/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |           (DATASET 0008: PHASE III EARLY DROPOUT FOLLOW-UP)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03088-0008-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE foutcome  1='(1) COMPLETE' ;
  VALUE f_ct      -7='(-7) NOT ASCERTAINED' 1='(1) DISCHARGED' 2='(2) IN TREATMENT' ;
  VALUE fa1fffff  -7='(-7) NOT ASCERTAINED' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE fa3fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa4fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa5fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WHITE' 2='(2) BLACK OR AFRICAN AMERICAN,' 3='(3) ASIAN,'
                  4='(4) NATIVE HAWAIIAN OR OTHER PACIFIC ISLANDE'
                  5='(5) AMERICAN INDIAN,' 6='(6) ALASKA NATIVE'
                  96='(96) OTHER (NOT FURTHER SPECIFIED)' ;
  VALUE fa6fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ENGLISH ONLY' 2='(2) SPANISH ONLY'
                  3='(3) OTHER LANGUAGE(S) ONLY (EXCLUDING ENGLIS'
                  4='(4) BOTH ENGLISH AND SPANISH'
                  5='(5) BOTH SPANISH AND OTHER LANGUAGE(S) (EXCL'
                  6='(6) BOTH ENGLISH AND OTHER LANGUAGE(S)' ;
  VALUE fa7fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa8fffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES, DIPLOMA' 2='(2) YES, GED' 3='(3) NO'
                  4='(4) NEVER ATTENDED SCHOOL (A11)' ;
  VALUE fa9fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) 1ST GRADE' 2='(2) 2ND GRADE' 3='(3) 3RD GRADE' 4='(4) 4TH GRADE'
                  5='(5) 5TH GRADE' 6='(6) 6TH GRADE' 7='(7) 7TH GRADE' 8='(8) 8TH GRADE'
                  9='(9) 9TH GRADE' 10='(10) 10TH GRADE' 11='(11) 11TH GRADE'
                  12='(12) 12TH GRADE' 13='(13) 1 YEAR COLLEGE/TECHNICAL SCHOOL'
                  14='(14) 2 YEARS COLLEGE/TECHNICAL SCHOOL'
                  15='(15) 3 - YEARS COLLEGE/TECHNICAL SCHOOL'
                  16='(16) 4 - YEARS COLLEGE/TECHNICAL SCHOOL'
                  17='(17) GRADUATE/PROFESSIONAL SCHOOL' ;
  VALUE fa10ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fa11ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa12ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa12a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fa13ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa14ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa15ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa16ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fa17ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fa18ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE f_lang    -7='(-7) NOT ASCERTAINED' 1='(1) ENGLISH' 2='(2) SPANISH' ;
  VALUE fb1a      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1b      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1c      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1d      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1e      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1f      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1g      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1h      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1i      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1j      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1k      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1l      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb2l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb1m      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb1moth   -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) DMT' 2='(2) ASTHMA MED' 3='(3) BARB' 4='(4) SMOKED CHERM'
                  5='(5) BLOOD PRESSURE MEDICINE' 6='(6) BAM' 7='(7) ANTIDEPRESSANTS'
                  8='(8) ELAVIL' 9='(9) PAIN KILLERS' 10='(10) CHOLORATINE' 11='(11) GHB'
                  96='(96) VARIES' ;
  VALUE fb2m      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb3m      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb4m      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fb5fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb6fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NEVER' 2='(2) LESS THAN ONCE A MONTH'
                  3='(3) 1 - 3 TIMES A MONTH' 4='(4) 1 - 2 TIMES A WEEK'
                  5='(5) 3 - 4 TIMES A WEEK' 6='(6) DAILY OR ALMOST EVERY DAY' ;
  VALUE fb7fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb8fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NEVER' 2='(2) LESS THAN ONCE A MONTH'
                  3='(3) 1 - 3 TIMES A MONTH' 4='(4) 1 - 2 TIMES A WEEK'
                  5='(5) 3 - 4 TIMES A WEEK' 6='(6) DAILY OR ALMOST EVERY DAY' ;
  VALUE fb9fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb9a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb10ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb11ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ONE DAY' 2='(2) 2 - 5 DAYS' 3='(3) 6 - 10 DAYS' 4='(4) 11 - 20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE fb12a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb13a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb12b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb13b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb12c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb13c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb14ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) INHALANTS,'
                  2='(2) MARIJUANA OR HASHISH' 3='(3) CRACK,'
                  4='(4) COCAINE, OTHER THAN CRACK'
                  5='(5) HALLUCINOGENS OR PSYCHEDELICS,' 6='(6) HEROIN,'
                  7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) OVER-THE-COUNTER DRUGS,'
                  13='(13) ALCOHOL' 14='(14) COMBO OF 02 AND 03 AND 04 AND 13'
                  15='(15) COMBO OF 04 AND 06 AND 13' 16='(16) COMBO OF 02 AND 13'
                  17='(17) COMBO OF 03 AND 04 AND 13' 18='(18) COMBO OF 04 AND 13'
                  19='(19) COMBO OF 03 AND 13' 20='(20) COMBO OF 09 AND 10 AND 04'
                  21='(21) COMBO OF 02 AND 12 AND 13' 22='(22) DEPRESSION RX'
                  23='(23) COMBO OF 02 AND 08' ;
  VALUE fb15ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO OTHER DRUG'
                  1='(1) INHALANTS,' 2='(2) MARIJUANA OR HASHISH,' 3='(3) CRACK,'
                  4='(4) COCAINE, OTHER THAN CRACK'
                  5='(5) HALLUCINOGENS OR PSYCHEDELICS,' 6='(6) HEROIN,'
                  7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) OVER-THE-COUNTER DRUGS,'
                  13='(13) ALCOHOL, OR' 14='(14) COMBO OF 04 AND 06'
                  15='(15) COMBO OF 02 AND 03 AND 05 AND 11' 16='(16) RX DRUGS'
                  17='(17) PAIN PILLS' ;
  VALUE fb16ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb17ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT DURING 12-MONTH PERIOD' ;
  VALUE fb18ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb19ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NOT DURING 12-MONTH PERIOD' ;
  VALUE fb20ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MARRIED' 2='(2) LIVING WITH SOMEONE AS MARRIED'
                  3='(3) SEPARATED' 4='(4) DIVORCED' 5='(5) WIDOWED' 6='(6) NEVER MARRIED' ;
  VALUE fb21ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb22ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb23ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb24ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb25ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1 - 6 MONTHS' 3='(3) 7 - 11 MONTHS'
                  4='(4) ENTIRE 12 MONTHS' ;
  VALUE fb26ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) A SINGLE FAMILY HOUSE, DUPLEX OR'
                  2='(2) AN APARTMENT, CONDO, OR OTHER MULTI-FAMI'
                  3='(3) A MOBILE HOME OR TRAILER,'
                  4='(4) A HOTEL, MOTEL, ROOMING HOUSE, OR BOARDI'
                  5='(5) A HOSPITAL OR MEDICAL INSTITUTION,' 6='(6) JAIL OR PRISON,'
                  7='(7) A RESIDENTIAL DRUG OR ALCOHOL TX PROGRAM'
                  8='(8) A HOMELESS SHELTER,' 9='(9) A HALFWAY HOUSE,'
                  10='(10) ON THE STREET, OR' 11='(11) TRANSIENT' 12='(12) GROUP HOME'
                  13='(13) FRIENDS HOUSE' 14='(14) COMBO OF 01 AND 06' 15='(15) CHURCH'
                  16='(16) PRERELEASE CENTER' 17='(17) BATTERED WOMENS SHELTER'
                  18='(18) COMBO 04 AND 08 AND 10' 19='(19) COMBO OF 01 AND 06 AND 10'
                  20='(20) COMMUNITY FOR PRIESTS' 21='(21) CAR'
                  22='(22) DIFFERENT FAMILY MEMBERS' 23='(23) TRUCK SLEEPER BERTH'
                  24='(24) PAROLE PROGRAM' 25='(25) DRINKING FRIENDS' ;
  VALUE fb27a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb27g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb28ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb29ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONE YEAR,' 2='(2) 1 TO 2 YEARS,'
                  3='(3) MORE THAN 2 YEARS BUT LESS THAN 5 YEARS'
                  4='(4) FIVE YEARS OR MORE?' ;
  VALUE fb30ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb31ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb32ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HH WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  6='(6) LABORER' 7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ADMINISTRATOR'
                  12='(12) LAY COUNSELOR, PEER COUNSELOR'
                  13='(13) PROFESSIONAL/TECHNICAL' 96='(96) OTHER, UNABLE TO CODE' ;
  VALUE fb33a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 2='(2) EVERY WEEK'
                  3='(3) EVERY TWO WEEKS' 4='(4) PER MONTH' 5='(5) PER YEAR'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE fb33aoth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' 1='(1) NIGHT' 2='(2) DAY'
                  3='(3) 3 MONTHS' 4='(4) TIP'
                  5='(5) NOT ENOUGH BUSINESS TO MAKE A PROFIT'
                  6='(6) PER 12 HOUR SHIFT' 7='(7) 9 MONTHS' 8='(8) PER HEAD' ;
  VALUE fb34ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb34a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONE YEAR,' 2='(2) 1 TO 2 YEARS'
                  3='(3) MORE THAN 2 YEARS BUT LESS THAN 5 YEARS'
                  4='(4) FIVE YEARS OR MORE?' ;
  VALUE fb35ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO (B39)' ;
  VALUE fb36ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb37ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HH WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  6='(6) LABORER' 7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ADMINISTRATOR'
                  12='(12) LAY COUNSELOR, PEER COUNSELOR'
                  13='(13) PROFESSIONAL/TECHNICAL' 96='(96) OTHER, UNABLE TO CODE' ;
  VALUE fb38a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 2='(2) EVERY WEEK'
                  3='(3) EVERY TWO WEEKS' 4='(4) PER MONTH' 5='(5) PER YEAR'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE fb38aoth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) PER JOB' 2='(2) PER NIGHT' 3='(3) PER 6 DAYS' 4='(4) PER POUND'
                  7='(7) SEMESTER' 8='(8) VOLUNTEERED' 9='(9) A DAY' 10='(10) WEEKEND'
                  11='(11) PER PARTY' ;
  VALUE fb39ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb40ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONE YEAR,' 2='(2) 1 TO 2 YEARS,'
                  3='(3) MORE THAN 2 YEARS BUT LESS THAN 5 YEARS'
                  4='(4) FIVE YEARS OR MORE?' ;
  VALUE fb41ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb42a     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42b     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42c     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42d     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42e     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42f     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42g     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42h     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42i     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42j     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42k     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb42l     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb43ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb44ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN $20,000' 2='(2) $20,000 OR MORE' ;
  VALUE fb44a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) LESS THAN $1,000 (INCLUDING LOSS)'
                  2='(2) $1,000 - $1,999' 3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999'
                  5='(5) $4,000 - $4,999' 6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999'
                  8='(8) $7,000 - $7,999' 9='(9) $8,000 - $8,999'
                  10='(10) $9,000 - $9,999' 11='(11) $10,000 - $10,999'
                  12='(12) $11,000 - $11,999' 13='(13) $12,000 - $12,999'
                  14='(14) $13,000 - $13,999' 15='(15) $14,000 - $14,999'
                  16='(16) $15,000 - $15,999' 17='(17) $16,000 - $16,999'
                  18='(18) $17,000 - $17,999' 19='(19) $18,000 - $18,999'
                  20='(20) $19,000 - $19,999' ;
  VALUE fb44b     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 21='(21) $20,000 - $24,999'
                  22='(22) $25,000 - $29,999' 23='(23) $30,000 - $34,999'
                  24='(24) $35,000 - $39,999' 25='(25) $40,000 - $44,999'
                  26='(26) $45,000 - $49,999' 27='(27) $50,000 - $74,999'
                  28='(28) $75,000 OR MORE' ;
  VALUE fb45ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb46a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb46h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb47h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb48h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED' ;
  VALUE fb49h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb50a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb50b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb50c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb50d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb51a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb52a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb53a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fb51b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb52b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb53b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fb51c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb52c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb53c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fb51d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb52d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb53d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fb54ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb55ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb56ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb57ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb58ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb59ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb60ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) EXCELLENT,'
                  2='(2) GOOD,' 3='(3) FAIR, OR' 4='(4) POOR?' ;
  VALUE fb61ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb62ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb63ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb64a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64k     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb64m     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb65m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb66ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb67ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb68ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb69ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb70ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb71ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb72ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb73ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb74ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb75ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb76ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN 1/4 PACK A DAY (1-5 CIGARETTES'
                  2='(2) ABOUT 1/2 PACK A DAY (6-15 CIGARETTES)'
                  3='(3) ABOUT A PACK A DAY (16-25 CIGARETTES)'
                  4='(4) ABOUT 1 1/2 PACKS A DAY (26-35 CIGARETTE'
                  5='(5) ABOUT 2 PACKS OR MORE A DAY (OVER 35 CIG' ;
  VALUE fb77a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb77b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb77c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb78ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb78a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb79ffff  -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE'
                  1='(1) ONE' 2='(2) 2 - 10' 3='(3) 11 - 25' 4='(4) 26 - 100' 5='(5) 101 - 500'
                  6='(6) MORE THAN 500' ;
  VALUE fb80ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb81a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81i     -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES'
                  2='(2) NO' ;
  VALUE fb82i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb82k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81m     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb82m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb81n     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb81noth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) PROBATION VIOLATION' 2='(2) WEAPON/WEAPON OFFENSES'
                  3='(3) NO ARREST' 4='(4) GAMBLING' 5='(5) PAROLE VIOLATION'
                  6='(6) WARRANTS ISSUED' 7='(7) CONTEMPT OF COURT' 8='(8) TAX EVASION'
                  9='(9) VANDALISM' 10='(10) DRIVING WITHOUT LICENSE'
                  11='(11) NON COMPLIANCE' 12='(12) UNDERAGE DRINKING'
                  13='(13) INCITING A RIOT' 14='(14) NUMBER RUNNER' 15='(15) TRESPASS'
                  16='(16) DEPRESSION' 17='(17) CHILD SUPPORT' 18='(18) RESISTING ARREST'
                  19='(19) TRAFFIC TICKET' 20='(20) BACK FINES'
                  21='(21) MOVING GUNS ACROSS STATE LINES' 22='(22) TERRORIST THREAT'
                  23='(23) VIOLATION OF ORDER OF PROTECTION'
                  24='(24) FAILURE TO PAY SUBWAY FARE' 25='(25) ARSON'
                  26='(26) DIDN''T GO TO AFTERCARE' ;
  VALUE fb82n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb83n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb84n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb85n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb86ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb87ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb88ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb89ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb90ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' ;
  VALUE fb91ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN OR EQUAL TO ONE DAY' ;
  VALUE fb91u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' 1='(1) DAYS' 2='(2) WEEKS'
                  3='(3) MONTHS' ;
  VALUE fb92ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb93ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fb93u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' 1='(1) WEEKS' 2='(2) MONTHS'
                  3='(3) YEARS' ;
  VALUE fb94ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fb95ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fb95a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc1fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) INHALANTS,'
                  2='(2) MARIJUANA OR HASHISH,' 3='(3) CRACK,' 4='(4) COCAINE,'
                  5='(5) HALLUCINOGENS OR PSYCHEDELICS,' 6='(6) HEROIN,'
                  7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES,'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) OVER-THE-COUNTER DRUGS,'
                  13='(13) ALCOHOL, OR' 14='(14) COMBO OF 04 AND 06'
                  15='(15) COMBO OF 02 AND 13' 16='(16) COMBO OF 03 AND 13'
                  17='(17) NO DRUG OR ALCOHOL PROBLEM'
                  18='(18) COMBO OF 02 AND 03 AND 09'
                  19='(19) COMBO OF 09 AND 10 AND 11' 20='(20) NONE'
                  21='(21) COMBO OF 03 AND 04' 22='(22) COMBO OF 02 AND 06'
                  23='(23) PAIN KILLERS'
                  96='(96) SOME OTHER DRUG? (NOT FURTHER SPECIFIED' ;
  VALUE fc2fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO OTHER DRUG'
                  1='(1) INHALANTS,' 2='(2) MARIJUANA OR HASHISH,' 3='(3) CRACK,'
                  4='(4) COCAINE,' 5='(5) HALLUCINOGENS OR PSYCHEDELICS,' 6='(6) HEROIN,'
                  7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES,'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) OVER-THE-COUNTER DRUGS,'
                  13='(13) ALCOHOL, OR' 14='(14) COMBO OF 09 AND 13'
                  15='(15) COMBO OF 01 AND 02' 16='(16) RX DRUGS' ;
  VALUE fc3fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc4fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) INHALANTS,' 2='(2) MARIJUANA OR HASHISH,' 3='(3) CRACK,'
                  4='(4) COCAINE,' 5='(5) HALLUCINOGENS OR PSYCHEDELICS,' 6='(6) HEROIN,'
                  7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES,'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) COMBO OF 04, 06 AND 13'
                  13='(13) ALCOHOL, OR' 14='(14) COMBO OF 02 AND 03 AND 06 AND 11'
                  15='(15) COMBO OF 03 AND 13' ;
  VALUE fc5fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NO OTHER DRUG' 1='(1) INHALANTS,' 2='(2) MARIJUANA OR HASHISH,'
                  3='(3) CRACK,' 4='(4) COCAINE,' 5='(5) HALLUCINOGENS OR PSYCHEDELICS,'
                  6='(6) HEROIN,' 7='(7) ILLEGAL METHADONE,' 8='(8) OTHER OPIATES,'
                  9='(9) AMPHETAMINES OR STIMULANTS,' 10='(10) SEDATIVES,'
                  11='(11) TRANQUILIZERS,' 12='(12) OVER-THE-COUNTER DRUGS,'
                  13='(13) ALCOHOL, OR' 15='(15) CHLONODINE' 17='(17) TOBACCO'
                  20='(20) COMBO OF 02 AND 03 AND 04'
                  96='(96) SOME OTHER DRUG? (NOT FURTHER SPECIFIED' ;
  VALUE fc6fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc6a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc7a      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc7b      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc7c      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc7d      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc7e      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc7f      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc8fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) TOO HIGH' 2='(2) THE RIGHT AMOUNT' 3='(3) TOO LOW' ;
  VALUE fc8a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' 1='(1) YES' 2='(2) NO' ;
  VALUE fc9fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc10ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc11ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) LESS THAN ONE' ;
  VALUE fc11u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE fc12ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HH WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  6='(6) LABORER' 7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ADMINISTRATOR'
                  12='(12) LAY COUNSELOR, PEER COUNSELOR'
                  13='(13) PROFESSIONAL/TECHNICAL' 14='(14) SELF EMPLOYED'
                  15='(15) MILITARY' 96='(96) OTHER, UNABLE TO CODE' ;
  VALUE fc13a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 2='(2) EVERY WEEK'
                  3='(3) EVERY TWO WEEKS' 4='(4) PER MONTH' 5='(5) PER YEAR'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE fc13aoth  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  2='(2) 3 MONTHS' 3='(3) PER DAY' 4='(4) PER HEAD' 5='(5) NO PROFIT'
                  6='(6) PER 12 HOUR SHIFT' 7='(7) VARIED-PAID BY JOB' 8='(8) PER NIGHT'
                  9='(9) EVERY 2 WKS PLUS COMMISSION' 10='(10) PIECEWORK' ;
  VALUE fc14ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc15ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc15u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS' ;
  VALUE fc16a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) PER HOUR' 2='(2) EVERY WEEK' 3='(3) EVERY TWO WEEKS'
                  4='(4) PER MONTH' 5='(5) PER YEAR' 6='(6) OTHER (SPECIFY)' ;
  VALUE fc16aoth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' 1='(1) GAIN PROGRAM'
                  2='(2) WORKED EVERY DAY' 3='(3) VOLUNTEER' 4='(4) PER DAY'
                  5='(5) DURING TREATMENT' 6='(6) PER JOB' 7='(7) VARIES' 8='(8) PER NIGHT'
                  9='(9) FOR 6 DAYS' 10='(10) NO PAY' ;
  VALUE fc17ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc18ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) RECEIVE TX ON AN OP BASIS ONLY'
                  2='(2) ONLY STAY OVERNIGHT SUCH AS RES TX ONLY'
                  3='(3) RECEIVE RES TX AND AN OP PERIOD OF CARE?' ;
  VALUE fc19ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc20ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH,' 2='(2) ONCE A MONTH,'
                  3='(3) TWO TO THREE TIMES A MONTH,' 4='(4) ONCE A WEEK,'
                  5='(5) TWICE A WEEK,' 6='(6) THREE TIMES A WEEK,'
                  7='(7) FOUR TIMES A WEEK,' 8='(8) FIVE TIMES A WEEK,'
                  9='(9) SIX TIMES A WEEK,' 10='(10) SEVEN TIMES A WEEK, OR'
                  11='(11) ONE TIME' 12='(12) 13WK AT 5X WK 4 1/2 MONTH AT 1 WK'
                  13='(13) LOCK DOWN' 14='(14) 5 DAYS DOWN TO 2' 15='(15) 7 DAYS DOWN TO 3'
                  16='(16) VARIED' 17='(17) IN HOME SESSIONS' 18='(18) FOR 6 DAYS'
                  19='(19) 5 DAYS' 20='(20) 3X' 21='(21) 2X WK THEN 5X WK' 22='(22) 78 VISITS'
                  23='(23) ALL THE TIME' 24='(24) INPATIENT' 25='(25) NEVER' 26='(26) 2X - 6X WK'
                  27='(27) ONLY TWICE' 28='(28) 4X - 7X WK' 29='(29) PHONE' 30='(30) 20 HOURS' ;
  VALUE fc21ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH,' 2='(2) ONCE A MONTH,'
                  3='(3) TWO TO THREE TIMES A MONTH,' 4='(4) ONCE A WEEK,'
                  5='(5) TWICE A WEEK,' 6='(6) THREE TIMES A WEEK,'
                  7='(7) FOUR TIMES A WEEK,' 8='(8) FIVE TIMES A WEEK,'
                  9='(9) SIX TIMES A WEEK,' 10='(10) SEVEN TIMES A WEEK, OR'
                  11='(11) MORE THAN 7X A WEEK' 12='(12) TWICE' 13='(13) JUST TREATMENT'
                  14='(14) 20 HOURS' 15='(15) NONE' 16='(16) 3X' 17='(17) ONE TIME'
                  18='(18) VARIOUS HOURS TO COMPLETE 20 HOURS' 19='(19) 5 DAYS' ;
  VALUE fc22ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FEELING PRESSURED BY JUDGE, PAROLE/PROBA'
                  2='(2) PRESSURE FROM A SPOUSE, PARTNER, OR PARE'
                  3='(3) PRESSURE FROM A SCHOOL TEACHER, MINISTER'
                  4='(4) TO GET, KEEP, OR IMPROVE A JOB SITUATION'
                  5='(5) TO GET OR KEEP CUSTODY OF ONE OR MORE CH'
                  6='(6) TO BECOME A BETTER PARENT,'
                  7='(7) ANY PROBLEMS YOU HAD WITH YOUR HEALTH TH'
                  8='(8) NEEDED/WANTED TO BECOME ELIG. FOR SOME T'
                  9='(9) WANTED TO CHANGE OR IMPROVE YOURSELF,'
                  10='(10) REQUIRED TO ATTEND TX AS CONDITION OF RE'
                  11='(11) DIFFICULTY GETTING DRUGS,'
                  12='(12) FINANCIAL PROBLEMS OR COULDNT AFFORD TO'
                  13='(13) ONLY TREATMENT AVAILABLE' 14='(14) TO OBTAIN DRIVER LICENSE'
                  15='(15) WIFES MENTAL ILLNESS' 16='(16) REFERRED TO HOSPITAL'
                  17='(17) FAILED DRUG TEST' 18='(18) DOCTOR SENT RESPONDENT'
                  19='(19) FAMILY SERVICE' 20='(20) NONE' 21='(21) NEED SOMEWHERE TO STAY'
                  22='(22) TRIED IT' 23='(23) TO BE WITH GIRLFRIEND' 24='(24) USED BAD DOPE'
                  25='(25) GET HELP WITH ADDICTION' 26='(26) TRANSFERRED'
                  27='(27) KEEP FROM BEING SICK' 28='(28) NEED METHADONE'
                  29='(29) WANTED TO STOP DRINKING'
                  30='(30) NORTH COAST HOUSE CONNIVED AGAINST ME HA'
                  32='(32) NEEDED SUPPORT EMOTIONALLY' 33='(33) COUNSELING'
                  34='(34) TIRED OF SELLING DRUGS, NO SLEEP BECAUSE' 35='(35) RELAPSE'
                  36='(36) TIRED OF GOING TO JAIL' 37='(37) FACILITY CLOSER TO HOME'
                  38='(38) SENT BY HOSPITAL' 39='(39) EMOTIONALLY FALL APART'
                  40='(40) GRIEF' 41='(41) DRUG ADDICTION' 42='(42) INSURANCE'
                  43='(43) MOMS ALCOHOL PROBLEM' 44='(44) CANT AFFORD METH. PROGRAM'
                  45='(45) WANTED LONG TERM TREATMENT'
                  46='(46) FACILITY COULDNT HANDLE PROBLEM'
                  47='(47) DIFFICULT TO WITHDRAW' ;
  VALUE fc24a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc25f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24k     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24m     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24n     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24o     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25o     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24p     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25p     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24q     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25q     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24r     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25r     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24s     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25s     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc24t     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc25t     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) FACILITY' 2='(2) ELSEWHERE' ;
  VALUE fc26ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH,' 2='(2) ONE TO 3 TIMES A MONTH,'
                  3='(3) ONE TO 2 TIMES A WEEK, OR' 4='(4) MORE OFTEN?' ;
  VALUE fc27ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH,' 2='(2) ONE TO 3 TIMES A MONTH,'
                  3='(3) ONE TO 2 TIMES A WEEK,' 4='(4) MORE OFTEN?' ;
  VALUE fc28ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) VERY HELPFUL'
                  2='(2) SOMEWHAT HELPFUL, OR' 3='(3) NOT AT ALL HELPFUL?' ;
  VALUE fc29a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29k     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29m     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29n     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc29o     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc30eoth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WEEKLY OVERNIGHT STAY' 2='(2) HOUSING'
                  3='(3) STAY WITH TREATMENT'
                  4='(4) PAMPHLETS & JOURNALS TO WRITE OUT FEELINGS'
                  5='(5) HOUSING REFERRAL AND MEDS.'
                  6='(6) EAT HEALTH, EXERCISE, REST' 7='(7) VOLUNTEER PROGRAM'
                  8='(8) HOME COUNSELING' 9='(9) HIV CLINIC' 10='(10) RELAXATION TAPES'
                  11='(11) STILL IN TREATMENT' 12='(12) FREE AIDS TESTING'
                  13='(13) DIDN''T GO BACK' ;
  VALUE fc31a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc32a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc33a     -9='(-9) INAPPLICABLE'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fc31b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc32b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc33b     -9='(-9) INAPPLICABLE'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fc31c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc32c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc33c     -9='(-9) INAPPLICABLE'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fc31d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc32d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc33d     -9='(-9) INAPPLICABLE'
                  1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY' 2='(2) ONCE A MONTH'
                  3='(3) TWO TO THREE TIMES A MONTH' 4='(4) ONCE A WEEK'
                  5='(5) ONE TO TWO TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fc34ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc35ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ONE TIME ONLY,' 2='(2) MORE THAN ONCE AT REGULAR INTERVALS,'
                  3='(3) MORE THAN ONCE, RANDOMLY,'
                  4='(4) MORE THAN ONCE, AT REGULAR INTERVALS AND'
                  5='(5) SOME OTHER TIMING?' ;
  VALUE fc35oth   -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) AFTER HOME VISITS' 2='(2) 2 TIMES ONLY'
                  3='(3) IF WENT OUTSIDE FACILITY' 4='(4) ONLY IF OUT ON A PASS' ;
  VALUE fc36ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) EXCELLENT'
                  2='(2) GOOD' 3='(3) FAIR' 4='(4) POOR' ;
  VALUE fc37ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc38ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc39ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc40ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc41ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc42ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc43ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc44ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc45ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc46ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc47ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc48ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc49ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc50ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc51ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fc52ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc53ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc54ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc55ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc56ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc57ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc58ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fc58u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NUMBER OF DAYS' 2='(2) NUMBER OF WEEKS' 3='(3) NUMBER OF MONTHS'
                  4='(4) NUMBER OF YEARS' ;
  VALUE fc59ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc60f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc61a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) CIRCLED'
                  2='(2) NOT CIRCLED' ;
  VALUE fc61joth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WORKMANS COMP' 2='(2) UNEMPLOYMENT'
                  3='(3) MEDICAID OR MEDICAL ASSISTANCE' 4='(4) ADASA'
                  5='(5) SCHOLARSHIPS' 6='(6) HEALTH PLAN' 7='(7) FOOD STAMPS'
                  8='(8) 90 DAY PROGRAM THAT PAID' 9='(9) D.C. GOVT' 10='(10) GRANT'
                  11='(11) DAS' 12='(12) COUPON' 13='(13) SEMSAS' 14='(14) STATE' 15='(15) UNION'
                  16='(16) WELFARE' 17='(17) PRIVATE FOUNDATION' 18='(18) SENT A BILL'
                  19='(19) M.I.A' 20='(20) CPS' 21='(21) TAPS' 22='(22) CAL OPTA' 23='(23) S.S.I'
                  24='(24) GOVERNMENT GRANT' 25='(25) JOB PAID' 26='(26) BLUE AND TENN CARE'
                  27='(27) COUNTY' 28='(28) TARGET CITY' 29='(29) PENDING' 30='(30) LADY PAID'
                  31='(31) STATE OF TEXAS' 32='(32) HEALTH SOURCE'
                  33='(33) TRIBE/INDIAN HEALTH CARE' 34='(34) HRS' 35='(35) WORKED THERE'
                  36='(36) 90% OF UNEMPLOYMENT' 37='(37) GROUP' 38='(38) R.R'
                  39='(39) STATE GRANT' 40='(40) PRIVATE DONATIONS' 41='(41) MED. PROGRAM'
                  42='(42) TOTAL HEALTH' 43='(43) ACT 151 STATE' 44='(44) ADAP'
                  45='(45) SECURITY BLUE' 46='(46) STATE SLOT' ;
  VALUE fc61main  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) A. PRIVATE HMO OR OTHER MANAGED CARE PL'
                  2='(2) B. OTHER PRIVATE HEALTH INSURANCE'
                  3='(3) C. MEDICAID OR MEDICAL ASSISTANCE' 4='(4) D. MEDICARE'
                  5='(5) E. MILITARY HEALTH CARE (CHAMPUS,CHAMPV'
                  6='(6) F. CRIMINAL JUSTICE SYSTEM' 7='(7) G. SOCIAL SERVICES'
                  8='(8) H. YOUR OWN MONEY' 9='(9) I. NO PAYMENT' 96='(96) J. OTHER PAY' ;
  VALUE fc62a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62k     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fc62l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd1a      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4a      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1b      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4b      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1c      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4c      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1d      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4d      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1e      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4e      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1f      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4f      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1g      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4g      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1h      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4h      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1i      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4i      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1j      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4j      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1k      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4k      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1l      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd2l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4l      -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1m      -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd1mothf  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ZOLOFT' 2='(2) INSULIN' 3='(3) TRAZHORNE'
                  4='(4) PRESCRIPTION MEDICATION' 5='(5) GH BRAND MUSHROOM'
                  6='(6) DEPOKE' 7='(7) COLONADINE' 8='(8) BLOOD PRESSURE MEDICINE' ;
  VALUE fd2mothf  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3mothf  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4mothf  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1mot0f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ZOLOFT' 6='(6) DEPOKE' 7='(7) TRAZODE'
                  8='(8) BLOOD PRESSURE MEDICINE' 9='(9) COLONADINE' 12='(12) CLODINE'
                  14='(14) GH BRAND MUSHROOM' 15='(15) PRESCRIPTION MEDICATION'
                  17='(17) TRAZHORNE' 18='(18) INSULIN' 19='(19) MUSHROOMS' ;
  VALUE fd2mot0f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3mot0f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4mot0f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd1mot1f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ZOLOFT' 6='(6) DEPOKE' 7='(7) TRAZODE'
                  8='(8) BLOOD PRESSURE MEDICINE' 9='(9) COLONADINE' 12='(12) CLODINE'
                  14='(14) GH BRAND MUSHROOM' 15='(15) PRESCRIPTION MEDICATION'
                  17='(17) TRAZHORNE' 18='(18) INSULIN' 19='(19) MUSHROOMS' ;
  VALUE fd2mot1f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN ONCE A MONTH' 2='(2) 1 - 3 TIMES A MONTH'
                  3='(3) 1 - 2 TIMES A WEEK' 4='(4) 3 - 4 TIMES A WEEK'
                  5='(5) 5 - 6 TIMES A WEEK, DAILY OR ALMOST EVER'
                  6='(6) 2 OR MORE TIMES A DAY' ;
  VALUE fd3mot1f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd4mot1f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) WITHIN THE PAST 3 DAYS'
                  2='(2) WITHIN THE PAST WEEK BUT NOT WITHIN THE'
                  3='(3) MORE THAN 1 WEEK AGO BUT WITHIN THE PAST'
                  4='(4) 1 - 6 MONTHS AGO' 5='(5) MORE THAN 6 MONTHS AGO' ;
  VALUE fd5fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd6fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd7fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NEVER' 2='(2) LESS THAN ONCE A MONTH'
                  3='(3) 1 - 3 TIMES A MONTH' 4='(4) 1 - 2 TIMES A WEEK'
                  5='(5) 3 - 4 TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd8fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NEVER' 2='(2) LESS THAN ONCE A MONTH'
                  3='(3) 1 - 3 TIMES A MONTH' 4='(4) 1 - 2 TIMES A WEEK'
                  5='(5) 3 - 4 TIMES A WEEK' 6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd9fffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd10ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd11ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ONE DAY' 2='(2) 2 - 5 DAYS' 3='(3) 6 - 10 DAYS' 4='(4) 11 - 20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE fd12a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd13a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd12b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd13b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd12c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd13c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd14ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd15ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd16ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MARRIED' 2='(2) LIVING WITH SOMEONE AS MARRIED'
                  3='(3) SEPARATED' 4='(4) DIVORCED' 5='(5) WIDOWED' 6='(6) NEVER MARRIED' ;
  VALUE fd17ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NONE' ;
  VALUE fd18ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd19ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd20ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd21ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1 - 6 MONTHS' 3='(3) 7 - 11 MONTHS'
                  4='(4) 12 MONTHS OR MORE' ;
  VALUE fd23a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd23g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd24ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd25ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd26ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd27ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HH WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  6='(6) LABORER' 7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ADMINISTRATOR'
                  12='(12) LAY COUNSELOR, PEER COUNSELOR'
                  13='(13) PROFESSIONAL/TECHNICAL' 96='(96) OTHER, UNABLE TO CODE' ;
  VALUE fd28a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) PER HOUR' 2='(2) EVERY WEEK'
                  3='(3) EVERY TWO WEEKS' 4='(4) PER MONTH' 5='(5) PER YEAR'
                  6='(6) OTHER (SPECIFY)' ;
  VALUE fd28aoth  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 2='(2) PER JOB' 3='(3) ROOM' 4='(4) A DAY' 5='(5) PER CAR'
                  6='(6) PER 12 HOUR SHIFT' 7='(7) 10 MONTHS' 8='(8) DEPENDING ON CATCH' ;
  VALUE fd29ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd30ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd31a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) PER HOUR' 2='(2) EVERY WEEK' 3='(3) EVERY TWO WEEKS'
                  4='(4) PER MONTH' 5='(5) PER YEAR' 6='(6) OTHER (SPECIFY)' ;
  VALUE fd31aoth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) PER JOB' 2='(2) DAY' 3='(3) VOLUNTEER' 4='(4) WHILE IN TREATMENT'
                  5='(5) FLAT FEE' 6='(6) 5 MONTHS' 7='(7) NO INCOME' 8='(8) COMMISSION'
                  9='(9) SUPPORT VARIED' 10='(10) PER CAR' ;
  VALUE fd32a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32b     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32c     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32d     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32e     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32f     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32g     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32h     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32i     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32j     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32k     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd32l     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd33a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd33b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd33c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd33d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd33e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd33f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd34a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd34b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd34c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd34d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd34e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd35ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd37a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED HOSPITAL OVERNIG' ;
  VALUE fd38a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED RESIDENTIAL PROG' ;
  VALUE fd38b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED OUTPATIENT METHA' ;
  VALUE fd38c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED OUTPATIENT NON-M' ;
  VALUE fd38d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED TREATMENT IN DR' ;
  VALUE fd38e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED HALF-WAY HOUSE' ;
  VALUE fd38f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED DUI/DWI PROGRAM' ;
  VALUE fd38g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd37h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) THIS TREATMENT NOT USED PROGRAM IN ANOTH' ;
  VALUE fd38h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd39a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd40a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd41a     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY'
                  2='(2) ONCE A MONTH' 3='(3) TWO TO THREE TIMES A MONTH'
                  4='(4) ONCE A WEEK' 5='(5) ONE TO TWO TIMES A WEEK'
                  6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd39b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd40b     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd41b     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY'
                  2='(2) ONCE A MONTH' 3='(3) TWO TO THREE TIMES A MONTH'
                  4='(4) ONCE A WEEK' 5='(5) ONE TO TWO TIMES A WEEK'
                  6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd39c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd40c     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd41c     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY'
                  2='(2) ONCE A MONTH' 3='(3) TWO TO THREE TIMES A MONTH'
                  4='(4) ONCE A WEEK' 5='(5) ONE TO TWO TIMES A WEEK'
                  6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd39d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd40d     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd41d     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) LESS THAN ONCE A MONTH OR INFREQUENTLY'
                  2='(2) ONCE A MONTH' 3='(3) TWO TO THREE TIMES A MONTH'
                  4='(4) ONCE A WEEK' 5='(5) ONE TO TWO TIMES A WEEK'
                  6='(6) DAILY OR ALMOST DAILY' ;
  VALUE fd42ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd42a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd42i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd43ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd44ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd45ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd46ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd47ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) EXCELLENT,'
                  2='(2) GOOD,' 3='(3) FAIR, OR' 4='(4) POOR' ;
  VALUE fd48ffff  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49j     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49k     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49l     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd49m     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd50ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd51ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd54ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd55ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd56ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd57ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd58ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd59ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd60ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) LESS THAN 1/4 PACK A DAY (1-5 CIGARETTES'
                  2='(2) ABOUT 1/2 PACK A DAY (6-15 CIGARETTES)'
                  3='(3) ABOUT A PACK A DAY (16-25 CIGARETTES)'
                  4='(4) ABOUT 1 1/2 PACKS A DAY (26-35 CIGARETTE'
                  5='(5) ABOUT 2 PACKS A DAY (OVER 35 CIGARETTES)' ;
  VALUE fd61a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd61b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd61c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd62ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd63ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd64ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd65ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd66ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) ONE' 2='(2) 2 - 10' 3='(3) 11 - 25'
                  4='(4) 26 - 100' 5='(5) 101 - 500' 6='(6) MORE THAN 500' ;
  VALUE fd67ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69j     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69k     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69l     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd69m     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd68noth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) ACCUSED OF STEALING' 2='(2) PAROLE/PROBATION VIOLATION'
                  3='(3) GAMBLING' 4='(4) WEAPON OFFENSE' 5='(5) CONTEMPT OF COURT'
                  6='(6) TRESPASSING' 7='(7) POSSESSION OF DRUG PARAPHERNALIA'
                  8='(8) DWI/FAILURE TO PAY FINE' 9='(9) OPEN BEER ON THE STREET'
                  10='(10) FAILURE TO PAY TICKET' 11='(11) DRIVING WITHOUT LICENSE'
                  12='(12) CHILD SUPPORT' 13='(13) BENCH WARRANT' ;
  VALUE fd69n     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd70ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd71ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd72ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd73ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd74ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd75ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE fd75u     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' ;
  VALUE fd76ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd77ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd78ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd79ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd80ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd81a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83a     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83b     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83c     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83d     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83e     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83f     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83g     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81h     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83h     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd81i     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd82i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) MEDICAL' 2='(2) NON-MEDICAL'
                  3='(3) BOTH MEDICAL AND NON-MEDICAL' ;
  VALUE fd83i     -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) YES' 2='(2) NO' ;
  VALUE fd84a     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) VERY SATISFIED'
                  2='(2) SOMEWHAT SATISFIED' 3='(3) NOT AT ALL SATISFIED' ;
  VALUE fd84b     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd84c     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd84d     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) YES' 2='(2) NO' ;
  VALUE fd84e     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) COMMENT (TEXT CONTAINED IN FILE P3TEXT I' 2='(2) NO COMMENT' ;
  VALUE fd84f     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) COMMENT (TEXT CONTAINED IN FILE P3TEXT I' 2='(2) NO COMMENT' ;
  VALUE fd84g     -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) COMMENT (TEXT CONTAINED IN FILE P3TEXT I' 2='(2) NO COMMENT' ;
  VALUE fb2cflg   0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb2fflg   0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb2kflg   0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82aflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82bflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82cflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82dflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82eflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82fflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82gflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82hflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82iflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82jflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82kflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82lflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82mflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb82nflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fb88aflg  0='(0) PASSED EDIT CHECK' 1='(1) FAILED EDIT CHECK' ;
  VALUE fd36flg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3bflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3cflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3dflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3eflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3fflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3gflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd3iflg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38bflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38cflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38dflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38fflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38gflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd38hflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd5flg    -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd26flg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd30flg   -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd40aflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd40bflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd40cflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fd40dflg  -9='(-9) INAPPLICABLE' 0='(0) PASSED EDIT CHECK'
                  1='(1) FAILED EDIT CHECK' ;
  VALUE fb64moth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BACK PROBLEM' 2='(2) CHEST PROBLEM' 3='(3) DROPPED BLADDER'
                  4='(4) SINUS' 5='(5) ANKYLOSIS SPONDILITUS'
                  6='(6) LUNG DISEASE, PNEUMONIA, BRONCHITIS'
                  7='(7) DENTAL, TEETH PROBLEM' 8='(8) GUN SHOT OR STAB WOUND'
                  9='(9) MASTITIS BREAST' 10='(10) BROKEN BONE' 11='(11) ALCOHOL'
                  12='(12) APPENDICITIS' 13='(13) HAY FEVER' 14='(14) SPLEEN REMOVAL'
                  15='(15) HERNIA' 16='(16) ULCER' 17='(17) RHEUMATIC FEVER' 18='(18) ASTHMA'
                  19='(19) PILLS' 20='(20) STROKE' 21='(21) PANCREATITIS' 22='(22) WEIGHT LOSS'
                  23='(23) GOUT' 24='(24) ENDOMETRIOSIS' 25='(25) AIDS' 26='(26) HIV'
                  27='(27) DEPRESSION' 28='(28) ABSCESSES' 29='(29) MALNUTRITION'
                  30='(30) BLADDER CANCER' 31='(31) SLEEP PROBLEM' 32='(32) WITHDRAWAL'
                  33='(33) DEFECTIVE HEARING' 34='(34) CIRCULATION PROBLEMS'
                  35='(35) MYEANTIUS GRAVIS' 36='(36) HEMORRHAGING' 37='(37) PSORIASIS'
                  38='(38) ALLERGIES' 39='(39) LOW PLATELETS' 40='(40) DIABETES'
                  41='(41) HIGH CHOLESTEROL' 42='(42) LOST RIGHT EYE' 43='(43) KNEE PROBLEM'
                  44='(44) MONONUCLEOSIS' 45='(45) SURGERY FOR OVARIAN CYST'
                  46='(46) NEUROLOGICAL CONDITIONS' 47='(47) BONE DISEASE'
                  48='(48) PYLONYTAL CYTOLOGY' 49='(49) ARTHRITIS' 50='(50) BROKEN NECK'
                  51='(51) THYROID' 52='(52) HEAD INJURIES' 53='(53) SPINAL PROBLEMS'
                  54='(54) HAND INJURY' 55='(55) OSTEOGENETIC SCOLIOSIS'
                  56='(56) HIP REPLACEMENT' 57='(57) ANXIETY ATTACK'
                  58='(58) ENDOCARDICIES/CONTAMINATED BLOOD' 59='(59) HIP PROBLEM'
                  60='(60) U.C' 61='(61) LOW BLOOD PRESSURE' 62='(62) LEG PROBLEM'
                  63='(63) JOINT PROBLEM' 64='(64) VISION' 65='(65) SHOULDER PROBLEM'
                  66='(66) REFLEX SYMP DYSTROPHY SYNDROME' 67='(67) HEART PROBLEMS'
                  68='(68) LEUKEMIA' 69='(69) SCHIZOPHRENIA' 70='(70) CAR ACCIDENT'
                  71='(71) BRAIN DAMAGE' 72='(72) TENDINITIS' 73='(73) PINS IN ANKLE'
                  74='(74) FOOT PROBLEMS' 75='(75) DIARRHEA' 76='(76) ULCER'
                  77='(77) STOMACH PROBLEMS' 78='(78) MS'
                  79='(79) TEMPERO MANDIBULAR JOINT DYSF'
                  80='(80) LOSS OF BALANCE AND CELLULITIS' 81='(81) PARALYSIS'
                  82='(82) BONE DEFORMITY' 83='(83) GALL BLADDER'
                  84='(84) CHRONIC FATIGUE SYNDROME' 85='(85) MUSCLE SPASM'
                  86='(86) BOILS AND CYSTS' 87='(87) SEIZURES' 88='(88) CPD'
                  89='(89) DETERIORATING BONE, MUSCLE MASS' 90='(90) BURN SCARS'
                  91='(91) BLOOD CLOTS' 92='(92) VIRAL MENINGITIS'
                  93='(93) CARPAL TUNNEL SYNDROME' 94='(94) BURSITIS' 95='(95) HYPOGLYCEMIA'
                  96='(96) INTESTINAL INFECTION' 97='(97) LOBOTOMY' 98='(98) MALARIA'
                  99='(99) GRAVES DISEASE' 100='(100) MYOFACIA STRAIN'
                  101='(101) FIBROMYALGIA' 102='(102) PROSTATE' 103='(103) OSTEOPOROSIS'
                  104='(104) ILIOSTOMY' 105='(105) RECTAL ABCESS'
                  106='(106) RECONSTRUCTIVE LEG SURGERY' 107='(107) EYE SURGERY'
                  108='(108) PAIN & NUMBNESS IN LIMBS' 109='(109) SWOLLEN LEGS'
                  110='(110) CELLULITIS' 111='(111) NERVES, CARDOSIS' 112='(112) TRAUMA'
                  113='(113) TORN KNEE CARTILAGE' 114='(114) LOW BLOOD SUGAR' ;
  VALUE fc7fothf  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) VALIUM/DIAZEPAM' 2='(2) VICODIN/LORCET/LORTAB'
                  3='(3) DILANTIN/PHENYTOIN' 4='(4) PHENOBARBITAL/DONNATAL'
                  5='(5) XANAX/ALPRAZOLAM' 6='(6) DESYREL/TRAZODONE' 7='(7) PROZAC'
                  8='(8) ALTRAM' 9='(9) PHENIGREN' 10='(10) EMPHYSEMA RX' 11='(11) DIABETES RX'
                  12='(12) BLOOD PRESSURE MEDICATION' 13='(13) ANTIBIOTICS'
                  14='(14) HORMONES' 15='(15) PREDNISONE' 16='(16) SINEMET' 17='(17) LASIX'
                  18='(18) CARBO-LEVO' 19='(19) CYLERT' 20='(20) BIRTH CONTROL PILLS'
                  21='(21) MOTRIN/IBUPROFEN' 22='(22) ZANTAC' 23='(23) TAGAMET'
                  24='(24) PRINZIDE' 25='(25) EFFEXOR' 26='(26) BUSPAR'
                  27='(27) ZOLOFT/SERTRALINE' 28='(28) DILAUDID'
                  29='(29) FAXER FOR DEPRESSION' 30='(30) MARINOL' 31='(31) AZT'
                  32='(32) LITHIUM' 33='(33) PREMARIN' 34='(34) ANTIDEPRESSANT' 35='(35) DEMEROL'
                  36='(36) BUPRENEX' 37='(37) TYLENOL' 38='(38) CODEINE' 39='(39) DECONGESTANT'
                  40='(40) DEPAKOTE' 41='(41) CLONAPIN/KLONAPIN/CLONAZEPAM' 42='(42) ABIAN'
                  43='(43) MYOSCYAMINE SULFUR' 44='(44) BRILOSEC' 45='(45) ZYPREXA'
                  46='(46) CRIXOVAIN' 47='(47) BACTRIM/SULFA' 48='(48) EPIVIR'
                  49='(49) EPILEPSY MEDICINE' 50='(50) REOLUIM' 51='(51) ANCIAD'
                  52='(52) PROCARDIA' 53='(53) AMITRIPOLENE' 54='(54) KEFLEX' 55='(55) ORAVILA'
                  56='(56) CLERVIER' 57='(57) GLYNASE' 58='(58) SEG' 59='(59) DDI' 60='(60) VARONINE'
                  61='(61) DI' 62='(62) VIADIN' 63='(63) PAINKILLER' 64='(64) MEXITIL'
                  65='(65) LOWMADIN' 66='(66) CLONIPINE' 67='(67) TEGRETOL'
                  68='(68) FIORINAL WITH CODEINE' 69='(69) RESPIRAL'
                  70='(70) CHLORAL HYDRATE' 71='(71) PAXIL' 72='(72) NEURONTIN' 73='(73) BENTYL'
                  74='(74) VITAMINS' 75='(75) PROLIXIN' 76='(76) HIRISPALDAR' 77='(77) INSULIN'
                  78='(78) SANUTEX' 79='(79) COLOPINE' 80='(80) OLANZITINE'
                  81='(81) CLONIDINE/CATEPRES' 82='(82) ASTHMA RX' 83='(83) VOLTAREN'
                  84='(84) WELLBUTRIN' 85='(85) SYNTHROID' 86='(86) HEART MEDS'
                  87='(87) NAPROXEN' 88='(88) ANTI-INFLAMMATORY' 89='(89) PAKIPAM'
                  90='(90) VASOTEC' 91='(91) MORPHINE' 92='(92) NORMODYNE' 93='(93) ASPIRIN'
                  94='(94) PERCOSET/PERCODAN/OXYCODONE' 95='(95) DUPROKOTE'
                  96='(96) COMBVIR/CINBVUR' 97='(97) BENADRYL' 98='(98) CLONOMINE'
                  99='(99) PRILOSEC' 100='(100) AMATROX' 101='(101) ZOMIG' 102='(102) KAIZAC'
                  103='(103) ASACOL' 104='(104) QUANADINE' 105='(105) INJECTIONS' 106='(106) LOZOL'
                  107='(107) CELEXA' 108='(108) GLYBURIDE' 109='(109) P.K' 110='(110) CALIZEN'
                  111='(111) DIET PILLS' 112='(112) CIMITRIL' 113='(113) LOXITANE'
                  114='(114) IMITREX' 115='(115) AMBIEN' 116='(116) CECORE' 117='(117) PROVACET'
                  118='(118) DEZERMINE' 119='(119) PHERIBAITAR' 120='(120) INDERAL'
                  121='(121) CLOZARIL' 122='(122) PROXICAPS' 123='(123) SUDAFED'
                  124='(124) TYLENOL WITH CODEINE' 125='(125) CARDIZEM' 126='(126) TERAZOSIN'
                  127='(127) LUVOX' 128='(128) ALLERGY MEDICINE' 129='(129) AZMACORT'
                  130='(130) ROBAXIN' 131='(131) COMPAZINE' 132='(132) TRIXOVAN'
                  133='(133) PAMELOR/NORTRIPTYLENE' 134='(134) HYDROCHROLOGYZINE'
                  135='(135) ANTI ANXIETY' 136='(136) PEPCID' 137='(137) TRIAVIL/TRILAFON'
                  138='(138) NORVIR' 139='(139) BIOTIN' 140='(140) MEDICINE FOR CHOLESTEROL'
                  141='(141) CLOVIDINC' 142='(142) T.B. DRUG' 143='(143) ZOVIRAX' 144='(144) ZESTRIL'
                  145='(145) MUSCLE RELAXER' 146='(146) KALADINE'
                  147='(147) TRIAMTERENE/DYAZIDE' 148='(148) BIOVAL' 149='(149) DONNATAL'
                  150='(150) OXAZEPAM/SERAX' 151='(151) VENTOLIN/PROVENTIL/ALBUTEROL'
                  152='(152) NITROGLYCERIN' 153='(153) KAOLIN' 154='(154) FOLIC ACID'
                  155='(155) CALIZAN' 156='(156) ZYPREXA' 157='(157) AFRAVIL' 158='(158) ZAIRES'
                  159='(159) COMPAVERE' 160='(160) VIRAMUNE' 161='(161) RECRITOR'
                  162='(162) FOR REFLUX' 163='(163) DELACTOSE' 164='(164) BECLOVENT'
                  165='(165) VAIRESES' 166='(166) HYDROCLONO' 167='(167) PRESORIBE' 168='(168) CRAVE'
                  169='(169) SEDATIVES' 170='(170) 3TC' 171='(171) REPISAL' 172='(172) HYADOL'
                  173='(173) CALDURA' 174='(174) ADALAT' 175='(175) HCTZ' 176='(176) MONOPIN'
                  177='(177) CIPRO' 178='(178) CALAN' 179='(179) CARDENSA' 180='(180) AMOXYCILLIN'
                  181='(181) COUGH SYRUP' 182='(182) FOR ARTHRITIS' 183='(183) VIRACEPT'
                  184='(184) SELDANE' 185='(185) FOR CONSTIPATION' 186='(186) ANADROL'
                  187='(187) ZERIT' 188='(188) NAPROSYN' 189='(189) ADDERAL' 190='(190) HYDROXYZINE'
                  191='(191) THIAMINE' 192='(192) PIMX' 193='(193) NORVASC' 194='(194) THEOPHYLLINE'
                  195='(195) DARVON/DARVOCET' 196='(196) FUBERCIOUS' 197='(197) SALSALATE'
                  198='(198) MELLARIL' 199='(199) QUADINE' 200='(200) SERZONE' 201='(201) RISPERDAL'
                  202='(202) HYDROCORDINE' 203='(203) NORTHRIPINE'
                  204='(204) CARISOPRODOL/SOMA' 205='(205) SLEEPING PILLS'
                  206='(206) TRANQUILIZERS' 207='(207) POTASSIUM' 208='(208) RITALIN'
                  209='(209) VISTARIL' 210='(210) HALCYON' 211='(211) FEN-PHEN' 212='(212) INDOVRAL'
                  213='(213) HIV MEDICINE' 214='(214) ETOH' 215='(215) COLCHICINE'
                  216='(216) MALEATE POLARAMINE' 217='(217) SOMETHING TO RELAX'
                  218='(218) BLOOD THINNER OR PEMETHIAN'
                  219='(219) MEDICATION TO CURB URGE TO DRINK'
                  220='(220) ATIVAN/LORAZEPAM' 221='(221) GLAVIDA' 222='(222) BENZTROPINE'
                  223='(223) SIMVASTATIN/ZOCOR' 224='(224) FLUPHENAZINE' 225='(225) DALMANE'
                  226='(226) CLINADAPAN' 227='(227) RISEROL' 228='(228) DOXEPIN/SINEQUAN'
                  229='(229) PENICILLIN' 230='(230) LIBRIUM' 231='(231) KEMADRIN'
                  232='(232) THORAZINE' ;
  VALUE fc7fot0f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) VALIUM/DIAZEPAM' 2='(2) VICODIN/LORCET/LORTAB'
                  3='(3) DILANTIN/PHENYTOIN' 4='(4) PHENOBARBITAL/DONNATAL'
                  5='(5) XANAX/ALPRAZOLAM' 6='(6) DESYREL/TRAZODONE' 7='(7) PROZAC'
                  8='(8) ALTRAM' 9='(9) PHENIGREN' 10='(10) EMPHYSEMA RX' 11='(11) DIABETES RX'
                  12='(12) BLOOD PRESSURE MEDICATION' 13='(13) ANTIBIOTICS'
                  14='(14) HORMONES' 15='(15) PREDNISONE' 16='(16) SINEMET' 17='(17) LASIX'
                  18='(18) CARBO-LEVO' 19='(19) CYLERT' 20='(20) BIRTH CONTROL PILLS'
                  21='(21) MOTRIN/IBUPROFEN' 22='(22) ZANTAC' 23='(23) TAGAMET'
                  24='(24) PRINZIDE' 25='(25) EFFEXOR' 26='(26) BUSPAR'
                  27='(27) ZOLOFT/SERTRALINE' 28='(28) DILAUDID'
                  29='(29) FAXER FOR DEPRESSION' 30='(30) MARINOL' 31='(31) AZT'
                  32='(32) LITHIUM' 33='(33) PREMARIN' 34='(34) ANTIDEPRESSANT' 35='(35) DEMEROL'
                  36='(36) BUPRENEX' 37='(37) TYLENOL' 38='(38) CODEINE' 39='(39) DECONGESTANT'
                  40='(40) DEPAKOTE' 41='(41) CLONAPIN/KLONAPIN/CLONAZEPAM' 42='(42) ABIAN'
                  43='(43) MYOSCYAMINE SULFUR' 44='(44) BRILOSEC' 45='(45) ZYPREXA'
                  46='(46) CRIXOVAIN' 47='(47) BACTRIM/SULFA' 48='(48) EPIVIR'
                  49='(49) EPILEPSY MEDICINE' 50='(50) REOLUIM' 51='(51) ANCIAD'
                  52='(52) PROCARDIA' 53='(53) AMITRIPOLENE' 54='(54) KEFLEX' 55='(55) ORAVILA'
                  56='(56) CLERVIER' 57='(57) GLYNASE' 58='(58) SEG' 59='(59) DDI' 60='(60) VARONINE'
                  61='(61) DI' 62='(62) VIADIN' 63='(63) PAINKILLER' 64='(64) MEXITIL'
                  65='(65) LOWMADIN' 66='(66) CLONIPINE' 67='(67) TEGRETOL'
                  68='(68) FIORINAL WITH CODEINE' 69='(69) RESPIRAL'
                  70='(70) CHLORAL HYDRATE' 71='(71) PAXIL' 72='(72) NEURONTIN' 73='(73) BENTYL'
                  74='(74) VITAMINS' 75='(75) PROLIXIN' 76='(76) HIRISPALDAR' 77='(77) INSULIN'
                  78='(78) SANUTEX' 79='(79) COLOPINE' 80='(80) OLANZITINE'
                  81='(81) CLONIDINE/CATEPRES' 82='(82) ASTHMA RX' 83='(83) VOLTAREN'
                  84='(84) WELLBUTRIN' 85='(85) SYNTHROID' 86='(86) HEART MEDS'
                  87='(87) NAPROXEN' 88='(88) ANTI-INFLAMMATORY' 89='(89) PAKIPAM'
                  90='(90) VASOTEC' 91='(91) MORPHINE' 92='(92) NORMODYNE' 93='(93) ASPIRIN'
                  94='(94) PERCOSET/PERCODAN/OXYCODONE' 95='(95) DUPROKOTE'
                  96='(96) COMBVIR/CINBVUR' 97='(97) BENADRYL' 98='(98) CLONOMINE'
                  99='(99) PRILOSEC' 100='(100) AMATROX' 101='(101) ZOMIG' 102='(102) KAIZAC'
                  103='(103) ASACOL' 104='(104) QUANADINE' 105='(105) INJECTIONS' 106='(106) LOZOL'
                  107='(107) CELEXA' 108='(108) GLYBURIDE' 109='(109) P.K' 110='(110) CALIZEN'
                  111='(111) DIET PILLS' 112='(112) CIMITRIL' 113='(113) LOXITANE'
                  114='(114) IMITREX' 115='(115) AMBIEN' 116='(116) CECORE' 117='(117) PROVACET'
                  118='(118) DEZERMINE' 119='(119) PHERIBAITAR' 120='(120) INDERAL'
                  121='(121) CLOZARIL' 122='(122) PROXICAPS' 123='(123) SUDAFED'
                  124='(124) TYLENOL WITH CODEINE' 125='(125) CARDIZEM' 126='(126) TERAZOSIN'
                  127='(127) LUVOX' 128='(128) ALLERGY MEDICINE' 129='(129) AZMACORT'
                  130='(130) ROBAXIN' 131='(131) COMPAZINE' 132='(132) TRIXOVAN'
                  133='(133) PAMELOR/NORTRIPTYLENE' 134='(134) HYDROCHROLOGYZINE'
                  135='(135) ANTI ANXIETY' 136='(136) PEPCID' 137='(137) TRIAVIL/TRILAFON'
                  138='(138) NORVIR' 139='(139) BIOTIN' 140='(140) MEDICINE FOR CHOLESTEROL'
                  141='(141) CLOVIDINC' 142='(142) T.B. DRUG' 143='(143) ZOVIRAX' 144='(144) ZESTRIL'
                  145='(145) MUSCLE RELAXER' 146='(146) KALADINE'
                  147='(147) TRIAMTERENE/DYAZIDE' 148='(148) BIOVAL' 149='(149) DONNATAL'
                  150='(150) OXAZEPAM/SERAX' 151='(151) VENTOLIN/PROVENTIL/ALBUTEROL'
                  152='(152) NITROGLYCERIN' 153='(153) KAOLIN' 154='(154) FOLIC ACID'
                  155='(155) CALIZAN' 156='(156) ZYPREXA' 157='(157) AFRAVIL' 158='(158) ZAIRES'
                  159='(159) COMPAVERE' 160='(160) VIRAMUNE' 161='(161) RECRITOR'
                  162='(162) FOR REFLUX' 163='(163) DELACTOSE' 164='(164) BECLOVENT'
                  165='(165) VAIRESES' 166='(166) HYDROCLONO' 167='(167) PRESORIBE' 168='(168) CRAVE'
                  169='(169) SEDATIVES' 170='(170) 3TC' 171='(171) REPISAL' 172='(172) HYADOL'
                  173='(173) CALDURA' 174='(174) ADALAT' 175='(175) HCTZ' 176='(176) MONOPIN'
                  177='(177) CIPRO' 178='(178) CALAN' 179='(179) CARDENSA' 180='(180) AMOXYCILLIN'
                  181='(181) COUGH SYRUP' 182='(182) FOR ARTHRITIS' 183='(183) VIRACEPT'
                  184='(184) SELDANE' 185='(185) FOR CONSTIPATION' 186='(186) ANADROL'
                  187='(187) ZERIT' 188='(188) NAPROSYN' 189='(189) ADDERAL' 190='(190) HYDROXYZINE'
                  191='(191) THIAMINE' 192='(192) PIMX' 193='(193) NORVASC' 194='(194) THEOPHYLLINE'
                  195='(195) DARVON/DARVOCET' 196='(196) FUBERCIOUS' 197='(197) SALSALATE'
                  198='(198) MELLARIL' 199='(199) QUADINE' 200='(200) SERZONE' 201='(201) RISPERDAL'
                  202='(202) HYDROCORDINE' 203='(203) NORTHRIPINE'
                  204='(204) CARISOPRODOL/SOMA' 205='(205) SLEEPING PILLS'
                  206='(206) TRANQUILIZERS' 207='(207) POTASSIUM' 208='(208) RITALIN'
                  209='(209) VISTARIL' 210='(210) HALCYON' 211='(211) FEN-PHEN' 212='(212) INDOVRAL'
                  213='(213) HIV MEDICINE' 214='(214) ETOH' 215='(215) COLCHICINE'
                  216='(216) MALEATE POLARAMINE' 217='(217) SOMETHING TO RELAX'
                  218='(218) BLOOD THINNER OR PEMETHIAN'
                  219='(219) MEDICATION TO CURB URGE TO DRINK'
                  220='(220) ATIVAN/LORAZEPAM' 221='(221) GLAVIDA' 222='(222) BENZTROPINE'
                  223='(223) SIMVASTATIN/ZOCOR' 224='(224) FLUPHENAZINE' 225='(225) DALMANE'
                  226='(226) CLINADAPAN' 227='(227) RISEROL' 228='(228) DOXEPIN/SINEQUAN'
                  229='(229) PENICILLIN' 230='(230) LIBRIUM' 231='(231) KEMADRIN'
                  232='(232) THORAZINE' ;
  VALUE fc7fot1f  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) VALIUM/DIAZEPAM' 2='(2) VICODIN/LORCET/LORTAB'
                  3='(3) DILANTIN/PHENYTOIN' 4='(4) PHENOBARBITAL/DONNATAL'
                  5='(5) XANAX/ALPRAZOLAM' 6='(6) DESYREL/TRAZODONE' 7='(7) PROZAC'
                  8='(8) ALTRAM' 9='(9) PHENIGREN' 10='(10) EMPHYSEMA RX' 11='(11) DIABETES RX'
                  12='(12) BLOOD PRESSURE MEDICATION' 13='(13) ANTIBIOTICS'
                  14='(14) HORMONES' 15='(15) PREDNISONE' 16='(16) SINEMET' 17='(17) LASIX'
                  18='(18) CARBO-LEVO' 19='(19) CYLERT' 20='(20) BIRTH CONTROL PILLS'
                  21='(21) MOTRIN/IBUPROFEN' 22='(22) ZANTAC' 23='(23) TAGAMET'
                  24='(24) PRINZIDE' 25='(25) EFFEXOR' 26='(26) BUSPAR'
                  27='(27) ZOLOFT/SERTRALINE' 28='(28) DILAUDID'
                  29='(29) FAXER FOR DEPRESSION' 30='(30) MARINOL' 31='(31) AZT'
                  32='(32) LITHIUM' 33='(33) PREMARIN' 34='(34) ANTIDEPRESSANT' 35='(35) DEMEROL'
                  36='(36) BUPRENEX' 37='(37) TYLENOL' 38='(38) CODEINE' 39='(39) DECONGESTANT'
                  40='(40) DEPAKOTE' 41='(41) CLONAPIN/KLONAPIN/CLONAZEPAM' 42='(42) ABIAN'
                  43='(43) MYOSCYAMINE SULFUR' 44='(44) BRILOSEC' 45='(45) ZYPREXA'
                  46='(46) CRIXOVAIN' 47='(47) BACTRIM/SULFA' 48='(48) EPIVIR'
                  49='(49) EPILEPSY MEDICINE' 50='(50) REOLUIM' 51='(51) ANCIAD'
                  52='(52) PROCARDIA' 53='(53) AMITRIPOLENE' 54='(54) KEFLEX' 55='(55) ORAVILA'
                  56='(56) CLERVIER' 57='(57) GLYNASE' 58='(58) SEG' 59='(59) DDI' 60='(60) VARONINE'
                  61='(61) DI' 62='(62) VIADIN' 63='(63) PAINKILLER' 64='(64) MEXITIL'
                  65='(65) LOWMADIN' 66='(66) CLONIPINE' 67='(67) TEGRETOL'
                  68='(68) FIORINAL WITH CODEINE' 69='(69) RESPIRAL'
                  70='(70) CHLORAL HYDRATE' 71='(71) PAXIL' 72='(72) NEURONTIN' 73='(73) BENTYL'
                  74='(74) VITAMINS' 75='(75) PROLIXIN' 76='(76) HIRISPALDAR' 77='(77) INSULIN'
                  78='(78) SANUTEX' 79='(79) COLOPINE' 80='(80) OLANZITINE'
                  81='(81) CLONIDINE/CATEPRES' 82='(82) ASTHMA RX' 83='(83) VOLTAREN'
                  84='(84) WELLBUTRIN' 85='(85) SYNTHROID' 86='(86) HEART MEDS'
                  87='(87) NAPROXEN' 88='(88) ANTI-INFLAMMATORY' 89='(89) PAKIPAM'
                  90='(90) VASOTEC' 91='(91) MORPHINE' 92='(92) NORMODYNE' 93='(93) ASPIRIN'
                  94='(94) PERCOSET/PERCODAN/OXYCODONE' 95='(95) DUPROKOTE'
                  96='(96) COMBVIR/CINBVUR' 97='(97) BENADRYL' 98='(98) CLONOMINE'
                  99='(99) PRILOSEC' 100='(100) AMATROX' 101='(101) ZOMIG' 102='(102) KAIZAC'
                  103='(103) ASACOL' 104='(104) QUANADINE' 105='(105) INJECTIONS' 106='(106) LOZOL'
                  107='(107) CELEXA' 108='(108) GLYBURIDE' 109='(109) P.K' 110='(110) CALIZEN'
                  111='(111) DIET PILLS' 112='(112) CIMITRIL' 113='(113) LOXITANE'
                  114='(114) IMITREX' 115='(115) AMBIEN' 116='(116) CECORE' 117='(117) PROVACET'
                  118='(118) DEZERMINE' 119='(119) PHERIBAITAR' 120='(120) INDERAL'
                  121='(121) CLOZARIL' 122='(122) PROXICAPS' 123='(123) SUDAFED'
                  124='(124) TYLENOL WITH CODEINE' 125='(125) CARDIZEM' 126='(126) TERAZOSIN'
                  127='(127) LUVOX' 128='(128) ALLERGY MEDICINE' 129='(129) AZMACORT'
                  130='(130) ROBAXIN' 131='(131) COMPAZINE' 132='(132) TRIXOVAN'
                  133='(133) PAMELOR/NORTRIPTYLENE' 134='(134) HYDROCHROLOGYZINE'
                  135='(135) ANTI ANXIETY' 136='(136) PEPCID' 137='(137) TRIAVIL/TRILAFON'
                  138='(138) NORVIR' 139='(139) BIOTIN' 140='(140) MEDICINE FOR CHOLESTEROL'
                  141='(141) CLOVIDINC' 142='(142) T.B. DRUG' 143='(143) ZOVIRAX' 144='(144) ZESTRIL'
                  145='(145) MUSCLE RELAXER' 146='(146) KALADINE'
                  147='(147) TRIAMTERENE/DYAZIDE' 148='(148) BIOVAL' 149='(149) DONNATAL'
                  150='(150) OXAZEPAM/SERAX' 151='(151) VENTOLIN/PROVENTIL/ALBUTEROL'
                  152='(152) NITROGLYCERIN' 153='(153) KAOLIN' 154='(154) FOLIC ACID'
                  155='(155) CALIZAN' 156='(156) ZYPREXA' 157='(157) AFRAVIL' 158='(158) ZAIRES'
                  159='(159) COMPAVERE' 160='(160) VIRAMUNE' 161='(161) RECRITOR'
                  162='(162) FOR REFLUX' 163='(163) DELACTOSE' 164='(164) BECLOVENT'
                  165='(165) VAIRESES' 166='(166) HYDROCLONO' 167='(167) PRESORIBE' 168='(168) CRAVE'
                  169='(169) SEDATIVES' 170='(170) 3TC' 171='(171) REPISAL' 172='(172) HYADOL'
                  173='(173) CALDURA' 174='(174) ADALAT' 175='(175) HCTZ' 176='(176) MONOPIN'
                  177='(177) CIPRO' 178='(178) CALAN' 179='(179) CARDENSA' 180='(180) AMOXYCILLIN'
                  181='(181) COUGH SYRUP' 182='(182) FOR ARTHRITIS' 183='(183) VIRACEPT'
                  184='(184) SELDANE' 185='(185) FOR CONSTIPATION' 186='(186) ANADROL'
                  187='(187) ZERIT' 188='(188) NAPROSYN' 189='(189) ADDERAL' 190='(190) HYDROXYZINE'
                  191='(191) THIAMINE' 192='(192) PIMX' 193='(193) NORVASC' 194='(194) THEOPHYLLINE'
                  195='(195) DARVON/DARVOCET' 196='(196) FUBERCIOUS' 197='(197) SALSALATE'
                  198='(198) MELLARIL' 199='(199) QUADINE' 200='(200) SERZONE' 201='(201) RISPERDAL'
                  202='(202) HYDROCORDINE' 203='(203) NORTHRIPINE'
                  204='(204) CARISOPRODOL/SOMA' 205='(205) SLEEPING PILLS'
                  206='(206) TRANQUILIZERS' 207='(207) POTASSIUM' 208='(208) RITALIN'
                  209='(209) VISTARIL' 210='(210) HALCYON' 211='(211) FEN-PHEN' 212='(212) INDOVRAL'
                  213='(213) HIV MEDICINE' 214='(214) ETOH' 215='(215) COLCHICINE'
                  216='(216) MALEATE POLARAMINE' 217='(217) SOMETHING TO RELAX'
                  218='(218) BLOOD THINNER OR PEMETHIAN'
                  219='(219) MEDICATION TO CURB URGE TO DRINK'
                  220='(220) ATIVAN/LORAZEPAM' 221='(221) GLAVIDA' 222='(222) BENZTROPINE'
                  223='(223) SIMVASTATIN/ZOCOR' 224='(224) FLUPHENAZINE' 225='(225) DALMANE'
                  226='(226) CLINADAPAN' 227='(227) RISEROL' 228='(228) DOXEPIN/SINEQUAN'
                  229='(229) PENICILLIN' 230='(230) LIBRIUM' 231='(231) KEMADRIN'
                  232='(232) THORAZINE' ;
  VALUE fd49moth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) BACK PROBLEMS' 2='(2) STROKE' 3='(3) BONES AND JOINTS'
                  4='(4) ANKYLOSIS SPONDILITIS' 5='(5) SINUS' 6='(6) DIABETES'
                  7='(7) KNEE INJURY' 8='(8) BROKEN RIBS' 9='(9) PINCHED NERVE'
                  10='(10) FEMALE PROBLEMS' 11='(11) CANT DO ANYTHING FOR MYSELF'
                  12='(12) RETINITIS PIGMENOTOSA' 13='(13) EMPHYSEMA' 14='(14) HERNIA'
                  15='(15) ULCER' 16='(16) COLITIS' 17='(17) ASTHMA' 18='(18) BURSITIS'
                  19='(19) LEG AMPUTATED' 20='(20) DROPPED BLADDER' 21='(21) CAR ACCIDENT'
                  22='(22) ENDOMETRIOSIS' 23='(23) PNEUMONIA' 24='(24) FEET PROBLEMS'
                  25='(25) HIV' 26='(26) MEIGS SYNDROME' 27='(27) ABSCESSES' 28='(28) PSORIASIS'
                  29='(29) ANEURYSM IN STOMACH' 30='(30) BROKEN COLLAR BONE'
                  31='(31) ALLERGIES' 32='(32) HIGH CHOLESTEROL' 33='(33) GOUT'
                  34='(34) ARTHRITIS' 35='(35) DM' 36='(36) INNER EAR PROBLEM'
                  37='(37) CHRONIC MUSCLE DAMAGE' 38='(38) YEAST'
                  39='(39) THERAPY AFTER ARM SURGERY' 40='(40) BRONCHITIS'
                  41='(41) BLADDER INFECTION' 42='(42) NEUROLOGICAL' 43='(43) OSTEOPOROSIS'
                  44='(44) ARTHRITIS AND DIABETES' 45='(45) STOMACH' 46='(46) BROKEN NECK'
                  47='(47) SMOKING' 48='(48) IRRITABLE BOWEL' 49='(49) HIPS'
                  50='(50) LEG PROBLEMS' 51='(51) BROKE PELVIS, FRACTURED HAND'
                  52='(52) PROTIRIA CARFANIA TARDA (PCT)' 53='(53) INJURY TO ARM'
                  54='(54) CARPAL TUNNEL SYNDROME' 55='(55) GALL BLADDER'
                  56='(56) ANKLE PROBLEMS' 57='(57) HYPOKEILMIC' 58='(58) PLEURISY'
                  59='(59) BROKE FINGER' 60='(60) CANCER' 61='(61) WEIGHT CONTROL'
                  62='(62) CANT WORK' 63='(63) ANOREXIA' 64='(64) CELLULITIS' 65='(65) M.S'
                  66='(66) POSITIVE LUPUS' 67='(67) SURGERY-BACK, KNEE & HAND'
                  68='(68) A VASCULA NECROSIS' 69='(69) THYROID LEVEL'
                  70='(70) BRAIN DAMAGE' 71='(71) SHORTNESS OF BREATH'
                  72='(72) BRAIN SURGERY' 73='(73) LUNG DISEASE' 74='(74) VERTIGO'
                  75='(75) HIGH RISK PREGNANCY' 76='(76) LOSS OF MEMORY' 77='(77) CATARACTS'
                  78='(78) DIARRHEA' 79='(79) SIGHT PROBLEMS' 80='(80) SKIN CONDITION'
                  81='(81) DTS' 82='(82) BROKEN ARM' 83='(83) IMMUNE DEFICIENCY'
                  84='(84) NAM WOUNDS' 85='(85) INSOMNIA' 86='(86) JUST SICK' 87='(87) PANCREAS'
                  88='(88) TEETH' 89='(89) FATIGUE' 90='(90) HYPOGLYCEMIA' 91='(91) HEAD INJURY'
                  92='(92) BONE DEFORMITY' 93='(93) SHOULDER' 94='(94) ECZEMA'
                  95='(95) TENDONITIS' 96='(96) HIGH ENZYMES' 97='(97) CROHNS DISEASE'
                  98='(98) STRESS' 99='(99) PARAPLEGIC' 100='(100) NECK/EYE NERVE DAMAGE'
                  101='(101) PAIN' 102='(102) BRAIN TUMOR' 103='(103) POLYPS ON THROAT'
                  104='(104) FIBROMYALGIA' 105='(105) RASH' 106='(106) TORN LIGAMENTS'
                  107='(107) NEUROPATHY-LEGS' 108='(108) CUT FINGER'
                  109='(109) WOUNDS FROM FIGHTING' 110='(110) BONE DISEASE'
                  111='(111) PELVIC INFECTION' 112='(112) HAND INJURY' ;
  VALUE fd81ioth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) CYLERT' 2='(2) DOXYCYCLINE' 3='(3) PROZAC' 4='(4) ZOLOFT'
                  5='(5) CARDIZEN' 6='(6) PEPCID' 7='(7) NEURONTIN' 8='(8) ACID' 9='(9) KLOPIN'
                  10='(10) IBUPROFEN' 11='(11) BENADRYL' 12='(12) FLEXERIL' 13='(13) DEPAKOTE'
                  14='(14) PROPRANOL' 15='(15) CLARITON' 16='(16) LUVOX' 17='(17) ANTABUSE'
                  18='(18) ROBITUSSIN' 19='(19) AMBIEN' 20='(20) WHIPPER' 21='(21) PREVENTIL'
                  22='(22) NYQUIL' 23='(23) REMERON' 24='(24) PRESCRIBED MEDS' 25='(25) ANACIN'
                  26='(26) BIPOLAR MEDICATION' 27='(27) VASOTEC' 28='(28) PARVAN'
                  29='(29) TEGRETOL' 30='(30) DESIPRAMINE' 31='(31) AMITRYPTYLINE'
                  32='(32) DESYRIL' 33='(33) AIDS/HIV DRUG' 34='(34) PREVICID' 35='(35) BUSPAR'
                  36='(36) TYLENOL' 37='(37) NYTOL' 38='(38) THERAFLU'
                  39='(39) FOR HEART DISEASE' 40='(40) PRILOSEC' 41='(41) NASACORT'
                  42='(42) BENADRYL' 43='(43) COLD MED' 44='(44) CUMIDIN' 45='(45) CIMITRIL'
                  46='(46) EUBRIUM' 47='(47) VITAMINS' 48='(48) PROCARDIA' 49='(49) CULAZAN'
                  50='(50) SULFADIAZINE' 51='(51) ASTHMA CORT' 52='(52) SINUS MED'
                  53='(53) PREDNISONE' 54='(54) AZT' 55='(55) MEDIPRES'
                  56='(56) PSEUDO PINPHETIDINE' 57='(57) ZESTRIL' 58='(58) MUSCLE RELAXER'
                  59='(59) REZOLIN' 60='(60) VICAND' 61='(61) ARTHRITIS MEDICATION'
                  62='(62) ANTIBIOTIC' 63='(63) CALAN' 64='(64) PROCARDICE' 65='(65) RR'
                  66='(66) KETOPROFEN' 67='(67) PAIN KILLERS' 68='(68) HYDROCORTHIZER'
                  69='(69) GLYBURIDE' 70='(70) PAIN & BACK PAIN MEDICINE'
                  71='(71) LORACAPOM' 72='(72) INSULIN' 73='(73) WELLBURTIN' 74='(74) DIALANTIN'
                  75='(75) GLUCOPHAGE' 76='(76) PANCOF' 77='(77) COUGH SUPPRESSANT'
                  78='(78) GLIPIZIDE' 79='(79) ERYTHROMYCIN' 80='(80) ASACOL' 81='(81) KYZAC'
                  82='(82) NOPROXEN' 83='(83) ANTIDEPRESSANTS' 84='(84) FUROSENIDE'
                  85='(85) CLONODINE' 86='(86) PROVACET' 87='(87) MEDS' 88='(88) ZYBAN'
                  89='(89) KLONINE' 90='(90) ECSTACY' 91='(91) INTERFERON' 92='(92) EFFECTXOR'
                  93='(93) OLANZIPINE' 94='(94) COLOPINE' 95='(95) LITHIUM' 96='(96) RISPERDAL'
                  97='(97) SLAMM' 98='(98) PAXIL' 99='(99) CLAUDIPINS'
                  100='(100) DIABETES MEDICATION' 101='(101) STEROID' 102='(102) KEFLEX'
                  103='(103) BACTRIM' 104='(104) THYROID MEDICATION' 105='(105) ALLEUL'
                  106='(106) LODINE' 107='(107) ZYPREHA' 108='(108) DILTIAZEM' 109='(109) TRAZODONE'
                  110='(110) SARAGRIL' 111='(111) HIGH CHOLESTEROL MEDICATION'
                  112='(112) PHENTERMINE' 113='(113) CLONAZAPAN' 114='(114) CLOZERAL'
                  115='(115) CHOLOPHEN' 116='(116) ULTRANX' 117='(117) GLOUCONTRO CARDIZAM'
                  118='(118) MELLARIL' 119='(119) ATENOLOL' 120='(120) MOTRIN' 121='(121) GLUCOPHASE'
                  122='(122) IODINE' 123='(123) BLOOD PRESSURE MEDICINE' 124='(124) MAX-ALERT'
                  125='(125) LAAM' 126='(126) ANTI-INFLAMMATORY' 127='(127) ASPIRIN'
                  128='(128) MULTIPLE DRUGS LISTED' ;
  VALUE fc23ffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) COMPLETED THE TX PLAN OR GRADUATED FROM'
                  2='(2) DROPPED FROM PROGRAM BY STAFF BECAUSE OF'
                  3='(3) DROPPED FROM PROGRAM BECAUSE YOUR INSURA'
                  4='(4) DID NOT WANT TO BE THERE IN THE FIRST PL'
                  5='(5) FELT THAT THE TREATMENT WAS NOT WORKING'
                  6='(6) TRANSFERRED TO OTHER PROGRAM BECAUSE YOU'
                  7='(7) WERE NO LONGER ELIGIBLE' 8='(8) WENT TO JAIL OR PRISON'
                  9='(9) TOO DIFFICULT TO GET THERE/CHILD CARE PR'
                  10='(10) YOU COULDNT AFFORD IT'
                  11='(11) THERE WAS PRESSURE FROM FAMILY/FRIENDS T'
                  12='(12) YOU LEFT THE AREA' 13='(13) TOO SICK'
                  14='(14) HEALTH RELATED PROBLEMS NOT HANDLED'
                  16='(16) ARRESTED, NOT IMPRISONED'
                  17='(17) DISSATISFIED OR WANTED DIFFERENT TREATME'
                  18='(18) HOSPITALIZED FOR HIGH BLOOD PRESSURE'
                  19='(19) STOPPED USING, GOT JOB BACK' 20='(20) RELIGIOUS BELIEFS'
                  21='(21) PRESSURE FROM DR' 22='(22) HEALTH'
                  23='(23) DIDN''T GO/DIDN''T HAVE TIME' 24='(24) REFERRAL'
                  25='(25) LAWYER GOT HIM OUT OF GOING BACK TO CLAS'
                  26='(26) WAS TOLD DIDN''T HAVE PROBLEM'
                  27='(27) COMPLETED COURT REQUIREMENT/COURT ORDERE'
                  28='(28) TRANSFERRED TO ANOTHER COMPANY' 29='(29) WENT ONE DAY'
                  30='(30) TRANSFER TO DIFFERENT PROGRAM (NO REASON'
                  31='(31) WENT TO COURT, CHARGES DISMISSED'
                  32='(32) GOT OUT OF IT WHAT I NEED' 33='(33) JUST OUT OF IT'
                  34='(34) STILL IN PROGRAM' 35='(35) NO CLOTHES TO WEAR'
                  36='(36) TOO MUCH TIME' 37='(37) PROVIDED GROUP COUNSELING'
                  38='(38) RELAPSE' 39='(39) NONE' 40='(40) STOPPED GOING'
                  41='(41) WORKED ON HELPING HIMSELF W/WIFES MENTA'
                  42='(42) WANTED TO EXTEND PROGRAM' 43='(43) CONTINUED LATER'
                  44='(44) MOTHER BECAME ILL' 45='(45) LOST DOCTOR' 46='(46) NOT SURE'
                  47='(47) GOT TIRED, STOP USING' 48='(48) RELEASED FROM JAIL'
                  49='(49) TOO BUSY' 50='(50) HELP MYSELF' 51='(51) TAKE CARE OF FATHER'
                  52='(52) TO LIBERATE MY LIFE' 53='(53) MEDICAL REASONS'
                  54='(54) PAROLE OR PROBATION WAS OVER' 55='(55) TO COME HOME'
                  56='(56) DIDN''T GET IN' 57='(57) DEPRESSED' 58='(58) MISSED CHILDREN'
                  59='(59) STIPULATED FOR 90 DAYS, SO STOPPED' ;
  VALUE fc29ooth  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) RECOGNIZE PROBLEM' 2='(2) BE MORE CONSISTENT'
                  3='(3) DECIDE NOT TO DRINK/DRIVE' 4='(4) WITH SEXUAL ISSUES'
                  5='(5) MET SOME GOOD PEOPLE' 6='(6) OPEN JOURNEYS'
                  7='(7) ONE COUNSELOR' 8='(8) LEARN NEW LAWS'
                  9='(9) CHANCE TO SEE MYSELF' 10='(10) BALANCED LIFE'
                  11='(11) DIDN''T GO AT ALL/NEVER WENT' 12='(12) GAIN SELF RESPECT'
                  13='(13) RECOMMENDED A STAY AT LOCATION' 14='(14) IM NOT ALONE'
                  15='(15) OVERALL OUTLOOK/ATTITUDE/ACCEPTANCE/AWAR'
                  16='(16) GET INTO ANOTHER TREATMENT PROGRAM'
                  17='(17) OTHER ADDICTION ISSUES' 18='(18) SELF PROCLAIMED DEALER'
                  19='(19) LEARNING SOMETHING IS ALWAYS GOOD'
                  20='(20) RECOGNIZING MY FEELINGS' 21='(21) WITH PERSONAL LIFE'
                  22='(22) GOOD LECTURES' 23='(23) UNDERSTAND PROBLEM W/SELLING DRUGS'
                  24='(24) HOW TO LIVE LIFE' 25='(25) TAUGHT ME TO GROW UP'
                  26='(26) SPIRITUALITY/RELIGION' 27='(27) DETOX FROM METH'
                  28='(28) MADE CLEAN AND SOBER FRIENDS THERE' 29='(29) BETTER FUTURE'
                  30='(30) STABILIZING' 31='(31) TO GO TO DETOX' 32='(32) PLOWED ME DOWN'
                  33='(33) KEPT ME OUT OF TROUBLE' 34='(34) KEPT ME FROM DYING'
                  35='(35) IT HELPS' 36='(36) NOTHING AT ALL'
                  37='(37) ADULT CHILD OF ALCOHOLICS' 38='(38) BE MORE SANE'
                  39='(39) MORE ACTIVE' 40='(40) LOSS OF PARENT' 41='(41) MADE ME SICK'
                  42='(42) PROVIDING BACK UP' 43='(43) MANY DIFFERENT WAYS'
                  44='(44) RESIDENTIAL REHAB'
                  45='(45) CUT OFF BAD INFLUENCES WITH FRIENDS'
                  46='(46) EDUCATION/KNOWLEDGE OF ADDICTION'
                  47='(47) GET IN TOUCH W/ NATIVE AMREICAN ANCESTRY'
                  48='(48) LEFT BAD RELATIONSHIP' 49='(49) PROFESSIONAL BALANCE'
                  50='(50) SKILLS TO SURVIVE' 51='(51) BETTER RELATIONSHIPS'
                  52='(52) GET ON SOCIAL SERVICES' 53='(53) STAY OFF STREETS'
                  54='(54) SAVED MY LIFE' 55='(55) SMOKED TOO MUCH MARIJUANA'
                  56='(56) MORALS SUPPORT' 57='(57) REFERRED TO MALVERN'
                  58='(58) DISCIPLINE' 59='(59) DEALING WITH LIFE' 60='(60) DEAL W/PROBLEMS'
                  61='(61) RELAXATION' 62='(62) RELAPSE' 63='(63) DETOX'
                  64='(64) COUNSELOR BEING THERE' 65='(65) UNDERSTAND MOMS PROBLEMS'
                  66='(66) NOT WORRIED ABOUT GETTING DRUGS'
                  67='(67) SOMEONE TO TALK TO' 68='(68) IT WAS ALL GOOD'
                  69='(69) PREPARE FOR ANOTHER PROGRAM'
                  70='(70) UNDERSTAND PSYCHOLOGICAL NEEDS'
                  71='(71) AN EFFORT TO GRADUATE'
                  72='(72) RECOMMENDATIONS TO OTHER CLINICS' ;
  VALUE fdaysdcg  -7='(-7) NOT ASCERTAINED' ;
  VALUE f_nexttx  -9='(-9) CLIENTS STILL IN TREATMENT' -7='(-7) NOT ASCERTAINED' ;
  VALUE f_ageint  -7='(-7) NOT ASCERTAINED' ;
  VALUE a73fffff  -9='(-9) INAPPLICABLE IN-TX METH CLIENT STILL IN' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) CLIENT DECEASED'
                  1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TX REFERRED/TRANSFERRED'
                  3='(3) DID NOT COMPLETE TX INSURANCE BENEFITS E'
                  4='(4) DID NOT COMPLETE TX NO PAYMENT SOURCE'
                  5='(5) DID NOT COMPLETE TX BY ADMINISTRATION CH'
                  6='(6) DID NOT COMPLETE TX BY CLIENT CHOICE'
                  7='(7) DID NOT COMPLETE TX INCARCERATED'
                  8='(8) DID NOT COMPLETE TX NOT OTHERWISE SPECIF'
                  9='(9) PENDING COMPLETION OF ASSIGNMENT'
                  10='(10) MUTUAL AGREEMENT TO TERMINATE'
                  11='(11) LAWYER TERMINATED THERAPY, COURT TERMINA'
                  12='(12) TREATMENT NEVER STARTED'
                  13='(13) PROBLEMS WITH TRANSPORTATION' 14='(14) EVALUATION ONLY'
                  15='(15) ARRESTED' 16='(16) MOVED AWAY'
                  17='(17) DROP OUT, PHYSICAL ILLNESS (E.G., CANCER'
                  18='(18) REFERRED TO NON-SA TREATMENT'
                  19='(19) MEDICALLY DISCHARGE AFTERCARE' 20='(20) HAVING A BABY' ;
  VALUE age_calc  -7='(-7) NOT ASCERTAINED' ;
  VALUE los       -7='(-7) NOT ASCERTAINED' ;
  VALUE trt_dur   -7='(-7) NOT ASCERTAINED' ;
  VALUE alcohol   0='(0) ALCOHOL USE NOT MENTIONED IN CLIENT RECO'
                  1='(1) ALCOHOL USE MENTIONED IN CLIENT RECORD' ;
  VALUE drug      0='(0) DRUG USE NOT MENTIONED IN CLIENT RECORD'
                  1='(1) DRUG USE MENTIONED IN CLIENT RECORD' ;
  VALUE drug_alc  1='(1) ALCOHOL USE ONLY MENTIONED IN CLIENT REC'
                  2='(2) BOTH ALCOHOL AND DRUG USE MENTIONED IN C'
                  3='(3) DRUG USE ONLY MENTIONED IN CLIENT RECORD'
                  4='(4) UNSPECIFIED SUB USE/NO MENTION OF WHICH' ;
  VALUE txcare    1='(1) M-OUTPATIENT METHADONE' 2='(2) N-OUTPATIENT NON-METHADONE'
                  3='(3) R-NON-HOSPITAL RESIDENTIAL' ;
  VALUE abssmpty  1='(1) EARLY DROPOUT' ;
  VALUE qfstrat   2='(2) STRATUM 2: RESIDENTIAL'
                  3='(3) STRATUM 3: PREDOMINANTLY OUTPATIENT MET'
                  4='(4) STRATUM 4: OP NON-METH-PREDOM ALC-N'
                  5='(5) STRATUM 5: OP NON-METH-NOT IN STRATUM'
                  6='(6) STRATUM 6: COMBINATION' ;
  VALUE group     0='(0) CLIENT SELECTED TO RECEIVE $15/$10 FOR F'
                  1='(1) CLIENT SELECTED TO RECEIVE $0/$0 FOR FOL'
                  2='(2) CLIENT SELECTED TO RECEIVE $0/$10 FOR FO'
                  3='(3) CLIENT SELECTED TO RECEIVE $25/$10 FOR F' ;
  VALUE u_mrj_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_pcp_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_amp_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE FOR AMPHETAMINES' 1='(1) POSITIVE FOR AMPHETAMINES' ;
  VALUE u_ben_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE FOR BENZODIAZEPINES'
                  1='(1) POSITIVE FOR BENZODIAZEPINES' ;
  VALUE u_coc_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_met_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_opi_sm  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE FOR OPIATES'
                  1='(1) POSITIVE FOR AT LEAST ONE OPIATE' ;
  VALUE u_alcf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_mrjf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_pcpf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_ampf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_ampf2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf3f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf4f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf5f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf6f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf7f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_benf8f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_cocf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_metf1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_opif1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_opif2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_opif3f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_opif4f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' 0='(0) NEGATIVE'
                  1='(1) POSITIVE' ;
  VALUE u_amlid   -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  31649463='(31649463) CHAIN OF CUSTODY DOCUMENT CONTROL NUMBER' ;
  VALUE u_creatn  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_ph      -5='(-5) MISSING' ;
  VALUE u_mrjv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_pcpv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_ampv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_ampv2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv3f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv4f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv5f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv6f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv7f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_benv8f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_cocv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_metv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_opiv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_opiv2f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_opiv3f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_opiv4f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_alcv1f  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_nitrit  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE (ACCEPTABLE)' 1='(1) POSITIVE' ;
  VALUE u_anypos  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE FOR ALCOHOL AND ALL OTHER DRUGS'
                  1='(1) POSITIVE FOR EITHER ALCOHOL OR AT LEAST' ;
  VALUE u_anydrg  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  0='(0) NEGATIVE FOR ALL DRUGS OTHER THAN ALCOHO'
                  1='(1) CONFIRMED POSITIVE FOR AT LEAST ONE DRUG' ;
  VALUE u_numdrg  -9='(-9) SKIPPED APPROPRIATELY POSITIVE' -5='(-5) MISSING' ;
  VALUE u_dtdiff  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING' ;
  VALUE u_result  -9='(-9) SKIPPED APPROPRIATELY' -5='(-5) MISSING'
                  1='(1) URINE SAMPLE COLLECTED-VALID RESULTS A'
                  2='(2) NO RESULTS SPECIMEN COLLECTED NO SIGNED'
                  3='(3) NO RESULTS SPECIMEN SUBMITTED LAB REPORT'
                  4='(4) NO RESULTS SPECIMEN SUBMITTED NOT USABLE'
                  5='(5) NO RESULTS NO SPECIMEN COLLECTED' ;
  VALUE fb33ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fb38ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fc13ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fc16ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE fd31ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1875;
INPUT
        CASEID 1-4              FOUTCOME 5-6            F_CT 7-8
        FA1 9-10                FA3 11-12               FA4 13-14
        FA5 15-16               FA6 17-18               FA7 19-20
        FA8 21-22               FA9 23-24               FA10 25-26
        FA11 27-28              FA12 29-30              FA12A 31-32
        FA13 33-34              FA14 35-36              FA15 37-38
        FA16 39-40              FA17 41-42              FA18 43-44
        F_LANG 45-46            FB1A 47-48              FB2A 49-50
        FB3A 51-52              FB4A 53-54              FB1B 55-56
        FB2B 57-58              FB3B 59-60              FB4B 61-62
        FB1C 63-64              FB2C 65-66              FB3C 67-68
        FB4C 69-70              FB1D 71-72              FB2D 73-74
        FB3D 75-76              FB4D 77-78              FB1E 79-80
        FB2E 81-82              FB3E 83-84              FB4E 85-86
        FB1F 87-88              FB2F 89-90              FB3F 91-92
        FB4F 93-94              FB1G 95-96              FB2G 97-98
        FB3G 99-100             FB4G 101-102            FB1H 103-104
        FB2H 105-106            FB3H 107-108            FB4H 109-110
        FB1I 111-112            FB2I 113-114            FB3I 115-116
        FB4I 117-118            FB1J 119-120            FB2J 121-122
        FB3J 123-124            FB4J 125-126            FB1K 127-128
        FB2K 129-130            FB3K 131-132            FB4K 133-134
        FB1L 135-136            FB2L 137-138            FB3L 139-140
        FB4L 141-142            FB1M 143-144            FB1MOTH 145-146
        FB2M 147-148            FB3M 149-150            FB4M 151-152
        FB5 153-154             FB6 155-156             FB7 157-158
        FB8 159-160             FB9 161-162             FB9A 163-164
        FB10 165-166            FB11 167-168            FB12A 169-170
        FB13A 171-172           FB12B 173-174           FB13B 175-176
        FB12C 177-178           FB13C 179-180           FB14 181-182
        FB15 183-184            FB16 185-186            FB17 187-188
        FB18 189-190            FB19 191-192            FB20 193-194
        FB21 195-196            FB22 197-198            FB23 199-200
        FB24 201-202            FB25 203-204            FB26 205-206
        FB27A 207-208           FB27B 209-210           FB27C 211-212
        FB27D 213-214           FB27E 215-216           FB27F 217-218
        FB27G 219-220           FB28 221-222            FB29 223-224
        FB30 225-226            FB31 227-228            FB32 229-230
        FB33A 231-232           FB33AOTH 233-234        FB34 235-236
        FB34A 237-238           FB35 239-240            FB36 241-242
        FB37 243-244            FB38A 245-246           FB38AOTH 247-248
        FB39 249-250            FB40 251-252            FB41 253-254
        FB42A 255-256           FB42B 257-258           FB42C 259-260
        FB42D 261-262           FB42E 263-264           FB42F 265-266
        FB42G 267-268           FB42H 269-270           FB42I 271-272
        FB42J 273-274           FB42K 275-276           FB42L 277-278
        FB43 279-280            FB44 281-282            FB44A 283-284
        FB44B 285-286           FB45 287-288            FB46A 289-290
        FB47A 291-292           FB46B 293-294           FB47B 295-297
        FB46C 298-299           FB47C 300-302           FB46D 303-304
        FB47D 305-307           FB46E 308-309           FB47E 310-311
        FB46F 312-313           FB47F 314-315           FB46G 316-317
        FB47G 318-320           FB46H 321-322           FB47H 323-324
        FB48A 325-326           FB49A 327-328           FB48B 329-330
        FB49B 331-332           FB48C 333-334           FB49C 335-336
        FB48D 337-338           FB49D 339-340           FB48E 341-342
        FB49E 343-344           FB48F 345-346           FB49F 347-348
        FB48G 349-350           FB49G 351-352           FB48H 353-354
        FB49H 355-356           FB50A 357-358           FB50B 359-360
        FB50C 361-362           FB50D 363-364           FB51A 365-366
        FB52A 367-368           FB53A 369-370           FB51B 371-372
        FB52B 373-374           FB53B 375-376           FB51C 377-378
        FB52C 379-380           FB53C 381-382           FB51D 383-384
        FB52D 385-386           FB53D 387-388           FB54 389-390
        FB55 391-392            FB56 393-394            FB57 395-396
        FB58 397-398            FB59 399-400            FB60 401-402
        FB61 403-404            FB62 405-406            FB63 407-408
        FB64A 409-410           FB65A 411-412           FB64B 413-414
        FB65B 415-416           FB64C 417-418           FB65C 419-420
        FB64D 421-422           FB65D 423-424           FB64E 425-426
        FB65E 427-428           FB64F 429-430           FB65F 431-432
        FB64G 433-434           FB65G 435-436           FB64H 437-438
        FB65H 439-440           FB64I 441-442           FB65I 443-444
        FB64J 445-446           FB65J 447-448           FB64K 449-450
        FB65K 451-452           FB64L 453-454           FB65L 455-456
        FB64M 457-458           FB65M 459-460           FB66 461-462
        FB67 463-464            FB68 465-466            FB69 467-468
        FB70 469-470            FB71 471-472            FB72 473-474
        FB73 475-476            FB74 477-478            FB75 479-480
        FB76 481-482            FB77A 483-484           FB77B 485-486
        FB77C 487-488           FB78 489-490            FB78A 491-492
        FB79 493-494            FB80 495-496            FB81A 497-498
        FB82A 499-500           FB83A 501-502           FB84A 503-504
        FB85A 505-506           FB81B 507-508           FB82B 509-510
        FB83B 511-512           FB84B 513-514           FB85B 515-516
        FB81C 517-518           FB82C 519-520           FB83C 521-522
        FB84C 523-524           FB85C 525-526           FB81D 527-528
        FB82D 529-530           FB83D 531-532           FB84D 533-534
        FB85D 535-536           FB81E 537-538           FB82E 539-540
        FB83E 541-542           FB84E 543-544           FB85E 545-546
        FB81F 547-548           FB82F 549-550           FB83F 551-552
        FB84F 553-554           FB85F 555-556           FB81G 557-558
        FB82G 559-560           FB83G 561-562           FB84G 563-564
        FB85G 565-566           FB81H 567-568           FB82H 569-570
        FB83H 571-572           FB84H 573-574           FB85H 575-576
        FB81I 577-578           FB82I 579-580           FB83I 581-582
        FB84I 583-584           FB85I 585-586           FB81J 587-588
        FB82J 589-590           FB83J 591-592           FB84J 593-594
        FB85J 595-596           FB82K 597-598           FB83K 599-600
        FB84K 601-602           FB85K 603-604           FB81L 605-606
        FB82L 607-608           FB83L 609-610           FB84L 611-612
        FB85L 613-614           FB81M 615-616           FB82M 617-618
        FB83M 619-620           FB84M 621-622           FB85M 623-624
        FB81N 625-626           FB81NOTH 627-628        FB82N 629-630
        FB83N 631-632           FB84N 633-634           FB85N 635-636
        FB86 637-638            FB87 639-641            FB88 642-643
        FB89 644-645            FB90 646-647            FB91 648-650
        FB91U 651-652           FB92 653-654            FB93 655-656
        FB93U 657-658           FB94 659-660            FB95 661-662
        FB95A 663-664           FC1 665-666             FC2 667-668
        FC3 669-670             FC4 671-672             FC5 673-674
        FC6 675-676             FC6A 677-678            FC7A 679-680
        FC7B 681-682            FC7C 683-684            FC7D 685-686
        FC7E 687-688            FC7F 689-690            FC8 691-692
        FC8A 693-694            FC9 695-696             FC10 697-698
        FC11 699-700            FC11U 701-702           FC12 703-704
        FC13A 705-706           FC13AOTH 707-708        FC14 709-710
        FC15 711-712            FC15U 713-714           FC16A 715-716
        FC16AOTH 717-718        FC17 719-720            FC18 721-722
        FC19 723-725            FC20 726-727            FC21 728-729
        FC22 730-731            FC24A 732-733           FC25A 734-735
        FC24B 736-737           FC25B 738-739           FC24C 740-741
        FC25C 742-743           FC24D 744-745           FC25D 746-747
        FC24E 748-749           FC25E 750-751           FC24F 752-753
        FC25F 754-755           FC24G 756-757           FC25G 758-759
        FC24H 760-761           FC25H 762-763           FC24I 764-765
        FC25I 766-767           FC24J 768-769           FC25J 770-771
        FC24K 772-773           FC25K 774-775           FC24L 776-777
        FC25L 778-779           FC24M 780-781           FC25M 782-783
        FC24N 784-785           FC25N 786-787           FC24O 788-789
        FC25O 790-791           FC24P 792-793           FC25P 794-795
        FC24Q 796-797           FC25Q 798-799           FC24R 800-801
        FC25R 802-803           FC24S 804-805           FC25S 806-807
        FC24T 808-809           FC25T 810-811           FC26 812-813
        FC27 814-815            FC28 816-817            FC29A 818-819
        FC29B 820-821           FC29C 822-823           FC29D 824-825
        FC29E 826-827           FC29F 828-829           FC29G 830-831
        FC29H 832-833           FC29I 834-835           FC29J 836-837
        FC29K 838-839           FC29L 840-841           FC29M 842-843
        FC29N 844-845           FC29O 846-847           FC30A 848-849
        FC30B 850-851           FC30C 852-853           FC30D 854-855
        FC30E 856-857           FC30EOTH 858-859        FC31A 860-861
        FC32A 862-863           FC33A 864-865           FC31B 866-867
        FC32B 868-869           FC33B 870-871           FC31C 872-873
        FC32C 874-875           FC33C 876-877           FC31D 878-879
        FC32D 880-881           FC33D 882-883           FC34 884-885
        FC35 886-887            FC35OTH 888-889         FC36 890-891
        FC37 892-893            FC38 894-895            FC39 896-897
        FC40 898-899            FC41 900-901            FC42 902-903
        FC43 904-905            FC44 906-907            FC45 908-909
        FC46 910-911            FC47 912-913            FC48 914-915
        FC49 916-917            FC50 918-919            FC51 920-921
        FC52 922-923            FC53 924-925            FC54 926-927
        FC55 928-929            FC56 930-931            FC57 932-933
        FC58 934-935            FC58U 936-937           FC59 938-939
        FC60A 940-941           FC60B 942-943           FC60C 944-945
        FC60D 946-947           FC60E 948-949           FC60F 950-951
        FC61A 952-953           FC61B 954-955           FC61C 956-957
        FC61D 958-959           FC61E 960-961           FC61F 962-963
        FC61G 964-965           FC61H 966-967           FC61I 968-969
        FC61J 970-971           FC61JOTH 972-973        FC61MAIN 974-975
        FC62A 976-977           FC62B 978-979           FC62C 980-981
        FC62D 982-983           FC62E 984-985           FC62F 986-987
        FC62G 988-989           FC62H 990-991           FC62I 992-993
        FC62J 994-995           FC62K 996-997           FC62L 998-999
        FD1A 1000-1001          FD2A 1002-1003          FD3A 1004-1005
        FD4A 1006-1007          FD1B 1008-1009          FD2B 1010-1011
        FD3B 1012-1013          FD4B 1014-1015          FD1C 1016-1017
        FD2C 1018-1019          FD3C 1020-1021          FD4C 1022-1023
        FD1D 1024-1025          FD2D 1026-1027          FD3D 1028-1029
        FD4D 1030-1031          FD1E 1032-1033          FD2E 1034-1035
        FD3E 1036-1037          FD4E 1038-1039          FD1F 1040-1041
        FD2F 1042-1043          FD3F 1044-1045          FD4F 1046-1047
        FD1G 1048-1049          FD2G 1050-1051          FD3G 1052-1053
        FD4G 1054-1055          FD1H 1056-1057          FD2H 1058-1059
        FD3H 1060-1061          FD4H 1062-1063          FD1I 1064-1065
        FD2I 1066-1067          FD3I 1068-1069          FD4I 1070-1071
        FD1J 1072-1073          FD2J 1074-1075          FD3J 1076-1077
        FD4J 1078-1079          FD1K 1080-1081          FD2K 1082-1083
        FD3K 1084-1085          FD4K 1086-1087          FD1L 1088-1089
        FD2L 1090-1091          FD3L 1092-1093          FD4L 1094-1095
        FD1M 1096-1097          FD1MOTH1 1098-1099      FD2MOTH1 1100-1101
        FD3MOTH1 1102-1103      FD4MOTH1 1104-1105      FD1MOTH2 1106-1107
        FD2MOTH2 1108-1109      FD3MOTH2 1110-1111      FD4MOTH2 1112-1113
        FD1MOTH3 1114-1115      FD2MOTH3 1116-1117      FD3MOTH3 1118-1119
        FD4MOTH3 1120-1121      FD5 1122-1123           FD6 1124-1128
        FD7 1129-1130           FD8 1131-1132           FD9 1133-1134
        FD10 1135-1136          FD11 1137-1138          FD12A 1139-1140
        FD13A 1141-1142         FD12B 1143-1144         FD13B 1145-1146
        FD12C 1147-1148         FD13C 1149-1150         FD14 1151-1152
        FD15 1153-1154          FD16 1155-1156          FD17 1157-1158
        FD18 1159-1160          FD19 1161-1162          FD20 1163-1164
        FD21 1165-1166          FD23A 1167-1168         FD23B 1169-1170
        FD23C 1171-1172         FD23D 1173-1174         FD23E 1175-1176
        FD23F 1177-1178         FD23G 1179-1180         FD24 1181-1182
        FD25 1183-1184          FD26 1185-1186          FD27 1187-1188
        FD28A 1189-1190         FD28AOTH 1191-1192      FD29 1193-1194
        FD30 1195-1196          FD31A 1197-1198         FD31AOTH 1199-1200
        FD32A 1201-1202         FD32B 1203-1204         FD32C 1205-1206
        FD32D 1207-1208         FD32E 1209-1210         FD32F 1211-1212
        FD32G 1213-1214         FD32H 1215-1216         FD32I 1217-1218
        FD32J 1219-1220         FD32K 1221-1222         FD32L 1223-1224
        FD33A 1225-1226         FD33B 1227-1228         FD33C 1229-1230
        FD33D 1231-1232         FD33E 1233-1234         FD33F 1235-1236
        FD34A 1237-1238         FD34B 1239-1240         FD34C 1241-1242
        FD34D 1243-1244         FD34E 1245-1246         FD35 1247-1248
        FD37A 1249-1250         FD38A 1251-1252         FD37B 1253-1254
        FD38B 1255-1256         FD37C 1257-1258         FD38C 1259-1260
        FD37D 1261-1262         FD38D 1263-1264         FD37E 1265-1266
        FD38E 1267-1268         FD37F 1269-1270         FD38F 1271-1272
        FD37G 1273-1274         FD38G 1275-1276         FD37H 1277-1278
        FD38H 1279-1280         FD39A 1281-1282         FD40A 1283-1284
        FD41A 1285-1286         FD39B 1287-1288         FD40B 1289-1290
        FD41B 1291-1292         FD39C 1293-1294         FD40C 1295-1296
        FD41C 1297-1298         FD39D 1299-1300         FD40D 1301-1302
        FD41D 1303-1304         FD42 1305-1306          FD42A 1307-1308
        FD42B 1309-1310         FD42C 1311-1312         FD42D 1313-1314
        FD42E 1315-1316         FD42F 1317-1318         FD42G 1319-1320
        FD42H 1321-1322         FD42I 1323-1324         FD43 1325-1326
        FD44 1327-1328          FD45 1329-1330          FD46 1331-1332
        FD47 1333-1334          FD48 1335-1336          FD49A 1337-1338
        FD49B 1339-1340         FD49C 1341-1342         FD49D 1343-1344
        FD49E 1345-1346         FD49F 1347-1348         FD49G 1349-1350
        FD49H 1351-1352         FD49I 1353-1354         FD49J 1355-1356
        FD49K 1357-1358         FD49L 1359-1360         FD49M 1361-1362
        FD50 1363-1364          FD51 1365-1366          FD54 1367-1368
        FD55 1369-1370          FD56 1371-1372          FD57 1373-1374
        FD58 1375-1376          FD59 1377-1378          FD60 1379-1380
        FD61A 1381-1382         FD61B 1383-1384         FD61C 1385-1386
        FD62 1387-1388          FD63 1389-1390          FD64 1391-1392
        FD65 1393-1394          FD66 1395-1396          FD67 1397-1398
        FD68A 1399-1400         FD69A 1401-1402         FD68B 1403-1404
        FD69B 1405-1406         FD68C 1407-1408         FD69C 1409-1410
        FD68D 1411-1412         FD69D 1413-1414         FD68E 1415-1416
        FD69E 1417-1418         FD68F 1419-1420         FD69F 1421-1422
        FD68G 1423-1424         FD69G 1425-1426         FD68H 1427-1428
        FD69H 1429-1430         FD68I 1431-1432         FD69I 1433-1434
        FD68J 1435-1436         FD69J 1437-1438         FD68K 1439-1440
        FD69K 1441-1442         FD68L 1443-1444         FD69L 1445-1446
        FD68M 1447-1448         FD69M 1449-1450         FD68N 1451-1452
        FD68NOTH 1453-1454      FD69N 1455-1456         FD70 1457-1458
        FD71 1459-1460          FD72 1461-1462          FD73 1463-1464
        FD74 1465-1466          FD75 1467-1469          FD75U 1470-1471
        FD76 1472-1473          FD77 1474-1475          FD78 1476-1477
        FD79 1478-1479          FD80 1480-1483          FD81A 1484-1485
        FD82A 1486-1487         FD83A 1488-1489         FD81B 1490-1491
        FD82B 1492-1493         FD83B 1494-1495         FD81C 1496-1497
        FD82C 1498-1499         FD83C 1500-1501         FD81D 1502-1503
        FD82D 1504-1505         FD83D 1506-1507         FD81E 1508-1509
        FD82E 1510-1511         FD83E 1512-1513         FD81F 1514-1515
        FD82F 1516-1517         FD83F 1518-1519         FD81G 1520-1521
        FD82G 1522-1523         FD83G 1524-1525         FD81H 1526-1527
        FD82H 1528-1529         FD83H 1530-1531         FD81I 1532-1533
        FD82I 1534-1535         FD83I 1536-1537         FD84A 1538-1539
        FD84B 1540-1541         FD84C 1542-1543         FD84D 1544-1545
        FD84E 1546-1547         FD84F 1548-1549         FD84G 1550-1551
        FB2CFLG 1552-1553       FB2FFLG 1554-1555       FB2KFLG 1556-1557
        FB82AFLG 1558-1559      FB82BFLG 1560-1561      FB82CFLG 1562-1563
        FB82DFLG 1564-1565      FB82EFLG 1566-1567      FB82FFLG 1568-1569
        FB82GFLG 1570-1571      FB82HFLG 1572-1573      FB82IFLG 1574-1575
        FB82JFLG 1576-1577      FB82KFLG 1578-1579      FB82LFLG 1580-1581
        FB82MFLG 1582-1583      FB82NFLG 1584-1585      FB88AFLG 1586-1587
        FD36FLG 1588-1589       FD3BFLG 1590-1591       FD3CFLG 1592-1593
        FD3DFLG 1594-1595       FD3EFLG 1596-1597       FD3FFLG 1598-1599
        FD3GFLG 1600-1601       FD3IFLG 1602-1603       FD38BFLG 1604-1605
        FD38CFLG 1606-1607      FD38DFLG 1608-1609      FD38FFLG 1610-1611
        FD38GFLG 1612-1613      FD38HFLG 1614-1615      FD5FLG 1616-1617
        FD26FLG 1618-1619       FD30FLG 1620-1621       FD40AFLG 1622-1623
        FD40BFLG 1624-1625      FD40CFLG 1626-1627      FD40DFLG 1628-1629
        FB64MOTH 1630-1632      FC7FOTH1 1633-1635      FC7FOTH2 1636-1638
        FC7FOTH3 1639-1641      FD49MOTH 1642-1644      FD81IOTH 1645-1647
        FC23 1648-1649          FC29OOTH 1650-1651      FDAYSDCG 1652-1654
        F_NEXTTX 1655-1657      F_AGEINT 1658-1659      A73 1660-1661
        FACID 1662-1665         AGE_CALC 1666-1667      LOS 1668-1670
        TRT_DUR 1671-1672       ALCOHOL 1673-1674       DRUG 1675-1676
        DRUG_ALC 1677-1678      TXCARE 1679-1680        ABSSMPTY 1681-1682
        QFSTRAT 1683-1684       GROUP 1685-1686         FIELDPSU 1687-1688
        U_MRJ_SM 1689-1690      U_PCP_SM 1691-1692      U_AMP_SM 1693-1694
        U_BEN_SM 1695-1696      U_COC_SM 1697-1698      U_MET_SM 1699-1700
        U_OPI_SM 1701-1702      U_ALCF1 1703-1704       U_MRJF1 1705-1706
        U_PCPF1 1707-1708       U_AMPF1 1709-1710       U_AMPF2 1711-1712
        U_BENF1 1713-1714       U_BENF2 1715-1716       U_BENF3 1717-1718
        U_BENF4 1719-1720       U_BENF5 1721-1722       U_BENF6 1723-1724
        U_BENF7 1725-1726       U_BENF8 1727-1728       U_COCF1 1729-1730
        U_METF1 1731-1732       U_OPIF1 1733-1734       U_OPIF2 1735-1736
        U_OPIF3 1737-1738       U_OPIF4 1739-1740       U_AMLID 1741-1748
        U_CREATN 1749-1751      U_PH 1752-1753          U_MRJV1 1754-1757
        U_PCPV1 1758-1760       U_AMPV1 1761-1764       U_AMPV2 1765-1769
        U_BENV1 1770-1773       U_BENV2 1774-1777       U_BENV3 1778-1779
        U_BENV4 1780-1781       U_BENV5 1782-1783       U_BENV6 1784-1787
        U_BENV7 1788-1789       U_BENV8 1790-1791       U_COCV1 1792-1797
        U_METV1 1798-1803       U_OPIV1 1804-1809       U_OPIV2 1810-1813
        U_OPIV3 1814-1816       U_OPIV4 1817-1819       U_ALCV1 1820-1824 .2
        U_NITRIT 1825-1826      U_ANYPOS 1827-1828      U_ANYDRG 1829-1830
        U_NUMDRG 1831-1832      U_DTDIFF 1833-1834      U_RESULT 1835-1836
        FB33 1837-1845 .2       FB38 1846-1853 .2       FC13 1854-1862 .2
        FC16 1863-1868 .2       FD31 1869-1875 .2       ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   FOUTCOME= 'OUTCOME'
   F_CT    = 'CLIENT TYPE'
   FA1     = 'MALE OR FEMALE'
   FA3     = 'BORN IN THE US'
   FA4     = 'HISPANIC OR LATINO BACKGROUND'
   FA5     = 'RACE BEST DESCRIBES'
   FA6     = 'LANGUAGE PREFERRED MOST OF THE TIME'
   FA7     = 'CURRENTLY IN SCHOOL, OR RECEIVING JOB OR SKILLS TRAINING'
   FA8     = 'HAVE HIGH SCHOOL DIPLOMA OR GED'
   FA9     = 'HIGHEST SCHOOL GRADE OR YEAR COMPLETED'
   FA10    = 'EVER EXPELLED OR SUSPENDED FROM SCHOOL > A DAY'
   FA11    = 'EVER BELONGED TO STREET GANG'
   FA12    = 'EVER LEGALLY MARRIED'
   FA12A   = 'NUMBER OF TIMES MARRIED'
   FA13    = 'EVER LIVED WITH SOMEONE AS MARRIED BUT NOT LEGALLY MARRIED'
   FA14    = '< AGE 18 COURTS/SOC SVC AGENCY EVER ARRANGE PLACE TO LIVE'
   FA15    = '< AGE 18 EVER RUN AWAY FROM HOME OR PLACE USUALLY LIVE'
   FA16    = '< AGE 18 EVER ASKED TO LEAVE HOME BY PARENT OR GUARDIAN'
   FA17    = 'NUMBER BIOLOGICAL OR NATURAL CHILDREN EVER HAD'
   FA18    = 'EVER LOSE CUSTODY OF BIOLOGICAL/OTH CHILDREN LEGALLY RAISING'
   F_LANG  = 'LANGUAGE VERSION'
   FB1A    = 'ANY TIME BEFORE (SEG 2 START) USE INHALANTS'
   FB2A    = 'AGE FIRST TIME TRIED INHALANTS'
   FB3A    = 'USE INHALANTS DURING 12 MOS. BEFORE ENTERING TX'
   FB4A    = 'FREQ INHALANT USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1B    = 'ANY TIME BEFORE (SEG 2 START), USE MARIJUANA OR HASHISH'
   FB2B    = 'AGE FIRST TIME TRIED MARIJUANA OR HASHISH'
   FB3B    = 'USE MARIJUANA OR HASHISH IN 12 MOS. BEFORE ENTERING TX'
   FB4B    = 'FREQ MJ/HASH USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1C    = 'ANY TIME BEFORE (SEG 2 START) USE CRACK'
   FB2C    = 'AGE FIRST TIME TRIED CRACK'
   FB3C    = 'USE CRACK DURING 12 MOS. BEFORE ENTERING TX'
   FB4C    = 'FREQ CRACK USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1D    = 'ANY TIME BEFORE (SEG 2 START) USE COCAINE OTHER THAN CRACK'
   FB2D    = 'AGE FIRST TIME TRIED COCAINE OTHER THAN CRACK'
   FB3D    = 'USE COCAINE OTHER THAN CRACK IN 12 MOS.BEFORE ENTERING TX'
   FB4D    = 'FRQ COCAINE (NON-CRACK) USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1E    = 'ANY TIME BEFORE (SEG 2 START) USE HALLUCINOGENS/PSYCHEDELICS'
   FB2E    = 'AGE FIRST TIME TRIED HALLUCINOGENS OR PSYCHEDELICS'
   FB3E    = 'USE HALLUCINOGENS OR PSYCHEDELICS 12 MOS. BEFORE ENTERING TX'
   FB4E    = 'FREQ HALL./PSYCHEDELICS USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1F    = 'ANY TIME BEFORE (SEG 2 START) USE HEROIN'
   FB2F    = 'AGE FIRST TIME TRIED  HEROIN'
   FB3F    = 'USE HEROIN 12 MOS. BEFORE ENTERING TX'
   FB4F    = 'FREQ HEROIN USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1G    = 'ANY TIME BEFORE (SEG 2 START) USE ILLEGAL METHADONE'
   FB2G    = 'AGE FIRST TIME TRIED ILLEGAL METHADONE'
   FB3G    = 'USE ILLEGAL METHADONE 12 MO. BEFORE ENTERING TX'
   FB4G    = 'ILLEGAL METH USE-AMOUNT IN MONTH USED MOST (PAST 12 MO)'
   FB1H    = 'AT ANY TIME BEFORE (SEG 2 START) USE OTHER OPIATES'
   FB2H    = 'APPROX.AGE FIRST TIME TRIED OTHER OPIATES'
   FB3H    = 'USE OPIATES IN 12-MOS. BEFORE ENTERED TX'
   FB4H    = 'FREQ OPIATE USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1I    = 'AT ANY TIME BEFORE (SEG 2 START) USE AMPHETAMINES/STIMULANTS'
   FB2I    = 'APPROX.AGE FIRST TIME TRIED AMPHETAMINES OR STIMULANTS'
   FB3I    = 'USE AMPHETAMINES OR STIMULANTS IN 12-MOS BEFORE ENTERED TX'
   FB4I    = 'FREQ AMPHET/STIM USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1J    = 'AT ANY TIME BEFORE (SEG 2 START) USE SEDATIVES'
   FB2J    = 'APPROX.AGE FIRST TIME TRIED SEDATIVES'
   FB3J    = 'USE SEDATIVES IN 12-MONTH BEFORE ENTERED TX'
   FB4J    = 'FREQ SEDATIVE USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1K    = 'AT ANY TIME BEFORE (SEG 2 START) USE TRANQUILIZERS'
   FB2K    = 'APPROX.AGE FIRST TIME TRIED TRANQUILIZERS'
   FB3K    = 'USE TRANQUILIZERS IN 12-MO. BEFORE ENTERED TX'
   FB4K    = 'FREQ TRANQUILIZER USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1L    = 'AT ANY TIME BEFORE (SEG 2 START) USE OVER-THE-COUNTER DRUGS'
   FB2L    = 'APPROX.AGE FIRST TIME TRIED OVER-THE-COUNTER DRUGS'
   FB3L    = 'USE OVER-THE-COUNTER DRUGS IN 12-MO.BEFORE ENTER TX'
   FB4L    = 'FREQ OTC DRUG USE-IN MONTH USED MOST (PAST 12 MO)'
   FB1M    = 'AT ANY TIME BEF. (SEG 2 START)USE ANY OTHER DRUG BESIDES ALC'
   FB1MOTH = 'OTHER DRUG USED, SPECIFIED'
   FB2M    = 'APPROX.AGE FIRST TIME TRIED OTHER DRUG'
   FB3M    = 'USE OTHER DRUG IN 12-MO. BEFORE ENTERED TX'
   FB4M    = 'FREQ OTHER DRUG USE-IN MONTH USED MOST (PAST 12 MO)'
   FB5     = 'BEFORE TX USED NEEDLE TO INJECT DRUGS'
   FB6     = '12-MO.BEFORE TX HOW OFTEN NEEDLE TO INJECT DRUGS'
   FB7     = 'BEFORE TX EVER USE NEEDLE USED BY SOMEONE ELSE'
   FB8     = '12-MO.BEFORE TX HOW OFTEN USE NEEDLE USED BY OTHER'
   FB9     = 'EVER HAD A DRINK OF ALCOHOL'
   FB9A    = 'AGE WHEN FIRST DRINK'
   FB10    = 'DURING 12-MO.BEFORE ENTERED TX EVER HAVE A DRINK OF ALCOHOL'
   FB11    = 'FREQ ALCOHOL USE-IN MONTH USED MOST (PAST 12 MO)'
   FB12A   = 'MO.DRINKING MOST, TYPICALLY DRINK 12 OZ BEER/MALT'
   FB13A   = 'ON A TYPICAL DRINKING DAY, AMT. 12 OZ BEER/MALT DRINKS'
   FB12B   = 'MO.DRINKING MOST, TYPICALLY DRINK 4 OZ WINE/WINE COOLERS'
   FB13B   = 'ON TYPICAL DRINKING DAY AMT 4 OZ GLASSES WINE/WINE COOLERS'
   FB12C   = 'MO.DRINKING MOST, TYPICALLY DRINK 1 OZ SHOTS OF HARD LIQUOR'
   FB13C   = 'ON TYPICAL DRINKING DAY, AMT. 1 OZ SHOTS OF HARD LIQUOR'
   FB14    = 'DURING 12-MO. WHICH ONE DRUG CAUSED MOST SERIOUS PROBLEMS'
   FB15    = 'DURING 12-MO. WHICH ONE OTHER DRUG CAUSED PROBLEMS'
   FB16    = 'BEFORE TX EVER OVERNIGHT IN HOSPITAL/DRUG OR ALC OVERDOSE'
   FB17    = '12-MO. PRIOR TX HOW MANY NIGHTS HOSP STAY-DRUG/ALC OVERDOSE'
   FB18    = 'BEFORE TX EVER HOSPITAL ER-DRUG/ALC OVERDOSE (NOT OVERNIGHT)'
   FB19    = 'BEFORE TX # TIMES HOSP ER-DRUG/ALC OVERDOSE (NOT OVERNIGHT)'
   FB20    = 'MARITAL STATUS AT ENTRY TO TX'
   FB21    = '# CHILDREN < AGE 18, RAISING AND LIVING WITH AT ENTRY TO TX'
   FB22    = 'DURING 12-MO.BEFORE TX LOSE CUSTODY OF ANY CHILDREN RAISING'
   FB23    = 'DURING 12-MO. BEFORE TX GET CUSTODY OF YOUR CHILD/CHILDREN'
   FB24    = 'DURING 12-MO.EVER 2+ NIGHTS IN A ROW HAVE NO PLACE TO STAY'
   FB25    = 'DURING 12-MO. PERIOD HOW LONG WITHOUT PLACE'
   FB26    = 'TYPE OF RESID/OTHER PLACE LIVED IN JUST BEFORE ENTERED TX'
   FB27A   = 'WHEN ENTERED TX LIVING WITH SPOUSE OR PARTNER'
   FB27B   = 'WHEN ENTERED TX LIVING WITH PARENT OR PARENTS'
   FB27C   = 'WHEN ENTERED TX LIVING WITH OTHER ADULT FAMILY MEMBERS'
   FB27D   = 'WHEN ENTERED TX LIVING WITH OTHER UNRELATED ADULTS'
   FB27E   = 'WHEN ENTERED TX LIVING WITH CHILDREN YOU WERE RAISING'
   FB27F   = 'WHEN ENTERED TX LIVING WITH OTHER CHILDREN'
   FB27G   = 'WHEN ENTERED TX LIVING BY YOURSELF'
   FB28    = 'BEFORE TX EVER HAD A FULL-TIME JOB'
   FB29    = 'BEFORE TX LONGEST TIME YOU HAD ANY ONE FULL-TIME JOB'
   FB30    = 'DURING 12 MONTHS PRIOR TX EMPLOYED FULL-TIME AT ANY TIME'
   FB31    = 'DURING THIS 12-MO PERIOD, HOW MANY MONTHS WORK FULL-TIME'
   FB32    = 'KIND OF WORK DONE AT LONGEST F/T JOB DURING 12-MO PERIOD'
   FB33A   = 'BEFORE TAXES, HIGHEST WAGE/SALARY/RATE OF PAY AT F/T JOB'
   FB33AOTH= 'SPECIFY CODE FOR OTHER WAGE'
   FB34    = 'BEFORE YOU ENTERED TX EVER HAVE A PART-TIME JOB'
   FB34A   = 'BEFORE YOU ENTERED TX, LONGEST TIME HAD ANY 1 PART-TIME JOB'
   FB35    = '12-MONTH PERIOD BEFORE TX EVER HAVE A PART TIME JOB'
   FB36    = 'DURING THIS 12-MO.HOW MANY MOS.WORKED PART-TIME'
   FB37    = 'KIND OF JOB DONE AT LONGEST P/T JOB DURING THIS 12-MO'
   FB38A   = 'CODE FOR OTHER RATE OF PAY AT JOB HAD LONGEST'
   FB38AOTH= 'OTHER RATE OF PAY AT JOB HAD LONGEST'
   FB39    = 'BEFORE ENTERED TX, WERE EVER UNEMPLOYED AND LOOKING FOR WORK'
   FB40    = 'LONGEST TIME THAT YOU WERE UNEMPLOYED AND LOOKING FOR WORK'
   FB41    = 'BEFORE TX EVER LOSE JOB BECAUSE OF DRUG OR ALCOHOL USE'
   FB42A   = '12-MO. BEFORE TX RECV. SOC SECURITY OR RAILROAD RETIREMENT'
   FB42B   = '12-MO. BEFORE TX RECV. SSI PAYMENTS'
   FB42C   = '12-MO. BEFORE TX RECV. GOV''T PAYMENTS'
   FB42D   = '12-MO. BEFORE TX RECV. FOOD STAMPS'
   FB42E   = '12-MO. BEFORE TX RECV. OTHER TYPES OF WELFARE ASSISTANCE'
   FB42F   = '12-MO. BEFORE TX RECV. INTEREST PAYMENTS'
   FB42G   = '12-MO. BEFORE TX RECV. ALIMONY OR CHILD SUPPORT'
   FB42H   = '12-MO. BEFORE TX RECV. INCOME FROM WAGES'
   FB42I   = '12-MO. BEFORE TX RECV. INCOME FROM UNEMPLOYMENT COMPENSATION'
   FB42J   = '12-MO. BEFORE TX RECV. INCOME RETIREMENT/SURVIVOR PENSION'
   FB42K   = '12MO.BEFORE TX RECV.INCOME FROM VET AFFAIR, WORK COMP, SSDI'
   FB42L   = '12-MO. BEFORE TX RECV. INCOME/OTHER SOURCES NOT MENTIONED'
   FB43    = 'DURING 12 MOS. HOW MANY MOS. RECV. ANY WELFARE ASSISTANCE'
   FB44    = 'PERSON INCOM 12MO.BEFOR ENTER TX MORE OR LESS THAN $20,000'
   FB44A   = 'LTR BEST REPRSENT TTL PRSON INCOM IN 12MO.PRE TX 0-19,999+'
   FB44B   = 'LTR BST REPRSENT TTL PRSON INCOM 12MO.PRE TX 20,000-74,999+'
   FB45    = 'BEFORE (SEG 2) EVER RECV. TX OR COUNSEL FOR ALCOHOL OR DRUGS'
   FB46A   = 'PRIOR SEG2 # OVRNGHT HOSP FOR TX OR COUNSEL  DRUG OR ALCOH'
   FB47A   = 'TOTAL  WKS. IN HOSPITAL TX FOR DRUGS ALCOH BEFORE (SEG 2)'
   FB46B   = 'BEFORE (SEG 2 ) #  OVERNIGHT IN A NON-HOSPITAL RES PROGRAM'
   FB47B   = 'WKS.IN NON-HOSP RES.PROGRAM FOR DRUG OR ALCOH BEFORE (SEG 2)'
   FB46C   = 'BEFORE (SEG 2 ) #  TIMES OVERNIGHT IN OUTPATIENT METHADONE'
   FB47C   = 'TOTAL WKS. IN OUTPATIENT METHADONE BEFORE (SEG 2)'
   FB46D   = 'PRIOR SEG 2 #  IN OUTPATIENT PGM OTHER THAN METHADONE'
   FB47D   = 'WKS.IN OUTPATIENT PROGRAM OTHER THAN METHADON BEFORE(SEG 2)'
   FB46E   = 'BEFORE (SEG 2 DATE) # SEPARATE TIMES IN A PHYSICIAN''S OFFICE'
   FB47E   = 'WKS.IN PHYSICIAN''S OFFICE BEFORE (SEG 2)'
   FB46F   = 'BEFORE (SEG 2 DATE) # SEPARATE TIMES IN HALF-WAY HOUSE'
   FB47F   = 'WKS. IN HALF-WAY HOUSE BEFORE (SEG 2)'
   FB46G   = 'BEFORE (SEG 2 ) #  TIMES IN DUI/DWI PROGRAM'
   FB47G   = 'WKS. IN DUI/DWI PROGRAM BEFORE (SEG 2)'
   FB46H   = 'BEFORE (SEG 2) # SEPARATE TIMES IN ANOTHER SETTING'
   FB47H   = 'TOTAL WKS. IN OTHER SETTING'
   FB48A   = '12MO.# STAY OVRNGHT IN HOSPIT RX OR COUNS FOR DRUGS OR ALCO'
   FB49A   = '12 MO.WKS.OVRNGHT IN HOSPIT RX OR COUNSEL FOR DRUGS OR ALCO'
   FB48B   = '12-MO. BEFORE (SEG 2) # OVRNGHT IN NON-HOSPITAL RES PROGRAM'
   FB49B   = '12 MO. WKS. OVRNGHT IN NON-HOSPITAL RES PROGRAM (SEG 2)'
   FB48C   = '12- MOS BEFORE (SEG 2 ) # TIMES ENTERED METHADONE COUNSEL'
   FB49C   = '12 MOS. WKS. ENTERED METHADONE COUNSEL (SEG 2 DATE)'
   FB48D   = '12-MO.BEFOR (SEG 2 ) # ENTER OUTPATIENT OTHER THAN METHADON'
   FB49D   = '12 MOS. WKS ENTERED PROGRAM OTHER THAN METHADONE (SEG 2)'
   FB48E   = '12- MOS.BEFORE (SEG 2 )  TIMES VISITED DOCTOR''S OFFICE'
   FB49E   = 'IN 12 MOS. WKS. VISITED DR.''S OFFICE (SEG 2 DATE)'
   FB48F   = 'IN 12- MOS.BEFORE (SEG 2) SEP. TIMES ENTERED HALFWAY HOUSE'
   FB49F   = '12 MO. WKS.ENTERED HALFWAY HOUSE (SEG 2)'
   FB48G   = 'IN 12- MOS.BEFORE (SEG 2) SEP. TIMES ENTERED DWI/DUI PROGRAM'
   FB49G   = 'IN 12 MOS. WKS. ENTERED DWI/DUI PROGRAM (SEG 2 DATE)'
   FB48H   = '12- MO. BEFORE (SEG 2) TIMES ENTERED ANOTHER SETTING'
   FB49H   = 'IN 12 MOS. WKS. IN OTHER TX SETTING (SEG 2 DATE)'
   FB50A   = 'BEFORE YOU ENTERED TX IN (FACILITY)ATTEND ANY AA MEETINGS'
   FB50B   = 'PRIOR ENTER TX IN (FACILIT) ATTEND ANY COCAINE ANON MEETINGS'
   FB50C   = 'PRIOR ENTERED TX IN (FACILITY) ATTEND NARCOTICS ANON MTNGS'
   FB50D   = 'PRIOR ENTER TX (FACILITY) ATTEND OTHER SELF-HELP GROUP PGMS'
   FB51A   = '12-MO. BEFORE TREATMENT ATTEND ANY AA MEETINGS'
   FB52A   = '# MOS. OF 12-MO. ATTEND AA MEETINGS'
   FB53A   = '# PER MONTH ATTEND AA MEETINGS'
   FB51B   = '12-MO. BEFORE TX ATTEND ANY COCAINE ANON. MEETINGS'
   FB52B   = '# MOS. OF 12 MO. PERIOD ATTEND COCOAINE ANON. MEETINGS'
   FB53B   = '# PER MONTH ATTEND CA MEETINGS'
   FB51C   = '12-MO. BEFORE TX ATTEND ANY NARCOTICS ANON.MEETINGS'
   FB52C   = '# MOS. OF 12-MO. PERIOD ATTEND NARCOTICS ANON. MEETINGS'
   FB53C   = '# PER MONTH ATTEND NA MEETINGS'
   FB51D   = '12 MO BEFORE TX ATTEND OTHER SELF-HELP GROUP MEETINGS'
   FB52D   = '# MOS. OF 12-MO. PERIOD ATTEND OTHER SELF-HELP GROUP MTGS'
   FB53D   = '# PER MONTH ATTEND OTHER SELF-HELP GROUP MEETINGS'
   FB54    = 'PRE TX 2CONSEC WK.SAD,BLU,DEPRES,LOS INTERES THING CARE ABT'
   FB55    = 'DEPRESSION DURING THE 12-MONTH PERIOD BEFORE YOU ENTERED TX?'
   FB56    = 'ANY TIME BEFORE YOU ENTERED TX, DID YOU EVER ATTEMPT SUICIDE'
   FB57    = 'WAS THAT DURING THE 12-MONTH PERIOD BEFORE YOU ENTERED TX'
   FB58    = '12MO PRE TX DR,RN,COUNSEL,S.WKR,FOR EMOTN,NERVES, MENT HLTH'
   FB59    = 'DUR12MO.OVRNGHT HOSPIT OR CLINIC TX OF EMOTN,NERV,MENT HLTH'
   FB60    = 'DUR.12-MO, WAS HEALTH  EXCELLENT, GOOD, FAIR, OR POOR'
   FB61    = 'DUR12MO ILL OR CNDTN LIMIT,CAUSE WRK OR SCH PBLM FOR > 3 DAY'
   FB62    = '12MO PRE TX,  TROUBLE CONTROL TEMPER OR VIOLENT BEHAV'
   FB63    = 'HALLU,DELU,SEE/HR THNG NO ELS SEE/HR,THNK OTHRS CONTR THGHTS'
   FB64A   = 'ANY TIME BEFORE YOU ENTERED TX HAVE POSITIVE TB TEST RESULT'
   FB65A   = 'WAS  POS TB TEST RESULT IN THE 12 MOS. BEFORE YOU ENTERED TX'
   FB64B   = 'AT ANY TIME BEFORE YOU ENTERED TX, DID YOU HAVE ACTIVE TB'
   FB65B   = 'WAS THE ACTIVE TB IN THE 12 MONTHS BEFORE YOU ENTERED TX'
   FB64C   = 'BEFORE YOU ENTERED TX, DID YOU HAVE HIGH BLOOD PRESSURE'
   FB65C   = 'WAS HIGH BLOOD PRESSURE IN 12 MONTHS BEFORE YOU ENTERED TX'
   FB64D   = 'ANY TIME BEFORE YOU ENTERED TX, DID YOU HAVE HEART DISEASE'
   FB65D   = 'WAS THE HEART DISEASE IN THE 12 MONTHS BEFORE YOU ENTERED TX'
   FB64E   = 'AT ANY TIME BEFORE YOU ENTERED TX, DID YOU HAVE ANEMIA'
   FB65E   = 'WAS THE ANEMIA IN THE 12 MONTHS BEFORE YOU ENTERED TX'
   FB64F   = 'ANY TIME BEFORE YOU TX, HAVE HEPATITIS OR YELLOW JAUNDICE'
   FB65F   = 'HEPATITIS OR YELLOW JAUNDICE IN 12 MO BEFORE YOU ENTERED TX'
   FB64G   = 'AT ANY TIME BEFORE YOU ENTERED TX, DID YOU HAVE CIRRHOSIS'
   FB65G   = 'WAS THE CIRRHOSIS IN THE 12 MONTHS BEFORE YOU ENTERED TX'
   FB64H   = 'BEFORE ENTERED TX, HAVE OTHER LIVER OR KIDNEY PROBLEMS'
   FB65H   = 'OTHER LIVER OR KIDNEY PROBLEM IN THE 12-MOS PRIOR ENTER TX'
   FB64I   = 'BEFORE YOU ENTERED TX, DID YOU HAVE CONVULSIONS OR EPILEPSY'
   FB65I   = 'WERE CONVULSIONS OR EPILEPSY IN 12-MOS BEFORE YOU ENTERED TX'
   FB64J   = 'BEFORE YOU ENTERED TX, DID YOU HAVE MIGRAINE HEADACHES'
   FB65J   = 'WERE MIGRANE HEADACHES IN 12-MOS BEFORE YOU ENTERED TX'
   FB64K   = 'AT ANY TIME BEFORE YOU ENTERED TX, DID YOU HAVE BLACKOUTS'
   FB65K   = 'WERE THE BLACKOUTS IN THE 12-MONTHS BEFORE YOU ENTERED TX'
   FB64L   = 'PRE TX,SYP,GONOR,G.HERP,OTHR SX TNSMT DISESE OTHR THN AIDS'
   FB65L   = 'WERE SEX TRANSMIT DISEASES IN 12-MOS BEFORE YOU ENTERED TX'
   FB64M   = 'PRE TX, HAVE OTHR PHYSICAL HLTH PROBLEM SERIOUS AFFCT HLTH'
   FB65M   = 'WERE HEALTH PROBLEMS IN 12-MOS BEFORE YOU ENTERED TX'
   FB66    = 'PRIOR ENTER TX,EVER HAVE A BLOOD TEST FOR AIDS OR HIV VIRUS'
   FB67    = 'WAS AIDS OR HIV BLOOD TEST DURING 12MO.BEFORE YOU ENTERED TX'
   FB68    = 'PRE TX,DOCTOR OR OTHR HLTH PROFESSIONAL TELL YOU HIV POS'
   FB69    = 'TOLD BY HEATLH PROFESSIONAL HIV POS. DURING 12MO PRE TX'
   FB70    = 'PRE TX, DOCTOR OR OTHR HEALTH PROFESS TELL YOU HAD AIDS'
   FB71    = 'TOLD YOU HAD AIDS DURING THE 12MO.BEFORE YOU ENTERED TX'
   FB72    = 'DUR.12-MO,# TO HOSPIT ER ILL,CONDIT,INJURY,NOT STAY OVRNIGHT'
   FB73    = 'DUR12MO#OVRNGHT IN HOSP,ILL,CONDIT, INJUR(NOT DRUG OR ALCOH)'
   FB74    = 'DUR12MO#DOC FOR ILL, CONDITION, INJUR(NOT DRUGS OR ALCOH)'
   FB75    = 'END OF 12-MO RIGHT BEFORE YOU ENTER TX. SMOKE CIGARETTES'
   FB76    = 'AT TIME,AV # CIGARET SMKE PR DAY:1-5,6-15,16-25,26-35,OVR 35'
   FB77A   = 'END OF THIS 12-MO, RIGHT BFR ENTERED TX, SMOKE CIGARS'
   FB77B   = 'AT END OF 12-MO,  BEFORE ENTERED TX, DID YOU SMOKE A PIPE'
   FB77C   = 'AT END OF 12MO,RGHT BFR ENTR TX, USE SMOKLES TOBACCO OR SNUF'
   FB78    = 'DUR 12-MO. BEFORE ENTERED TX, WERE YOU PREGNANT AT ANY TIME'
   FB78A   = 'GIVE BIRTH TO LIVE BABY DUR 12 MOS. BEFORE YOU ENTERED TX'
   FB79    = '12M BFR TX#DIF PLE HV SX WTH,0,1,2-10,11-25,26-100,101-500,+'
   FB80    = 'DUR 12MO HAVE SEX W/SOMEONE FOR $,DRUGS,CLOTH,PLACE TO SLEEP'
   FB81A   = 'BEFORE TX, DID YOU USE OR POSSESS DRUGS, INCLUDING MARIJUANA'
   FB82A   = 'HOW OLD WHEN FIRST USED OR POSSESSED DRUG INCLUD MARIJUANA'
   FB83A   = 'USE OR POSSES DRUG INCLUD MARIJUANA DUR 12MO BEFORE ENTER TX'
   FB84A   = 'PRE TX, EVER ARREST FOR POSSES OR USE DRUG INCLUD MARIJUANA'
   FB85A   = 'ARREST FOR POSSES OR USE DRUGS INCLUD MARIJUA IN 12MO PRE TX'
   FB81B   = 'PRE TX,EVER DRIVE UNDER INFLUENCE OR WHILE INTOXICATED'
   FB82B   = 'HOW OLD WHEN FIRST DROVE UNDER INFLUENCE OR WHILE INTOXICAT'
   FB83B   = 'DRIVE UNDER INFLUENC OR WHILE INTOXICATED DUR 12MO PRE TX'
   FB84B   = 'PRE TX ARREST FOR DRIVE UNDER INFLUENCE OR WHILE INTOXICAT'
   FB85B   = 'ARREST FOR DRIV UNDR INFLUENC OR INTOXICAT DUR 12MO PRE TX'
   FB81C   = 'PRE ENTER TX, DID YOU ENGAGE IN DRUNK AND DISORDERLY CONDUCT'
   FB82C   = 'AGE WHEN YOU FIRST ENGAGED IN DRUNK AND DISORDERLY CONDUCT'
   FB83C   = 'ENGAGE IN DRUNK AND DISORDER CONDUCT DURING12MO PRE TX'
   FB84C   = 'PRE TX EVER ARRESTED FOR DRUNK AND DISORDERLY CONDUCT'
   FB85C   = 'EVER ARREST FOR DRUNK AND DISORDERLY CONDUCT DUR12MO PRE TX'
   FB81D   = 'BEFORE YOU ENTERED TX DID YOU SELL OR MANUFACTURE DRUGS'
   FB82D   = 'AGE WHEN YOU FIRST SOLD OR MANUFACTURED DRUGS'
   FB83D   = 'SELL OR MANUFACTURE DRUGS DUR12MO PRE TX'
   FB84D   = 'PRE TX, EVER ARRESTED FOR SELLING OR MANUFACTURING DRUGS'
   FB85D   = 'EVER ARREST FOR SELLING OR MANUFACT DRUGS DUR 12MO BEFORE TX'
   FB81E   = 'PRE TX, PASS BAD CHKS, FORGE CHKS, OR USE STOLEN CREDIT CARD'
   FB82E   = 'AGE FIRST PASS BAD CHKS, FORGE CHKS, OR USE STOLEN CRDT CARD'
   FB83E   = 'DUR12MO PRE TX PASS BAD CHKS, FORG CHKS, OR USE STOL CRDT CD'
   FB84E   = 'PRE TX,ARREST PASS BAD CHKS, FORGE CHKS OR US STOLE CRDT CDS'
   FB85E   = 'AREST 12MO PRE TX PAS BD CHKS,FORG CHKS OR USE STOLE CRDT CD'
   FB81F   = 'PRE ENTERED TX  DEAL IN STOLEN PROPERTY INCLUDING FENCING'
   FB82F   = 'AGE WHEN FIRST DEALT IN STOLE PROPERTY INCLUD FENCING'
   FB83F   = 'DUR 12MO. PRE TX DEAL IN STOLEN PROPERTY INCLUDING FENCING'
   FB84F   = 'PRE TX,  ARREST FOR DEAL IN STOLEN PROPERTY INCLUD FENCING'
   FB85F   = 'ARREST 12MO PRE TX FOR DEAL IN STOLE PROPERT INCLUD FENCING'
   FB81G   = 'PRE TX BRK IN HSE,BUSINES,VEHICL FOR SOMONE ELSE$OR PROPERT'
   FB82G   = 'AGE1ST BROKE IN HOUS,BUSINS,OR VHCL FR SOMEON ELSE$OR PRPRTY'
   FB83G   = 'DUR12MO PRE TX BRK IN HSE,BUSINS,VEHICL FOR OTHRS$OR PROPERT'
   FB84G   = 'PRE TX,AREST BREAK IN HSE,BUSINES,VHCLE FOR OTHRS$OR PROP'
   FB85G   = 'ARST DUR12MO PRE TX BRK IN HOUSE,BUSINS,VHCL OTHRS$OR PROPTY'
   FB81H   = 'PRE TX,THFT,PKPKT,PURSSNTCH,NO FORC,SHPLFT,THFT FM MTR.VHCL'
   FB82H   = 'AGE 1ST THFT,THFT FM VHCLE,PCKPKT,PURSSNTCH,NO FRCE,SHPLFT'
   FB83H   = '12MO PRE TX THFT,FM VHCLE,PCKPKT,PURSSNATCH(NO FRCE) SHOPLFT'
   FB84H   = 'PRE TX,ARREST THFT,FM MOTR VHCL, PKPKT, PURSSNTCH(NO FORCE)'
   FB85H   = 'AREST12MO PRE TX THFT,FM VHCL,PKPKT,PRSSNATCH(NO FORC)SHPLFT'
   FB81I   = 'BEFORE YOU ENTERED TX DID YOU HAVE SEX FOR MONEY OR DRUGS'
   FB82I   = 'AGE WHEN FIRST HAD SEX FOR MONEY OR DRUGS'
   FB83I   = 'DURING12-MONTH BEFORE TX HAVE SEX FOR MONEY OR DRUGS'
   FB84I   = 'PRE TX, EVER ARRESTED FOR HAVING SEX FOR MONEY OR DRUGS'
   FB85I   = 'DUR ARREST12-MO BEFORE TX FOR HAVING SEX FOR MONEY OR DRUGS'
   FB81J   = 'PRE TX USE WPON OR PHYS FORC AGNST OTHR TO STEAL$OR PROPTY'
   FB82J   = 'AGE FIRST USE WPON OR PHYS FORC AGNST OTHR STEAL$OR PROPERTY'
   FB83J   = '12MO PRE TX USE WPON OR PHYS FORC ON OTHR TO STEAL$OR PROPT'
   FB84J   = 'PRE TX ARRST USE WEAP OR PHYS FORC ON OTHR TO STEAL$OR PROPT'
   FB85J   = 'ARRST 12MO PRE TX USE WEAPN,PHYS FORC AGST OTHR STL$OR PROP'
   FB82K   = 'AGE1ST ATTCK PSNS IG:HOMI,MNSLGHT,AGGR ASULT,FORC RAPE,KDNAP'
   FB83K   = '12MO.PRE TX ATTCK IG:HOMI,MSLGHT, AGGR ASSLT,FORC RPE,KIDNP'
   FB84K   = 'PRE TX,ARST ATCK,HOMI,MANSLGHT,AGRAV ASSLT,FORC RAPE,KIDNAP'
   FB85K   = 'ARRST 12MO PRE TX ATCK:HOMI,MSLGHT,AGR ASALT,FRC RAPE,KDNP'
   FB81L   = 'PRE TX OTHR OFFNS PPLE INJU: ASAULT OR OFENS AGNST FAM&CHILD'
   FB82L   = 'AGE 1ST OTHR OFFENS PPLE INJUR:ASAULT,OFFENS AGNST FAM&CHILD'
   FB83L   = 'DUR 12MO.PRE TX OTHR OFFENS PPLE INJUR:ASSLT OR FAM&CHLD'
   FB84L   = 'PRE TX ARRST OTHR OFNS PLE INJUR:ASAULT,OFFNS AGNST FAM&CHLD'
   FB85L   = 'ARRST 12MO PRE TX OTHR PPLE INJR:ASSLT,OFFNS AGNST FAM&CHLD'
   FB81M   = 'PRE TX,COMMIT STATUS OFFENS: RUNAWAY,CURF VIOLAT,TRUANCY'
   FB82M   = 'AGE 1ST COMMIT STATU OFFENS:RUNAWY, CURFW VIOLA,OR TRUNCY'
   FB83M   = '12MO.PRE TX COMIT STATUS OFFENS:RUNAWY,CURF VIOLAT,TRUANCY'
   FB84M   = 'PRE TX,ARREST COMMIT STATUS OFFENS:RUNAWY,CRFW VIOLAT,TRNCY'
   FB85M   = 'ARRST 12MO PRE TX STATUS OFFNS:RUNWY,CURF VIOLA,TRUNCY'
   FB81N   = 'PRE TX,OTHR OFFNSE IG:GAMBL,WPON,PROBA/PARO VIOL, CNTMPT CRT'
   FB81NOTH= 'Other offense specified'
   FB82N   = 'AGE FIRST COMMITTED OTHER OFFENSE'
   FB83N   = 'BEFORE TX, EVER ARRESTED FOR OTHER OFFENSE'
   FB84N   = 'BEFORE TX, EVER ARRESTED FOR OTHER OFFENSE'
   FB85N   = 'ARREST DURING 12-MO BEFORE TX ARREST FOR OTHER OFFENSE'
   FB86    = 'PRE TX ON (2 START DATE), HAD YOU EVER BEEN ARRESTED?'
   FB87    = '# TIMES ARRESTED BEFORE ENTERED TX'
   FB88    = 'HOW OLD WHEN ARREST 1ST TIME (BEFORE YOU ENTERED TX)'
   FB89    = '# TIMES ARREST AND BOOKED,OR TAKE INTO CUSTODY, 12-MO PRE TX'
   FB90    = '# TIMES IN JAIL, PRISON, JUV. DET. FACILITY12-MONTH PRE TX'
   FB91    = 'DAYS,WKS.,MOS.JAIL, PRISON,OR JUV DET FACIL DUR 12MOS'
   FB91U   = 'DOES # TIMES INCARCERATED REPRESENT DAYS, WEEKS, OR MONTHS'
   FB92    = 'DURING THE 12-MO.BEFORE TX ON PROBATION OR PAROLE'
   FB93    = 'DUR 12MO. HOW OFTN HAVE CONTACT W/ PROBA OR PAROLE OFFICER'
   FB93U   = 'DOES #REPORT TO PROBA OR PARO OFFICE REPRES DAYS,WKS OR MOS'
   FB94    = 'DUR12MO.WERE URINE TESTS REQUIR AS CONDIT OF PROBA OR PARO'
   FB95    = 'PRE TX SUPT SLF MAIN ILLGAL HUSTL DRG DEAL,FRAUD AT LST 1 YR'
   FB95A   = 'ILLGAL HUST,DRUG DEAL,FRAUD,DUR 12-MO BEFORE YOU PRE TX'
   FC1     = 'DRUG,INCLUDE ALCO,MAIN RSN WENT TO (FACILITY) (2 START)'
   FC2     = 'DRUG, INCLUD ALCOHOL, REASON WENT TO (FACILITY) (2 START)'
   FC3     = 'DUR TX AT(FACILITY)USE ALCO OR DRUGS INCLUD INJECT DRUGS'
   FC4     = 'DUR TX PERIOD, DRUG INCLUD ALCOHOL, USED THE MOST FREQUENTLY'
   FC5     = 'DUR TX WHAT DRUG, INCLUD ALCOHOL,USED NEXT MOST FREQUENTLY'
   FC6     = 'DUR TX,USE NDLE TO INJECT DRUGS GET HIGH, OTHR NONMED EFCTS'
   FC6A    = 'DUR TX USE NDLE INJCT DRUGS KNEW/SUSPCT USE BY SOMEON ELS'
   FC7A    = 'DUR TX TAKE METHADONE PRESCRIBED FOR YOU BY A DOCTOR'
   FC7B    = 'DUR TX TAKE DESIPRAMINE PRESCRIBED FOR YOU BY A DOCTOR'
   FC7C    = 'DURING TX TAKE ANTABUSE PRESCRIBED FOR YOU BY A DOCTOR'
   FC7D    = 'DURING TX TAKE NALTREXONE PRESCRIBED FOR YOU BY A DOCTOR'
   FC7E    = 'DURING TX PERIOD EVER LAAM PRESCRIBED FOR YOU BY A DOCTOR'
   FC7F    = 'DUR TX EVER TAKE OTHER MEDS PRESCRIB BY A DOCTOR (SPECIFY)'
   FC8     = 'DUR TX,WERE DOSE OF METHDON PRSCRIB TOO HIGH,RT AMNT,TOO LOW'
   FC8A    = 'PARTICIPATE IN DECISION ABOUT HOW MUCH METHADON WOULD GET'
   FC9     = 'DUR TX(2 START)ATTND SCHL,GED,HSCHOOL,TECHSCHOOL,COLLGDIPLMA'
   FC10    = 'DURING THIS TX PERIOD, EMPLOYED FULL-TIME AT ANY TIME'
   FC11    = 'FOR HOW LONG DURING TX PERIOD WERE YOU WORKING FULL-TIME'
   FC11U   = 'NUMBER OF DAYS, WEEKS, MONTHS, YEARS'
   FC12    = 'WORK DONE AT LONGST FULL-TIME JOB DUR TX PERIOD; JOB TITLE'
   FC13A   = 'PRE TAX,HIGHST WAGE,SALAR,RATE OF PAY AT FULL JOB DUR TX'
   FC13AOTH= 'CODE FOR OTHER RATE OF PAY SPECIFIED'
   FC14    = 'DURING TX PERIOD, DID YOU HAVE A PART-TIME JOB AT ANY TIME'
   FC15    = 'HOW LONG DURING THIS TX PERIOD WERE YOU WORKING PART-TIME'
   FC15U   = 'NUMBER OF DAYS, WEEKS, MONTHS, YEARS'
   FC16A   = 'PRE TAX,HIGHST WAGE,SALAR,RATE OF PAY@PART TIM JOB DUR TX'
   FC16AOTH= 'CODE FOR OTHER PERIOD SPECIFIED'
   FC17    = 'DUR TX TAKE CLASS OR LESSON TO GET JOB,OR IMPROV JOB SKILL'
   FC18    = 'DUR TX AT(FACIL)BETW(2 START)&(2 END)OUTPAT,RESIDENT,BOTH'
   FC19    = 'DUR TX # NIGHTS STAY OVERNIGHT AT (FACILITY NAME)'
   FC20    = 'DUR TX, FROM (2 START)TO(2 END)HOW OFTEN VISIT (FACILITY)'
   FC21    = 'HOW FREQUENT VISIT FOR IND OR GROUP COUNSEL,W/STAFF COUNSEL'
   FC22    = 'MOST IMPORTANT REASON FOR START TX OR COUNSEL AT (FACILITY)'
   FC24A   = 'DURING TX RECV. INDIVIDUAL THERAPY'
   FC25A   = '(IF YES), RECV. IND  THERAPY AT (FACILITY NAME) OR ELSEWHERE'
   FC24B   = 'DURING TX RECV. GROUP THERAPY'
   FC25B   = '(IF YES), RECV. GROUP THERAPY AT (FACILITY) OR ELSEWHERE'
   FC24C   = 'DURING TX RECV. FAMILY COUNSELING'
   FC25C   = '(IF YES)RECV. FAMILY COUNSEL AT (FACILITY NAME) OR ELSEWHERE'
   FC24D   = 'DURING TX RECV. PHYSICAL EXAM'
   FC25D   = '(IF YES) RECV. PHYSICAL EXAM AT (FACILITY NAME) OR ELSEWHERE'
   FC24E   = 'DURING TX RECV. MEDICAL CARE OTHER THAN A PHYSICAL EXAM'
   FC25E   = '(IF YES)RECV. MEDICAL EXAM AT (FACILITY NAME) OR ELSEWHERE'
   FC24F   = 'DURING TX RECV. (FEMALES ONLY) PRENATAL CARE'
   FC25F   = '(IF YES)RECV. (FEMALES) PRENAT CARE (FACILITY) OR ELSEWHERE'
   FC24G   = 'DURING TX RECV. EMPLOYMENT COUNSELING OR TRAINING'
   FC25G   = '(IF YES),RECV.EMPLOY COUNSEL OR TRAIN(FACILITY)OR ELSEWHERE'
   FC24H   = 'DURING TX RECV. ACADEMIC EDUCATION OR GED CLASSES'
   FC25H   = '(IF YES)RECV.ACADEM EDUCAT OR GED CLASS(FACILITY)OR ELSWHRE'
   FC24I   = 'DUR TX RECV. LEGAL OR CRIM JUSTICE SYSTEM COUNSEL OR SUPPORT'
   FC25I   = '(IF YES)RECV.LEGL,CRIM JUS SYST SUPPT(FACILITY)OR ELSEWHERE'
   FC24J   = 'DURING TX RECV. TRANSPORTATION'
   FC25J   = '(IF YES) RECV. TRANSPORTATION (FACILITY NAME) OR ELSEWHERE'
   FC24K   = 'DURING TX RECV. CHILD CARE'
   FC25K   = '(IF YES), DID YOU RECV. CHILD CARE (FACILITY) OR ELSEWHERE'
   FC24L   = 'DURING TX RECV. PARENTING EDUCATION'
   FC25L   = '(IF YES), RECV. PARENTING EDUCATION (FACILITY) OR ELSEWHERE'
   FC24M   = 'DURING TX RECV. HOUSING ASSISTANCE'
   FC25M   = '(IF YES)RECV. HOUSING ASSISTANCE  (FACILITY) OR ELSEWHERE'
   FC24N   = 'DURING TX RECV. HIV OR AIDS EDUCATION'
   FC25N   = '(IF YES) RECV. HIV OR AIDS EDUCATION (FACILITY) OR ELSEWHERE'
   FC24O   = 'DURING TX RECV. FINANCIAL COUNSELING'
   FC25O   = '(IF YES), RECV. FINANCIAL COUNSELING (FACILITY) OR ELSEWHERE'
   FC24P   = 'DURING TX RECV. TB TESTING'
   FC25P   = '(IF YES), RECV. TB TESTING (FACILITY NAME) OR ELSEWHERE'
   FC24Q   = 'DURING TX RECV. TB TX'
   FC25Q   = '(IF YES), DID YOU RECV. TB TX (FACILITY NAME) OR ELSEWHERE'
   FC24R   = 'DURING TX RECV. SERVICES AT STOP SMOKING CLINIC'
   FC25R   = '(IF YES),RECV. STOP SMOK SERVICES AT (FACILITY) OR ELSEWHERE'
   FC24S   = 'DURING TX RECV. SERVICES FOR DETOXIFICATION'
   FC25S   = '(IF YES), RECV.DETOX SERVICES AT (FACILITY) OR ELSEWHRE'
   FC24T   = 'DURING TX RECV. SERVICES FOR ACUPUNCTURE'
   FC25T   = '(IF YES), DID YOU RECV. ACUPUNCT SVCS AT(FACILITY)OR ELSWHRE'
   FC26    = 'DUR TX RECV. IND THERAP@(FACILITY)< 1 MO,1-3 A MO.,1-2 WK,+'
   FC27    = 'DUR TX RECV GROUP THERAPY@(FACILITY)< 1MO,1-3 MO,1-2 A WK,+'
   FC28    = 'DUR TX,HOW HELPFUL WAS TX OR COUNSEL RECV. VERY,SOMWHT,NOT'
   FC29A   = 'DID TX AT (FACILITY) HELP YOU GET OFF OR STAY OFF DRUGS'
   FC29B   = 'DID TX AT (FACILITY) HELP YOU DECREASE YOUR DRUG USE'
   FC29C   = 'DID TX AT (FACILITY) HELP YOU DECREASE YOUR ALCOHOL USE'
   FC29D   = 'DID TX AT (FACILITY) HELP YOU STOP DRINKING'
   FC29E   = 'DID TX AT (FACILITY) HELP YOU STOP SMOKING'
   FC29F   = 'DID TX AT (FACILITY) HELP YOU IMPROVE YOUR HEALTH'
   FC29G   = 'DID TX AT (FACILITY) HELP WITH EMOTIONAL PROBLEMS'
   FC29H   = 'DID TX AT (FACILITY) HELP GET A JOB'
   FC29I   = 'DID TX AT (FACILITY) HELP WITH FINANCIAL PROBLEMS'
   FC29J   = 'DID TX AT (FACILITY) HELP GET HOUSING'
   FC29K   = 'DID TX AT (FACILITY) HELP GET TRAINING AND EDUCATION'
   FC29L   = 'DID TX AT (FACILITY) HELP WITH LEGAL PROBLEMS'
   FC29M   = 'DID TX AT (FACILITY) HELP WITH IMPROVE YOUR FAMILY RELATNSHP'
   FC29N   = 'DID TX AT (FACILITY) HLP RETAIN OR REGAIN CUSTDY OF CHILDREN'
   FC29O   = 'DID TX AT (FACILITY) HELP WITH ANYTHING ELSE (SPECIFY)'
   FC30A   = 'DUR TX@(FACILITY) RECV. TRAIN FOR PLAN FUTURE OR HANDL PROBS'
   FC30B   = 'DUR TX@(FACILITY) RECV. REFERRAL TO PRGMS:AA, CA, OR NA'
   FC30C   = 'DUR TX RECV.RECOMMND TO CONTINU CNTACT W/STAFF@FACIL POST TX'
   FC30D   = 'DUR TX@(FACILITY)RECV.REFER TO OTHR PGRMS OR SRVCS POST TX'
   FC30E   = 'DURING TX AT (FACILITY) RECV. OTHER SERVICE'
   FC30EOTH= 'Other service specified'
   FC31A   = 'DURING THIS TX PERIOD ATTEND ANY AA MEETINGS'
   FC32A   = 'HOW MANY MONTHS OF THIS TX PERIOD DID YOU ATTEND AA MEETINGS'
   FC33A   = 'DUR MOS ATTND AA<1 MO,1 MO,2-3 MO,1 WK,1-2 WK,DAILY'
   FC31B   = 'DURING THIS TX PERIOD ATTEND ANY COCAINE ANON MEETINGS'
   FC32B   = 'OVER HOW MANY MOS.OF TX ATTEND COCAINE ANON MEETINGS'
   FC33B   = 'DUR MOS.ATTND CA< 1 MO,1 MO,2-3 MO,1 WK,1-2 WK,DAILY'
   FC31C   = 'DURING THIS TX PERIOD ATTEND ANY NARCOTICS ANON MEETINGS'
   FC32C   = 'HOW MANY MOS OF TX DID YOU ATTEND NARCOTICS ANON MEETINGS'
   FC33C   = 'DUR MOS.ATTEND NA<1MO.,1MO, 2-3 MO.,1WK,1-2 WK,DAILY'
   FC31D   = 'DUR TX ATTEND OTHER GROUP MEETINGS FOR DRUG OR ALCOHOL USE'
   FC32D   = 'HOW MANY MOS.OF TX ATTEND OTHR GROUPS FOR DRUG OR ALCOHO USE'
   FC33D   = 'DUR MOS. ATTND OTHR< 1MO,1MO, 2-3 MO,1WK,1-2 WK,DAILY,DAILY'
   FC34    = 'DUR TX(DID HAVE/HAVE YOU HAD) ANY URINE TESTS AT (FACILITY)'
   FC35    = 'DUR TX URIN TST@(FACI)1 ONLY,>1@REG.INTVLS,>1,@RNDM&REG,OTHR'
   FC35OTH = 'OTHER TIMING FOR URINE TESTS'
   FC36    = 'DUR TX,HEALTH/HAS YOUR HEALTH EXCELLENT, GOOD, FAIR, OR POOR'
   FC37    = 'DUR TX,OTHR THAN SUB ABSE,COUNSEL OR TREAT FOR MENT.HEALTH'
   FC38    = 'DUR TX (HAVE/ HAVE YOU HAD)BLOOD TEST FOR AIDS OR HIV VIRUS'
   FC39    = 'DUR TX DID DOCTOR OR OTHR HEALTH PROF. TELL YOU HIV POS'
   FC40    = 'DUR TX PERIOD DOCTOR OR OTHER HEALTH PROF. TELL YOU AIDS'
   FC41    = 'DUR TX RECV.COUNS,ATND CLAS TO LRN WAYS NOT GET OR SPRD AIDS'
   FC42    = 'WERE YOU PREGNANT AT ANY TIME DURING THIS TX PERIOD'
   FC43    = 'HAVE/HAD A MISCARGE,INDUC ABORT, STILLBIRTH DUR TX PERIOD'
   FC44    = 'GIVE/HAVE YOU GIVEN BIRTH TO LIVE BABY DURING THIS TX PERIOD'
   FC45    = 'CHILD BORN TO YOU DUR TX PERIOD HAVE ANY PROBLEMS AT BIRTH'
   FC46    = 'AT END OF TX PERIOD NUMBER CHILDREN RAISING AND LIVING WITH'
   FC47    = 'DUR TX(LOSE/HAVE YOU LOST) CUSTOD OF CHILDRN WERE RAISING'
   FC48    = 'DID YOU GET CUSTODY OF YOUR CHILD BACK DURING THIS TX'
   FC49    = 'WERE/HAVE YOU BEEN ON PROBA OR PARO DUR TX PERIOD'
   FC50    = 'DUR TX, REPORT TO OR HAVE ANY CONTACT W/PROBA OR PARO OFFIC'
   FC51    = 'DUR TX URINE TESTS REQUIR AS CONDITION OF PROBA OR PARO'
   FC52    = 'DUR TX URINE TESTS REQUIRED AS CONDITION OF PROBA OR PARO'
   FC53    = 'DURING THIS TX PERIOD, (WERE YOU/HAVE YOU BEEN) ARRESTED'
   FC54    = 'DURING THIS TX PERIOD, HOW MANY TIMES WERE YOU ARRESTED'
   FC55    = 'DUR TX HELP W/ CRIM CHARGES AGAINST YOU IG:SEEING A LAWYER'
   FC56    = 'DUR TX(SERVE/SERVED)TIME IN JAIL,PRISON,JUV DET FAC'
   FC57    = 'DUR TX,# TIMES SERV TIME IN JAIL,PRISON,OR JUV. DETENT FACIL'
   FC58    = 'DUR TX,HOW LONG SPEND IN JAIL,PRISON OR JUV DETENT FACILITY'
   FC58U   = '#DAYS,WKS,MOS.,YRS SPENT IN JAIL,PRISON,OR JUV. FACILITY'
   FC59    = 'DUR TX,GET SUPPRT FROM ILLEGL ACTIVIT:HUST,DRUG DEAL,FRAUD'
   FC60A   = 'DUR TX HAVE PRIVAT HMO OR OTHER MANAG CARE HEALTH CARE PLAN'
   FC60B   = 'DURING TX HAVE ANY OTHER PRIVATE HEALTH INSURANCE'
   FC60C   = 'DURING TX HAVE ANY MEDICAID OR MEDICAL ASSISTANCE'
   FC60D   = 'DURING TX HAVE ANY MEDICARE'
   FC60E   = 'DUR TX HAVE MILITARY HEALTH CARE CHAMPUS,CHAMPVA,TRICARE,VA'
   FC60F   = 'DURING TX HAVE ANY OTHER HEALTH INSURANCE OR HEALTH PLAN'
   FC61A   = 'SOURC OF PAYMNT FOR TX:PRVTE, HMO OR OTHER MANAGED CARE PLAN'
   FC61B   = 'SOURCE OF PAYMENT FOR MOST OF TX OTHER PRIVAT HEALTH INSUR'
   FC61C   = 'SOURCE OF PYMNT FOR MOST OF TX MEDICAID OR MEDICAL ASSIST'
   FC61D   = 'SOURCE OF PAYMENT FOR MOST OF YOUR TX MEDICAIRE'
   FC61E   = 'SOURC PYMNT FOR TX MILIT HLTH CARE CHMPS,CHAMPVA,TRICARE,VA'
   FC61F   = 'SOURCE OF PAYMENT FOR MOST OF  TX CRIMINAL JUSTICE SYSTEM'
   FC61G   = 'SOURCE OF PAYMENT FOR MOST OF YOUR TX SOCIAL SERVICES'
   FC61H   = 'SOURCE OF PAYMENT FOR MOST OF YOUR TX YOUR OWN MONEY'
   FC61I   = 'NO PAYMENT FOR TX'
   FC61J   = 'OTHER PAY SPECIFIED'
   FC61JOTH= 'OTHER SOURCE OF PAYMENT'
   FC61MAIN= 'IF MORE THAN ONE, WHICH IS THE MAIN SOURCE'
   FC62A   = 'DUR TX HELP W/  LIV EXP FROM SOCSEC OR RAIL RETIRE PAYMENTS'
   FC62B   = 'DUR TX HELP W/ LIVI EXPENS FROM SUPSEC INCOME OR SSI PAYMNTS'
   FC62C   = 'DUR TX HELP W/ LIV EXP FROM GOVT. PAYMNTS IG:ATAP, AFDC, ADA'
   FC62D   = 'DURING TX HELP W/ YOUR LIV EXP FROM FOOD STAMPS'
   FC62E   = 'DUR TX HELP W/ YOUR LIV EXP FROM OTHR KIND OF WELFAR ASSIST'
   FC62F   = 'DUR TX$:INTRST SAV,B ACCT,CD,BNDS,STCKS,M.FNDS,TRST,EST,PPTY'
   FC62G   = 'DUR TX HELP W/LIV EXPENS FROM ALIMONY OR CHILD SUPPORT'
   FC62H   = 'DUR TX HLP W/LIV EXPENS FRM PAY EARN WHILE WRK@JOB OR BUSIN'
   FC62I   = 'DUR TX HELP W/ YOUR LIV EXPENS FROM UNEMPLOY COMP'
   FC62J   = 'DUR TX HELP W/LIV EXPENS INCOM FM RETIRE OR SURVIV PENSION'
   FC62K   = 'DUR TX HELP W/LIV EXP.INCOM VET''S AFFRS,WRK COMP, SSDI,DISAB'
   FC62L   = 'DUR TX HELP W/LIV EXP.FROM INCOM OF OTHR SOURCE NOT MENTND'
   FD1A    = 'SINCE (SEGMENT 3 START) DID YOU USE INHALANTS'
   FD2A    = 'SINCE(3 START)IN THE MO.USE INHALANTS THE MOST HOW OFTEN USE'
   FD3A    = 'HOW LONG AFTER LEFT (FACILITY) ON (2 END)FIRST USE INHALANTS'
   FD4A    = 'WHEN DID YOU LAST USE INHALANTS'
   FD1B    = 'SINCE (SEGMENT 3 START) DID YOU USE MARIJUANA OR HASHISH'
   FD2B    = 'SINC(3 START)IN MO.USED MARIJUA OR HASH MOST HOW OFTEN USE'
   FD3B    = 'HOW LONG AFT LEFT (FACILIT)ON(SEG 2 END) FIRST USE POT, HASH'
   FD4B    = 'WHEN DID YOU LAST USE MARIJUANA OR HASH'
   FD1C    = 'SINCE (SEGMENT 3 START) DID YOU USE CRACK'
   FD2C    = 'SINCE (3 START)IN THE MO.USED CRACK THE MOST HOW OFT USING'
   FD3C    = 'HOW LONG AFTER LEFT (FACIL) ON (2 END)  FIRST USE CRACK'
   FD4C    = 'WHEN DID YOU LAST USE CRACK'
   FD1D    = 'SINCE (SEGMENT 3 START) DID YOU USE COCAINE OTHER THAN CRACK'
   FD2D    = 'SINC(3 START)IN MO.USE COCAIN OTHR THAN CRACK MOST HOW OFTN'
   FD3D    = 'HOW LONG POST(2 END) FIRST USE COCAIN OTHER THAN CRACK'
   FD4D    = 'WHEN DID YOU LAST USE COCAINE OTHER THAN CRACK'
   FD1E    = 'SINC(3 START) DID YOU USE HALLUCINOGENS OR PSYCHEDELICS'
   FD2E    = 'SINC(3 START)IN MO.USE HALLUCIN OR PSYCHDEL MST HW OFTN USE'
   FD3E    = 'HOW LONG POST(2 END)FIRST USE HALLUCINOGEN OR PSYCHEDEL'
   FD4E    = 'WHEN DID YOU LAST USE HALLUCINOGENS OR PSYCHEDELICS'
   FD1F    = 'SINCE (SEGMENT 3 START) DID YOU USE HEROIN'
   FD2F    = 'SINCE(3 START)IN MO.USED HEROIN THE MOST HOW OFTEN USING'
   FD3F    = 'HOW LONG AFTER( 2 END) DID YOU FIRST USE HEROIN'
   FD4F    = 'WHEN DID YOU LAST USE HEROIN'
   FD1G    = 'SINCE (SEGMENT 3 START) DID YOU USE ILLEGAL METHADONE'
   FD2G    = 'SINC(3 START)IN MO.USED ILLEGAL METHADONE MOST HOW OFTN USE'
   FD3G    = 'HOW LONG AFT (2 END) DID YOU FIRST USE ILLEGAL METHADONE'
   FD4G    = 'WHEN DID YOU LAST USE ILLEGAL METHADONE'
   FD1H    = 'SINCE (SEGMENT 3 START) DID YOU USE OTHER OPIATES'
   FD2H    = 'SINCE(3 START)IN MO.USED OTHER OPIATES MOST HOW OFTEN USING'
   FD3H    = 'HOW LNG AFTR LEFT (FACIL)ON(2 END)FIRST USE OTHER OPITATES'
   FD4H    = 'WHEN DID YOU LAST USE OPITATES'
   FD1I    = 'SINC(3 START)USE AMPHETAMINES OR STIMULANTS'
   FD2I    = 'SINC(3 START)IN MO.USE AMPHTAMIN OR STIMULAN MST HW OFT USE'
   FD3I    = 'HW LNG POST(FACIL)ON(2 END)1ST USE OTHR AMPHTAMIN OR STIMULN'
   FD4I    = 'WHEN DID YOU LAST USE AMPHETAMINES OR STIMULANTS'
   FD1J    = 'SINCE (SEGMENT 3 START) DID YOU USE SEDATIVES'
   FD2J    = 'SINC(3 START)IN MO.USE SEDATIV MOST HOW OFTN USE'
   FD3J    = 'HOW LONG POST(FACIL)ON(2 END) DID YOU FIRST USE SEDATIVES'
   FD4J    = 'WHEN DID YOU LAST USE SEDATIVES'
   FD1K    = 'SINCE (SEGMENT 3 START) DID YOU USE TRANQUILIZERS'
   FD2K    = 'SINC(3 START)IN MO.USED TRANQUILIZ THE MOST HOW OFTEN USING'
   FD3K    = 'HOW LONG POST(FACIL)ON(2 END) DID YOU FIRST USE TRANQUILIZ'
   FD4K    = 'WHEN DID YOU LAST USE TRANQUILIZERS'
   FD1L    = 'SINCE (SEGMENT 3 START) DID YOU USE OVER-THE-COUNTER DRUGS'
   FD2L    = 'SINC(3 START)IN MO.USE OVER-COUNTER DRUG MOST HOW OFTN USE'
   FD3L    = 'HOW LNG POST(FACIL)ON(2 END)  1ST USE OVER-COUNTER DRUG'
   FD4L    = 'WHEN DID YOU LAST USE OVER-THE-COUNTER-DRUGS'
   FD1M    = 'SINC(3 START)USE ANY OTHER DRUG BESIDES ALCOHOL'
   FD1MOTH1= 'SPECIFY OTHER DRUG'
   FD2MOTH1= 'SINC(3 START IN MO.USED OTHER DRUG THE MOST HOW OFTEN USING'
   FD3MOTH1= 'HOW LONG POST(FACIL)ON(2 END) DID YOU 1ST USE OTHER DRUG'
   FD4MOTH1= 'WHEN DID YOU LAST USE THE OTHER DRUG'
   FD1MOTH2= 'SPECIFY SECOND OTHER DRUG'
   FD2MOTH2= 'SINCE (SEGMENT 3 START) DID YOU USE SECOND OTHER DRUG'
   FD3MOTH2= 'SINC(3 START)IN MO.USE 2ND OTHER DRUG MOST HOW OFTEN USING'
   FD4MOTH2= 'WHEN DID YOU LAST USE THE SECOND OTHER DRUG'
   FD1MOTH3= 'SPECIFY THIRD OTHER DRUG'
   FD2MOTH3= 'SINCE (SEGMENT 3 START) DID YOU USE THIRD OTHER DRUG'
   FD3MOTH3= 'SINC(3 START) IN MO.USE 2ND OTHR DRUG THE MOST HOW OFTEN USE'
   FD4MOTH3= 'WHEN DID YOU LAST USE THIRD OTHER DRUG'
   FD5     = 'SINC(3 START)HOW MANY MOS USING ANY DRUGS OTHER THAN ALCOHOL'
   FD6     = 'LST 30 DAYS$ ON DRG, NO ALCO,GT HGH, FR OTHR NONMED EFFCTS'
   FD7     = 'SINC(SEG START)#USE NDLE TO INJCT DRG HGH OTHR NONMED EFFCTS'
   FD8     = 'SINC(3 START)#NDLE INJCT DRGS KNW OR SUSPCT OTHR USE NDLE'
   FD9     = 'SINC(3 START), HAVE YOU HAD A DRINK OF ALCOHOL'
   FD10    = 'DURING THE LAST 30 DAYS, DID YOU DRINK ANY ALCOHOL'
   FD11    = 'SINC(3 START), THINK ABOUT THE MO YOU WERE DRINKING THE MOST'
   FD12A   = 'ON TYPICAL DRINK DAY DRINK ANY BEER OR MALT LIQUOR (12 OZ.)'
   FD13A   = 'ON TYPICAL DRINK DAY # DRINKS OF BEER OR MALT LIQ (12 OZ.)'
   FD12B   = 'ON TYPICAL DRINK DAY WINE (4 OZ.) OR WINE COOLERS(BTTLES)'
   FD13B   = 'ON TYPIC DRINK DAY#DRINKS OF WINE(4 OZ.)WINE COOLERS(BTTLES)'
   FD12C   = 'ON TYPICAL DRINKING DAY DRINK ANY HARD LIQUOR'
   FD13C   = 'ON TYPICAL DRINK DAY#DRINKS OF BEER OR HARD LIQUOR (12 OZ.)'
   FD14    = 'SINC(3 START)STAY OVRNGHT IN HOSPIT DRG OVRDSE,DRNK TOO MCH'
   FD15    = 'SINC(3 START)HOSP ER DRUG OVRDSE OR DRNK TOO MCH,NO OVRNGHT'
   FD16    = 'MARRIED, LIV W/SMONE AS MARRY,SEPRT,DIVCD, WIDW,NEVER MARRIE'
   FD17    = '# CHLD UND 18 CURREN RAIS/LIV W/,INCLD BIO,NAT,ADPT FOS CHLD'
   FD18    = 'SINC(3 START)LOSE CUSTOD OF CHILD YOU WERE RAISING'
   FD19    = 'EVER GET CUSTODY OF CHILDREN BACK SINCE (SEG 3 START)'
   FD20    = 'SINC(3 START)2 CONS.NGHT+,NO PLAC EXPT HOMLS SHLTR,STRT,CAR'
   FD21    = 'TIME W/OUT PLACE TO STAY:< MO.,1-6 MOS.,7-11 MOS.,> 12 MOS'
   FD23A   = 'ARE YOU CURRENTLY LIVING WITH SPOUSE OR PARTNER'
   FD23B   = 'ARE YOU CURRENTLY LIVING WITH PARENT OR PARENTS'
   FD23C   = 'ARE YOU CURRENTLY LIVING WITH OTHER ADULT FAMILY MEMBERS'
   FD23D   = 'ARE YOU CURRENTLY LIVING WITH OTHER UNRELATED ADULTS'
   FD23E   = 'ARE YOU CURRENTLY LIVING WITH CHILDREN YOU ARE RAISING'
   FD23F   = 'ARE YOU CURRENTLY LIVING WITH OTHER CHILDREN'
   FD23G   = 'ARE YOU CURRENTLY LIVING BY YOURSELF'
   FD24    = '(3 START)ATTND SCHL,CLASS/LSON GED H.SCHL,TEC SCHL,COLG DIPL'
   FD25    = 'SINC(3 START) BEEN EMPLOY FULL;WORK 35 HRS OR > A WK AT JOB'
   FD26    = 'SINCE (SEG 3 START) HOW MANY MOS WORKED FULL-TIME'
   FD27    = 'WORK DONE AT LONGST FULL-TIME JOB SINCE(3 START) JOB TITLE'
   FD28A   = 'HIGHST WAGE,SALRY,RATE OF PAY AT FULL-TIME JOB SINC(3 START)'
   FD28AOTH= 'OTHER RATE OF PAY SPECIFIED'
   FD29    = 'SINCE (SEG 3 START) HAVE PART-TIME JOB AT ANY TIME'
   FD30    = 'SINCE (SEG 3 START) HOW MANY MOS WORKED PART-TIME'
   FD31A   = 'PRE TAX HIGHST WAGE,SALAR,RATE PAY@PARTTIM JOB HAD LONGST'
   FD31AOTH= 'OTHER PAY RATE SPECIFIED'
   FD32A   = 'SINC(3 START)HELP W/LIVE EXPENS FROM SSEC OR RR RETIR PYMNTS'
   FD32B   = 'SINC(3 START)HLP W/LIVE EXPNS FRM SUP SEC INCM OR SSI PYMNTS'
   FD32C   = 'SINC(3 START)HLP W/LIVE EXPENS FRM GOVT.PAYMNTS IG:ATAP,AFDC'
   FD32D   = 'SINCE (SEG 3 START) HELP W/LIVE EXPENSE FROM FOOD STAMPS'
   FD32E   = 'SINC(3 START)HELP W/LIVE EXPENS FM OTHR WELFAR ASSIST'
   FD32F   = 'HLP W/EXP:SAV,INTRST,B ACCT,CD,BNDS,STKS,MFNDS,PPTY,TRUS,EST'
   FD32G   = 'SINC(3 START)HELP W/LIVE EXPENS FM ALIMON OR CHILD SUPPORT'
   FD32H   = 'HELP W/LIVE EXPENS FROM WAGE/PAY EARN WORK AT JOB OR BUSIN'
   FD32I   = 'SINC(3 START)HELP W/LIVE EXPENS FROM UNEMPLOY COMP'
   FD32J   = 'SINC(3 START)HLP W/LIVE EXPENS FM $ FM RTIRE OR SURV PNSION'
   FD32K   = 'SINC(3 SRT)HLP W/LIVE EXP VET AFFAIR,WRK COMP,SSDI,OTH DISAB'
   FD32L   = 'SINC(3 STRT)HLP W/LIV EXPNSE FRM INCOM OF OTHR SOURC NO MNTN'
   FD33A   = 'DO YOU CURRENTLY HAVE PRIVATE HMO OR OTHER MANAGED CARE PLAN'
   FD33B   = 'DO YOU CURRENTLY HAVE OTHER PRIVATE HEALTH INSURANCE'
   FD33C   = 'DO YOU CURRENTLY HAVE MEDICAID OR MEDICAL ASSISTANCE'
   FD33D   = 'DO YOU CURRENTLY HAVE MEDICARE'
   FD33E   = 'CURRENT HAVE MILITA HLTH CARE CHAMPUS, CHAMPVA, TRICARE, VA'
   FD33F   = 'DO YOU CURRENTLY HAVE ANY OTHER HEALTH CARE COVERAGE'
   FD34A   = 'RECV.INDIV.THERAPY AFTRCARE@(FACIL)SNCE LVING (FACIL)(2 END)'
   FD34B   = 'RECV.GRP THRPY AFTRCARE@(FACIL)SNCE LEAV(FACIL)ON(SEG 2 END)'
   FD34C   = 'RECV.FAM COUNS AFTRCARE@(FACIL)SNCE LEAV(FACIL)ON(2 END)'
   FD34D   = 'ALUMN OR RUNION GP AFTERCRE@(FACIL)SNCE LEAV(FACIL)ON(2 END)'
   FD34E   = 'ANY OTHER TYPE OF FOLLOW UP'
   FD35    = 'SINC LEAV TX(FACIL)(2 END)ENTR TX OR COUNS AGN FOR DRUG/ALCO'
   FD37A   = 'SINC(3 START)# STAY OVRNGHT IN HOSPIT TO TREAT DRUGS/ALCO'
   FD38A   = 'TOTL WKS OVRNGHT IN HOSPIT FOR DRUGS OR ALCO SINCE(3 START )'
   FD37B   = 'SINC(3 START)# ENTRED OUTPTNT NONHOSP RESID FOR DRUGS/ALCO'
   FD38B   = '# WKS OVRNGHT IN OUTPNT RESID FOR DRUGS/ALCO SINCE(3 START )'
   FD37C   = 'SINC(3 START)# ENTRD OUTPTNT METHADONE FOR DRUGS/ALCO'
   FD38C   = '# WKS ENTRED OUTPTNT METHAD FOR DRUGS/ALCO SINCE (3 START )'
   FD37D   = 'SINC(3 START)# OUTPTNT PROGRM OTHR THAN METHAD FOR DRUG/ALCO'
   FD38D   = 'TOTAL # WKS OUTPTNT OTHR THAN METH DRUG/ALCO SINC(3 START )'
   FD37E   = 'SINCE (SEG 3 START) # TIMES IN A PHYSICIAN''S FOR DRUG/ALCO'
   FD38E   = 'TOTL # WKS DRUG/ALCO @DR''S FOR DRUG/ALCO SINCE (3 START )'
   FD37F   = 'SINC(SEG 3 START) # TIMES IN A HALF-WAY HOUSE FOR DRUG/ALCO'
   FD38F   = 'TOTL#WK FOR DRUG/ALCO IN HFWY HSE FOR DRG/ALCO SINC(3 START)'
   FD37G   = 'SINC(3 START) # TIMES IN A DWI/DUI PROGRAM FOR DRUG/ALCO'
   FD38G   = 'TOTL WKS FOR DRUG/ALCO@DWI PGRM DRUG/ALCO SINCE (3 START )'
   FD37H   = 'SINCE (SEG 3 START) # TIMES IN ANOTHER SETTING FOR DRUG/ALCO'
   FD38H   = 'TOTL#WKS DRUGS/ALCO IN OTHR SETTING SINC(3 START )'
   FD39A   = 'SINC(3 START), DID YOU ATTEND AA MEETINGS'
   FD40A   = 'SINC(3 START) OVER HOW MANY MOS. DID YOU ATTEND AA MEETINGS'
   FD41A   = 'ATND AA MTGS<1 MO/INFQNT,1MO,2-3MO,1WK.,2-3WK,DALY,AMST DALY'
   FD39B   = 'SINC(SEG 3 START), DID YOU ATTEND COCAINE ANON. MEETINGS'
   FD40B   = 'SINC(3 START)HOW MANY MOS.ATTEND COCAINE ANON. MEETINGS'
   FD41B   = 'COCAIN ANON.MTGS<1MO,1 MO,2-3MO,1WK,2-3 WK,DLY,ALMST DLY'
   FD39C   = 'SINC(SEG 3 START), DID YOU ATTEND NARCOTICS ANON. MEETINGS'
   FD40C   = 'SINC(3 START)HOW MANY MOS.ATTEND NARCOTICS ANON. MEETINGS'
   FD41C   = 'NARCOTIC ANON MTNGS< 1MO,1MO,2-3MO,1WK.,2-3 WK,DLY,ALMST DLY'
   FD39D   = 'SINC(3 START)ATTND OTHR SELF HLP GPS FOR DRUG OR ALCO ABUSE'
   FD40D   = 'SINC(3 START) # MOS. ATTEND OTHER SELF HELP MEETINGS'
   FD41D   = 'NARCOTI ANON MTNGS<1MO,1MO,2-3MO,1WK.,2-3 WK,DLY,ALMOST DLY'
   FD42    = 'ARE YOU IN TX NOW FOR USE OF DRUGS OR ALCOHOL'
   FD42A   = 'RCVING TX FOR USE OF DRUGS OR ALCO OVRNGHT IN A HOSPIT'
   FD42B   = 'RECV TX USE OF DRUG OR ALCOH OVRNGHT IN NONHOSP RESIDNT PGRM'
   FD42C   = 'RECVING TX FOR DRUG OR ALCO IN OUTPATIENT METHADONE PROGRAM'
   FD42D   = 'RCVING TX FOR DRUGS OR ALCOH IN OUTPAT PGRM OTHR THAN METHAD'
   FD42E   = 'RCVING TX FOR YOUR USE OF DRUGS OR ALCOHOL IN A DR''S OFFICE'
   FD42F   = 'RCVING TX FOR YOUR USE OF DRUGS OR ALCOHOL IN HALFWAY HOUSE'
   FD42G   = 'RCVING TX FOR USE OF DRUGS OR ALCOHL IN A DWI/DUI PRGM'
   FD42H   = 'RCVING TX FOR USE OF DRUGS OR ALCO IN GROUP SUCH AS AA'
   FD42I   = 'RCVING TX FOR USE OF DRUG OR ALCO IN COCAIN OR NAROTIC ANON'
   FD43    = 'AT LST 2 CONS WKS,SAD,BLUE,DEPRES,LOS INTRST,PLEAS IN THNGS'
   FD44    = 'SINCE (SEGMENT 3 START DATE) DID YOU ATTEMPT SUICIDE'
   FD45    = 'SEE DR,COUNSEL, SOC WORK PROBS WITH EMOT,NERVE OR M.HEALT'
   FD46    = 'STAY OVRNNT HOSP/CLINIC TX OF PBLMS W/EMOT,NRVES,OR M.HEALT'
   FD47    = 'HEALTH RIGHT NOW IS EXCELLENT, GOOD, FAIR, OR POOR'
   FD48    = 'CURR ILL/COND CAUSE PAIN,LIMIT ACTIV,CAUSE TRBLE WK OR SCHL'
   FD49A   = 'SINCE (SEG 3 START), HAD A POS TB TEST RESULT'
   FD49B   = 'SINCE (SEG 3 START), HAD ACTIVE TB'
   FD49C   = 'SINCE (SEG 3 START), HAD HIGH BLOOD PRESSURE'
   FD49D   = 'SINCE (SEG 3 START), HAD HEART DISEASE'
   FD49E   = 'SINCE (SEG 3 START), HAD ANEMIA'
   FD49F   = 'SINCE (SEG 3 START) HAD HEPATITIS OR YELLOW JAUNDICE'
   FD49G   = 'SINCE (SEG 3 START), HAD CIRRHOSIS'
   FD49H   = 'SINCE (SEG 3 START) HAD OTHER LIVER OR KIDNEY PROBLEMS'
   FD49I   = 'SINCE (SEG 3 START) HAD CONVULSIONS OR EPILEPSY'
   FD49J   = 'SINCE (SEG 3 START) HAD MIGRANE HEADACHES'
   FD49K   = 'SINCE (SEG 3 START) HAD BLACKOUTS'
   FD49L   = 'HAD SYPH,GONOR,G.HERPE,OTHR SEX TRNSMT DISEAS OTHER THN AIDS'
   FD49M   = 'OTHR PHYS HEALTH PROBLM OR ILL SERIOUS AFFECT HLTH (SPECIFY)'
   FD50    = 'HAVE YOU HAD ANY OF THESE PROBLEMS IN THE LAST 30 DAYS'
   FD51    = 'SINCE (3 START)HAD A BLOOD TEST FOR AIDS OR THE HIV VIRUS'
   FD54    = 'SINCE (3 START) # SEE A DOCTOR FOR A PHYS ILL, COND OR INJUR'
   FD55    = 'SINCE(3 START)# TO HOSP ER FOR PHYS ILL,BUT NO STAY OVRNGHT'
   FD56    = '#  ER FOR DRUG OVRDSE,DRANK TOO MUCH,BUT DID NOT STAY OVERNT'
   FD57    = 'SINCE( 3 START)# OVERNGT FOR DRINK TOO MUCH OR DRUG OVERDOSE'
   FD58    = 'SINCE(3 START)# OVRNGHT FOR PHYSICAL ILLNSS,CONDIT OR INJURY'
   FD59    = 'DURING THE LAST 30 DAYS DID YOU SMOKE CIGARETTES'
   FD60    = 'DURING THE LAST 30 DAYS HOW MANY CIGARETTES DID YOU SMOKE'
   FD61A   = 'IN THE LAST THIRTY DAYS SMOKE CIGAR'
   FD61B   = 'IN THE LAST THIRTY DAYS SMOKE A PIPE'
   FD61C   = 'IN THE LAST THIRTY DAYS USE TOBACCO OR SNUFF'
   FD62    = 'SINC(3 START) HAVE YOU BEEN PREGNANT AT ANY TIME'
   FD63    = 'SINCE (3 START) HAD MISCARRIAGE, INDUCED ABORTION, STILLBORN'
   FD64    = 'SINCE (3 START) GIVE BIRTH TO A LIVE BABY'
   FD65    = 'ANY CHILD BORN TO YOU SINCE(3 START) PROBLEMS AT BIRTH'
   FD66    = 'SINC(3 START)# PEPLE SEX W/:0,1, 2-10,11-25,26-100,101-500,+'
   FD67    = 'SINC(3 START)SEX W/ SOMEON FOR$,DRUGS,CLOTHES,PLACE TO SLEEP'
   FD68A   = 'SINCE (SEG 3 START) USE OR POSSES DRUGS, INCLUDING MARIJUANA'
   FD69A   = 'ARRESTED FOR USING OR POSSESSING DRUGS, INCLUDING MARIJUANA'
   FD68B   = 'SINCE (3 START) DRIVE UNDER INFLUENCE WHILE INTOXICATED'
   FD69B   = 'ARRESTED FOR DRIVING UNDER THE INFLUENCE WHILE INTOXICATED'
   FD68C   = 'SINCE(3 START)DRIVE INTOX. ENGAGE IN DRUNK &DISORD CONDUCT'
   FD69C   = 'ARRESTED FOR ENGAGING IN DRUNK AND DISORDERLY CONDUCT'
   FD68D   = 'SINCE (SEG 3 START) SELL OR MANUFACTURE DRUGS'
   FD69D   = 'WERE YOU ARRESTED FOR SELLING OR MANUFACTURING DRUGS'
   FD68E   = 'SINCE(3 START)PASS BAD CHCKS,FORG CHCKS,USE STOLEN CRDT CDS'
   FD69E   = 'ARREST FOR PASS BD CHKS,FORG CHKS OR USE STOLE CRDT CDS'
   FD68F   = 'SINCE (3 START) DEAL IN STOLEN PROPERTY INCLUDING FENCING'
   FD69F   = 'ARRESTED FOR DEALING IN STOLEN PROPERTY INCLUDING FENCING'
   FD68G   = 'SINCE(3 START)BK INTO HSE,BUSI OR VHCL TAKE OTHRS$ PROPRTY'
   FD69G   = 'ARREST FOR BREAK INTO HSE,BUSIN, VHCLE TAKE OTHRS$PROPRTY'
   FD68H   = 'SINCE(3 START)THEFT,PCKPCKT,PRSE-SNATCH W/OUT FORCE'
   FD69H   = 'ARREST FOR THEFT, PKPKTING, PURSE SNATCHING W/OUT FORCE'
   FD68I   = 'SINCE (SEG 3 START) HAVE SEX FOR MONEY OR DRUGS'
   FD69I   = 'ARRESTED FOR HAVING SEX FOR MONEY OR DRUGS'
   FD68J   = 'SINCE(SEG 3 START)USE WEAPON/PHYSICAL FORCE AGAINST SOMEONE'
   FD69J   = 'ARREST FOR USE WEAPON/PHYSICAL FORCE AGAINST SOMEONE'
   FD68K   = 'SINCE( 3 START)ATTACK,HOMIC,MANSLT,AGG ASLT,FORC RAPE,KIDNAP'
   FD69K   = 'ARREST FOR HOMICI,MANSLAUGHT,AGGRAV ASSAULT,FORC RAPE,KIDNAP'
   FD68L   = 'OFFENS PEOPLE INJURE IG:ASSAULT,OFFENS AGAINST FAM AND CHILD'
   FD69L   = 'ARREST FOR PEOPLE INJURE IG:ASSAULT,OFFENS AGAINS FAM&CHILD'
   FD68M   = 'COMMIT STATUS OFFENS IG:RUN AWAY,CURFEW VIOLAT, OR TRUANCY'
   FD69M   = 'ARREST FOR STATUS OFFENS IG:RUNAWAY,CURFEW VIOLATI,TRUANCY'
   FD68N   = 'OTHR OFFENS IG:GAMBL,WEAPN OFENS,PROBA,PARO VIOLAT,CNTMPT CT'
   FD68NOTH= 'OTHER OFFENSE SPECIFIED'
   FD69N   = 'ARREST IG:GAMBL,WEAP OFFENS,PROBA OR PAROL VIOLA,CNTMPT CT'
   FD70    = 'SINCE(SEG 3 START)ARREST&BOOKED, OR TAKEN INTO CUSTODY'
   FD71    = 'SINC(SEG 3 START)# ARRESTED & BOOKED OR TAKEN INTO CUSTODY'
   FD72    = 'CRIM CHARGES CASES INCLUD CONVICTION AWAITING SENTENC FOR'
   FD73    = 'SINC(SEG 3 STAR)SERVE TIME IN JAIL,PRISON, JUV DETENT FACIL'
   FD74    = '# TIMES SERVED TIME IN JAIL, PRISON, OR A JUV DETENT FACIL'
   FD75    = 'SINCE(SEG 3 START)HOW LONG JAIL, PRISON,OR JUV DETENT FACIL'
   FD75U   = '# DAYS,WKS,MOS IN JAIL, PRISON, OR JUV DETENT FACIL'
   FD76    = 'SINCE (SEG 3 START) ON PROBATION OR PAROLE'
   FD77    = 'REPORT TO/HAVE CONTACT WITH YOUR PROBA OR PAROL OFFIC SINCE'
   FD78    = 'URIN TEST REQ AS CONDITN OF PROBA OR PAROL SINC(SEG 3 START)'
   FD79    = 'SINCE(SEG 3 START)GET SOME SUPPORT FROM ILLEGAL ACTIVITIES'
   FD80    = 'SINCE(SEG 3 START)TYP.WK,HOW MUCH$EARNED FROM ILLEGAL ACTIV'
   FD81A   = 'HAVE YOU TAKEN MARIJUANA DURING THE PAST 7 DAYS'
   FD82A   = 'MARIJUA IN PAST 7 DAY FOR MED,NONMED,BOTH MED&NONMED RSNS'
   FD83A   = 'HAVE YOU TAKEN MARIJUANA DURING PAST 24 HOURS'
   FD81B   = 'TAKEN COCAINE, INCLUDING CRACK, DURING THE PAST 7 DAYS'
   FD82B   = 'COCAIN,INCLUD CRACK PAST 7 DAY FOR MED,NONMED,MED&NONMED RSN'
   FD83B   = 'HAVE YOU TAKEN COCAINE, INCLUDING CRACK DURING PAST 24 HRS'
   FD81C   = 'HAVE YOU TAKEN PCP DURING THE PAST 7 DAYS'
   FD82C   = 'USE PCP DURING PAST 7 DAYS FOR MED,NONMED,MED&NONMED RSNS'
   FD83C   = 'HAVE YOU TAKEN PCP IN PAST 24 HOURS'
   FD81D   = 'HAVE YOU TAKE HEROIN OR OTHER OPIATES DURING THE PAST 7 DAYS'
   FD82D   = 'USE HEROIN, OPIATE PAST 7 DAY FOR MED,NONMED,MED&NONMED RSNS'
   FD83D   = 'TAKEN HEROIN OR OTHER OPIATES IN PAST 24 HOURS'
   FD81E   = 'HAVE YOU TAKEN METHADONE DURING THE PAST 7 DAYS'
   FD82E   = 'USE METHADON PAST 7 DAY FOR MED,NONMED,MED&NONMED REASONS'
   FD83E   = 'HAVE YOU TAKEN METHADONE IN PAST 24 HOURS'
   FD81F   = 'HAVE YOU TAKEN AMPHETAMINES DURING PAST 7 DAYS'
   FD82F   = 'USE AMPHETAMIN DUR PAST 7 DAY FOR MED,NONMED,BOTH MED&NONMED'
   FD83F   = 'TAKEN AMPHETAMINES IN PAST 24 HOURS'
   FD81G   = 'USE BENZDIAZPN,TRANQUIL:VALIUM,LIBRIUM,XANA,ATIVA PAST 7 DAY'
   FD82G   = 'USE BENZDIAZPNE DUR PAST 7 DAY FOR MED,NONMED,MED&NON MED'
   FD83G   = 'TAKEN BENZODIAZEPINES IN PAST 24 HOURS'
   FD81H   = 'HAVE YOU USED ALCOHOL DURING PAST 7 DAYS'
   FD82H   = 'USE ALCO IN PAST 7 DAYS FOR MED,NONMED,BOTH MED&NON MED RSNS'
   FD83H   = 'HAVE YOU TAKEN ALCOHOL IN PAST 24 HOURS'
   FD81I   = 'HAVE YOU USED ANY OTHER DRUG IN THE PAST 7 DAYS (SPECIFY)'
   FD82I   = 'USE OTHR DRUG IN PAST 7 DAY MED,NONMED,BOTH MED&NONMED RSNS'
   FD83I   = 'HAVE YOU USED OTHER DRUG IN THE PAST 24 HOURS'
   FD84A   = 'SATISF W/ TX FM(SEG 2 ST)TO(SEG 2 END)VERY,SMWHAT,NOT AT ALL'
   FD84B   = 'WAS TX FROM (SEG START) TO (SEG 2 END) LONG ENOUGH'
   FD84C   = 'DENIED ANY SERVICES BECAUSE OF YOUR HEALTH CARE COVERAGE'
   FD84D   = 'RECEIVE  THE SERVICES YOU NEEDED TO HELP WITH YOUR RECOVERY'
   FD84E   = 'MOST HELPFUL SERVICES'
   FD84F   = 'SERVICES FEEL YOU COULD HAVE BENEFIT WHICH NOT RECV'
   FD84G   = 'HOW COULD TX BE IMPROVED'
   FB2CFLG = 'FB2C VALUES THAT FAILED AGE EDITS'
   FB2FFLG = 'FB2F VALUES THAT FAILED AGE EDITS'
   FB2KFLG = 'FB2K VALUES THAT FAILED AGE EDITS'
   FB82AFLG= 'FB82A VALUES THAT FAILED AGE EDITS'
   FB82BFLG= 'FB82B VALUES THAT FAILED AGE EDITS'
   FB82CFLG= 'FB82C VALUES THAT FAILED AGE EDITS'
   FB82DFLG= 'FB82D VALUES THAT FAILED AGE EDITS'
   FB82EFLG= 'FB82E VALUES THAT FAILED AGE EDITS'
   FB82FFLG= 'FB82F VALUES THAT FAILED AGE EDITS'
   FB82GFLG= 'FB82G VALUES THAT FAILED AGE EDITS'
   FB82HFLG= 'FB8HA VALUES THAT FAILED AGE EDITS'
   FB82IFLG= 'FB82I VALUES THAT FAILED AGE EDITS'
   FB82JFLG= 'FB82J VALUES THAT FAILED AGE EDITS'
   FB82KFLG= 'FB82K VALUES THAT FAILED AGE EDITS'
   FB82LFLG= 'FB82L VALUES THAT FAILED AGE EDITS'
   FB82MFLG= 'FB82M VALUES THAT FAILED AGE EDITS'
   FB82NFLG= 'FB82N VALUES THAT FAILED AGE EDITS'
   FB88AFLG= 'FB88A VALUES THAT FAILED AGE EDITS'
   FD36FLG = 'DISCHARGE DATE BEFORE D36 EDIT FAILURE'
   FD3BFLG = 'FAILED FD3B 1ST DRUG USE SINCE DISCHARGE'
   FD3CFLG = 'FAILED FD3C 1ST DRUG USE SINCE DISCHARGE'
   FD3DFLG = 'FAILED FD3D 1ST DRUG USE SINCE DISCHARGE'
   FD3EFLG = 'FAILED FD3E 1ST DRUG USE SINCE DISCHARGE'
   FD3FFLG = 'FAILED FD3F 1ST DRUG USE SINCE DISCHARGE'
   FD3GFLG = 'FAILED FD3G 1ST DRUG USE SINCE DISCHARGE'
   FD3IFLG = 'FAILED FD31 1ST DRUG USE SINCE DISCHARGE'
   FD38BFLG= 'FAILED FD38B 1ST DRUG USE SINCE DISCHARGE'
   FD38CFLG= 'FAILED FD38C 1ST DRUG USE SINCE DISCHARGE'
   FD38DFLG= 'FAILED FD38D 1ST DRUG USE SINCE DISCHARGE'
   FD38FFLG= 'FAILED FD38F 1ST DRUG USE SINCE DISCHARGE'
   FD38GFLG= 'FAILED FD38G 1ST DRUG USE SINCE DISCHARGE'
   FD38HFLG= 'FAILED FD38H 1ST DRUG USE SINCE DISCHARGE'
   FD5FLG  = 'FAILED #MONTHS USING FD5 SINCE DISCHARGE'
   FD26FLG = 'FAILED #MONTHS USING FD26 SINCE DISCHARGE'
   FD30FLG = 'FAILED #MONTHS USING FD30 SINCE DISCHARGE'
   FD40AFLG= 'FAILED #MONTHS USING FD40A SINCE DISCHARGE'
   FD40BFLG= 'FAILED #MONTHS USING FD40B SINCE DISCHARGE'
   FD40CFLG= 'FAILED #MONTHS USING FD40C SINCE DISCHARGE'
   FD40DFLG= 'FAILED #MONTHS USING FD40B SINCE DISCHARGE'
   FB64MOTH= 'OTHER PHYSICAL HEALTH PROBLEM'
   FC7FOTH1= 'C7F. FIRST OTHER MEDICINE PRESCRIBED'
   FC7FOTH2= 'C7F. SECOND OTHER MEDICINE PRESCRIBED'
   FC7FOTH3= 'C7F. THIRD OTHER MEDICINE PRESCRIBED'
   FD49MOTH= 'D49M. OTHER PHYSICAL HEALTH PROBLEM'
   FD81IOTH= 'D81I. OTHER DRUG SPECIFIED'
   FC23    = 'C23. WHAT IS THE MAIN REASON YOU STOP'
   FC29OOTH= 'C29O. OTHER HELP SPECIFIED'
   FDAYSDCG= 'NUMBER OF DAYS SINCE DISCHARGE DATE'
   F_NEXTTX= 'TIME TO 1ST TREATMENT SINCE DISCHARGE'
   F_AGEINT= 'AGE AT CLIENT FOLLOWUP INTERVIEW'
   A73     = 'REASON FOR DISCHARGE'
   FACID   = 'FACILITY ID'
   AGE_CALC= 'CALCULATED AGE AT ADMISSION'
   LOS     = 'LENGTH OF STAY (DAYS)'
   TRT_DUR = 'TREATMENT DURATION (DAYS)'
   ALCOHOL = 'ALCOHOL CLIENT (1=ALCOHOL USE MENTIONED)'
   DRUG    = 'DRUG CLIENT (1=DRUG MENTIONED)'
   DRUG_ALC= 'ALCOHOL CLIENT, DRUG CLIENT, OR BOTH'
   TXCARE  = 'CLIENT''S TYPE OF TREATMENT'
   ABSSMPTY= 'ABSTRACT SAMPLE TYPE'
   QFSTRAT = 'TREATMENT TYPE STRATUM INDICATOR'
   GROUP   = 'INCENTIVE GROUP INDICATOR'
   FIELDPSU= 'PSU NUMBER'
   U_MRJ_SM= 'THC METABOLITES SUMMARY FLAG'
   U_PCP_SM= 'PHENCYCLIDINE(PCP) SUMMARY FLAG'
   U_AMP_SM= 'AMPHETAMINES SUMMARY FLAG'
   U_BEN_SM= 'BENZODIAZEPINES SUMMARY FLAG'
   U_COC_SM= 'BENZOYLECGONINE(COCAINE) SUMMARY FLAG'
   U_MET_SM= 'METHADONE SUMMARY FLAG'
   U_OPI_SM= 'OPIATES SUMMARY FLAG'
   U_ALCF1 = 'ETHANOL(ALCOHOL) FLAG'
   U_MRJF1 = 'CARBOXY ACID THC FLAG'
   U_PCPF1 = 'PHENCYCLIDINE(PCP)FLAG'
   U_AMPF1 = 'AMPHETAMINE FLAG'
   U_AMPF2 = 'METHAMPHETAMINE FLAG'
   U_BENF1 = 'NORDIAZEPAM FLAG'
   U_BENF2 = 'OXAZEPAM FLAG'
   U_BENF3 = 'TEMAZEPAM FLAG'
   U_BENF4 = 'LORAZEPAM FLAG'
   U_BENF5 = 'FLURAZEPAM FLAG'
   U_BENF6 = 'ALPHA-HYDROXYALPRAZOLAM FLAG'
   U_BENF7 = 'DESALKYLFLURAZEPAM FLAG'
   U_BENF8 = 'ALPRAZOLAM FLAG'
   U_COCF1 = 'BENZOYLECGONINE FLAG'
   U_METF1 = 'METHADONE FLAG'
   U_OPIF1 = 'MORPHINE FLAG'
   U_OPIF2 = 'CODEINE FLAG'
   U_OPIF3 = 'HYDROMORPHONE FLAG'
   U_OPIF4 = '6 - MONOACETYLMORPHONE FLAG'
   U_AMLID = 'AML ID'
   U_CREATN= 'CREATININE, URINE'
   U_PH    = 'VALID PH-URINE SCREEN'
   U_MRJV1 = 'CARBOXY ACID THC VALUE'
   U_PCPV1 = 'PHENCYCLIDINE(PCP)VALUE'
   U_AMPV1 = 'AMPHETAMINE VALUE'
   U_AMPV2 = 'METHAMPHETAMINE VALUE'
   U_BENV1 = 'NORDIAZEPAM VALUE'
   U_BENV2 = 'OXAZEPAM VALUE'
   U_BENV3 = 'TEMAZEPAM VALUE'
   U_BENV4 = 'LORAZEPAM VALUE'
   U_BENV5 = 'FLURAZEPAM VALUE'
   U_BENV6 = 'ALPHA-HYDROXYALPRAZOLAM VALUE'
   U_BENV7 = 'DESALKYLFLURAZEPAM VALUE'
   U_BENV8 = 'ALPRAZOLAM VALUE'
   U_COCV1 = 'BENZOYLECGONINE VALUE'
   U_METV1 = 'METHADONE VALUE'
   U_OPIV1 = 'MORPHINE VALUE'
   U_OPIV2 = 'CODEINE VALUE'
   U_OPIV3 = 'HYDROMORPHONE VALUE'
   U_OPIV4 = '6-MONOACETYLMORPHONE VALUE'
   U_ALCV1 = 'ETHANOL(ALCOHOL) VALUE'
   U_NITRIT= 'NITRITES, URINE'
   U_ANYPOS= 'POS. FOR ALCOHOL OR ANY DRUG'
   U_ANYDRG= 'POS. FOR ANY DRUG OTHER THAN ALCOHOL'
   U_NUMDRG= 'NUM OF POS. DRUG FAMILIES NOT ALCOHOL'
   U_DTDIFF= 'DAYS BETWEEN COLLECTION & TEST REPORT'
   U_RESULT= 'URINE DATA COLLECION RESULT'
   FB33    = 'PRE TAX, HIGHES WAGE, SALARY, OR RATE OF PAY AT F/T JOB'
   FB38    = 'PRE TAX,HIGHES RATE OF PAY AT PART-TIME JOB'
   FC13    = 'PRE TAX,HIGHEST RATE OF PAY AT F/T JOB DURING TX PERIOD'
   FC16    = 'PRE TAX HIGHEST WAGE FOR PART-TIME JOB HAD LONGEST'
   FD31    = 'PRE TAX HGHST $ FOR PRT-TME JOB LONGST SINCE (3 START)'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (FOUTCOME <= -1) THEN FOUTCOME = .;
   IF (F_CT <= -1) THEN F_CT = .;
   IF (FA1 <= -1) THEN FA1 = .;
   IF (FA3 <= -1) THEN FA3 = .;
   IF (FA4 <= -1) THEN FA4 = .;
   IF (FA5 <= -1) THEN FA5 = .;
   IF (FA6 <= -1) THEN FA6 = .;
   IF (FA7 <= -1) THEN FA7 = .;
   IF (FA8 <= -1) THEN FA8 = .;
   IF (FA9 <= -1) THEN FA9 = .;
   IF (FA10 <= -1) THEN FA10 = .;
   IF (FA11 <= -1) THEN FA11 = .;
   IF (FA12 <= -1) THEN FA12 = .;
   IF (FA12A <= -1) THEN FA12A = .;
   IF (FA13 <= -1) THEN FA13 = .;
   IF (FA14 <= -1) THEN FA14 = .;
   IF (FA15 <= -1) THEN FA15 = .;
   IF (FA16 <= -1) THEN FA16 = .;
   IF (FA17 <= -1) THEN FA17 = .;
   IF (FA18 <= -1) THEN FA18 = .;
   IF (F_LANG <= -1) THEN F_LANG = .;
   IF (FB1A <= -1) THEN FB1A = .;
   IF (FB2A <= -1) THEN FB2A = .;
   IF (FB3A <= -1) THEN FB3A = .;
   IF (FB4A <= -1) THEN FB4A = .;
   IF (FB1B <= -1) THEN FB1B = .;
   IF (FB2B <= -1) THEN FB2B = .;
   IF (FB3B <= -1) THEN FB3B = .;
   IF (FB4B <= -1) THEN FB4B = .;
   IF (FB1C <= -1) THEN FB1C = .;
   IF (FB2C <= -1) THEN FB2C = .;
   IF (FB3C <= -1) THEN FB3C = .;
   IF (FB4C <= -1) THEN FB4C = .;
   IF (FB1D <= -1) THEN FB1D = .;
   IF (FB2D <= -1) THEN FB2D = .;
   IF (FB3D <= -1) THEN FB3D = .;
   IF (FB4D <= -1) THEN FB4D = .;
   IF (FB1E <= -1) THEN FB1E = .;
   IF (FB2E <= -1) THEN FB2E = .;
   IF (FB3E <= -1) THEN FB3E = .;
   IF (FB4E <= -1) THEN FB4E = .;
   IF (FB1F <= -1) THEN FB1F = .;
   IF (FB2F <= -1) THEN FB2F = .;
   IF (FB3F <= -1) THEN FB3F = .;
   IF (FB4F <= -1) THEN FB4F = .;
   IF (FB1G <= -1) THEN FB1G = .;
   IF (FB2G <= -1) THEN FB2G = .;
   IF (FB3G <= -1) THEN FB3G = .;
   IF (FB4G <= -1) THEN FB4G = .;
   IF (FB1H <= -1) THEN FB1H = .;
   IF (FB2H <= -1) THEN FB2H = .;
   IF (FB3H <= -1) THEN FB3H = .;
   IF (FB4H <= -1) THEN FB4H = .;
   IF (FB1I <= -1) THEN FB1I = .;
   IF (FB2I <= -1) THEN FB2I = .;
   IF (FB3I <= -1) THEN FB3I = .;
   IF (FB4I <= -1) THEN FB4I = .;
   IF (FB1J <= -1) THEN FB1J = .;
   IF (FB2J <= -1) THEN FB2J = .;
   IF (FB3J <= -1) THEN FB3J = .;
   IF (FB4J <= -1) THEN FB4J = .;
   IF (FB1K <= -1) THEN FB1K = .;
   IF (FB2K <= -1) THEN FB2K = .;
   IF (FB3K <= -1) THEN FB3K = .;
   IF (FB4K <= -1) THEN FB4K = .;
   IF (FB1L <= -1) THEN FB1L = .;
   IF (FB2L <= -1) THEN FB2L = .;
   IF (FB3L <= -1) THEN FB3L = .;
   IF (FB4L <= -1) THEN FB4L = .;
   IF (FB1M <= -1) THEN FB1M = .;
   IF (FB1MOTH <= -1) THEN FB1MOTH = .;
   IF (FB2M <= -1) THEN FB2M = .;
   IF (FB3M <= -1) THEN FB3M = .;
   IF (FB4M <= -1) THEN FB4M = .;
   IF (FB5 <= -1) THEN FB5 = .;
   IF (FB6 <= -1) THEN FB6 = .;
   IF (FB7 <= -1) THEN FB7 = .;
   IF (FB8 <= -1) THEN FB8 = .;
   IF (FB9 <= -1) THEN FB9 = .;
   IF (FB9A <= -1) THEN FB9A = .;
   IF (FB10 <= -1) THEN FB10 = .;
   IF (FB11 <= -1) THEN FB11 = .;
   IF (FB12A <= -1) THEN FB12A = .;
   IF (FB13A <= -1) THEN FB13A = .;
   IF (FB12B <= -1) THEN FB12B = .;
   IF (FB13B <= -1) THEN FB13B = .;
   IF (FB12C <= -1) THEN FB12C = .;
   IF (FB13C <= -1) THEN FB13C = .;
   IF (FB14 <= -1) THEN FB14 = .;
   IF (FB15 <= -1) THEN FB15 = .;
   IF (FB16 <= -1) THEN FB16 = .;
   IF (FB17 <= -1) THEN FB17 = .;
   IF (FB18 <= -1) THEN FB18 = .;
   IF (FB19 <= -1) THEN FB19 = .;
   IF (FB20 <= -1) THEN FB20 = .;
   IF (FB21 <= -1) THEN FB21 = .;
   IF (FB22 <= -1) THEN FB22 = .;
   IF (FB23 <= -1) THEN FB23 = .;
   IF (FB24 <= -1) THEN FB24 = .;
   IF (FB25 <= -1) THEN FB25 = .;
   IF (FB26 <= -1) THEN FB26 = .;
   IF (FB27A <= -1) THEN FB27A = .;
   IF (FB27B <= -1) THEN FB27B = .;
   IF (FB27C <= -1) THEN FB27C = .;
   IF (FB27D <= -1) THEN FB27D = .;
   IF (FB27E <= -1) THEN FB27E = .;
   IF (FB27F <= -1) THEN FB27F = .;
   IF (FB27G <= -1) THEN FB27G = .;
   IF (FB28 <= -1) THEN FB28 = .;
   IF (FB29 <= -1) THEN FB29 = .;
   IF (FB30 <= -1) THEN FB30 = .;
   IF (FB31 <= -1) THEN FB31 = .;
   IF (FB32 <= -1) THEN FB32 = .;
   IF (FB33A <= -1) THEN FB33A = .;
   IF (FB33AOTH <= -1) THEN FB33AOTH = .;
   IF (FB34 <= -1) THEN FB34 = .;
   IF (FB34A <= -1) THEN FB34A = .;
   IF (FB35 <= -1) THEN FB35 = .;
   IF (FB36 <= -1) THEN FB36 = .;
   IF (FB37 <= -1) THEN FB37 = .;
   IF (FB38A <= -1) THEN FB38A = .;
   IF (FB38AOTH <= -1) THEN FB38AOTH = .;
   IF (FB39 <= -1) THEN FB39 = .;
   IF (FB40 <= -1) THEN FB40 = .;
   IF (FB41 <= -1) THEN FB41 = .;
   IF (FB42A <= -1) THEN FB42A = .;
   IF (FB42B <= -1) THEN FB42B = .;
   IF (FB42C <= -1) THEN FB42C = .;
   IF (FB42D <= -1) THEN FB42D = .;
   IF (FB42E <= -1) THEN FB42E = .;
   IF (FB42F <= -1) THEN FB42F = .;
   IF (FB42G <= -1) THEN FB42G = .;
   IF (FB42H <= -1) THEN FB42H = .;
   IF (FB42I <= -1) THEN FB42I = .;
   IF (FB42J <= -1) THEN FB42J = .;
   IF (FB42K <= -1) THEN FB42K = .;
   IF (FB42L <= -1) THEN FB42L = .;
   IF (FB43 <= -1) THEN FB43 = .;
   IF (FB44 <= -1) THEN FB44 = .;
   IF (FB44A <= -1) THEN FB44A = .;
   IF (FB44B <= -1) THEN FB44B = .;
   IF (FB45 <= -1) THEN FB45 = .;
   IF (FB46A <= -1) THEN FB46A = .;
   IF (FB47A <= -1) THEN FB47A = .;
   IF (FB46B <= -1) THEN FB46B = .;
   IF (FB47B <= -1) THEN FB47B = .;
   IF (FB46C <= -1) THEN FB46C = .;
   IF (FB47C <= -1) THEN FB47C = .;
   IF (FB46D <= -1) THEN FB46D = .;
   IF (FB47D <= -1) THEN FB47D = .;
   IF (FB46E <= -1) THEN FB46E = .;
   IF (FB47E <= -1) THEN FB47E = .;
   IF (FB46F <= -1) THEN FB46F = .;
   IF (FB47F <= -1) THEN FB47F = .;
   IF (FB46G <= -1) THEN FB46G = .;
   IF (FB47G <= -1) THEN FB47G = .;
   IF (FB46H <= -1) THEN FB46H = .;
   IF (FB47H <= -1) THEN FB47H = .;
   IF (FB48A <= -1) THEN FB48A = .;
   IF (FB49A <= -1) THEN FB49A = .;
   IF (FB48B <= -1) THEN FB48B = .;
   IF (FB49B <= -1) THEN FB49B = .;
   IF (FB48C <= -1) THEN FB48C = .;
   IF (FB49C <= -1) THEN FB49C = .;
   IF (FB48D <= -1) THEN FB48D = .;
   IF (FB49D <= -1) THEN FB49D = .;
   IF (FB48E <= -1) THEN FB48E = .;
   IF (FB49E <= -1) THEN FB49E = .;
   IF (FB48F <= -1) THEN FB48F = .;
   IF (FB49F <= -1) THEN FB49F = .;
   IF (FB48G <= -1) THEN FB48G = .;
   IF (FB49G <= -1) THEN FB49G = .;
   IF (FB48H <= -1) THEN FB48H = .;
   IF (FB49H <= -1) THEN FB49H = .;
   IF (FB50A <= -1) THEN FB50A = .;
   IF (FB50B <= -1) THEN FB50B = .;
   IF (FB50C <= -1) THEN FB50C = .;
   IF (FB50D <= -1) THEN FB50D = .;
   IF (FB51A <= -1) THEN FB51A = .;
   IF (FB52A <= -1) THEN FB52A = .;
   IF (FB53A <= -1) THEN FB53A = .;
   IF (FB51B <= -1) THEN FB51B = .;
   IF (FB52B <= -1) THEN FB52B = .;
   IF (FB53B <= -1) THEN FB53B = .;
   IF (FB51C <= -1) THEN FB51C = .;
   IF (FB52C <= -1) THEN FB52C = .;
   IF (FB53C <= -1) THEN FB53C = .;
   IF (FB51D <= -1) THEN FB51D = .;
   IF (FB52D <= -1) THEN FB52D = .;
   IF (FB53D <= -1) THEN FB53D = .;
   IF (FB54 <= -1) THEN FB54 = .;
   IF (FB55 <= -1) THEN FB55 = .;
   IF (FB56 <= -1) THEN FB56 = .;
   IF (FB57 <= -1) THEN FB57 = .;
   IF (FB58 <= -1) THEN FB58 = .;
   IF (FB59 <= -1) THEN FB59 = .;
   IF (FB60 <= -1) THEN FB60 = .;
   IF (FB61 <= -1) THEN FB61 = .;
   IF (FB62 <= -1) THEN FB62 = .;
   IF (FB63 <= -1) THEN FB63 = .;
   IF (FB64A <= -1) THEN FB64A = .;
   IF (FB65A <= -1) THEN FB65A = .;
   IF (FB64B <= -1) THEN FB64B = .;
   IF (FB65B <= -1) THEN FB65B = .;
   IF (FB64C <= -1) THEN FB64C = .;
   IF (FB65C <= -1) THEN FB65C = .;
   IF (FB64D <= -1) THEN FB64D = .;
   IF (FB65D <= -1) THEN FB65D = .;
   IF (FB64E <= -1) THEN FB64E = .;
   IF (FB65E <= -1) THEN FB65E = .;
   IF (FB64F <= -1) THEN FB64F = .;
   IF (FB65F <= -1) THEN FB65F = .;
   IF (FB64G <= -1) THEN FB64G = .;
   IF (FB65G <= -1) THEN FB65G = .;
   IF (FB64H <= -1) THEN FB64H = .;
   IF (FB65H <= -1) THEN FB65H = .;
   IF (FB64I <= -1) THEN FB64I = .;
   IF (FB65I <= -1) THEN FB65I = .;
   IF (FB64J <= -1) THEN FB64J = .;
   IF (FB65J <= -1) THEN FB65J = .;
   IF (FB64K <= -1) THEN FB64K = .;
   IF (FB65K <= -1) THEN FB65K = .;
   IF (FB64L <= -1) THEN FB64L = .;
   IF (FB65L <= -1) THEN FB65L = .;
   IF (FB64M <= -1) THEN FB64M = .;
   IF (FB65M <= -1) THEN FB65M = .;
   IF (FB66 <= -1) THEN FB66 = .;
   IF (FB67 <= -1) THEN FB67 = .;
   IF (FB68 <= -1) THEN FB68 = .;
   IF (FB69 <= -1) THEN FB69 = .;
   IF (FB70 <= -1) THEN FB70 = .;
   IF (FB71 <= -1) THEN FB71 = .;
   IF (FB72 <= -1) THEN FB72 = .;
   IF (FB73 <= -1) THEN FB73 = .;
   IF (FB74 <= -1) THEN FB74 = .;
   IF (FB75 <= -1) THEN FB75 = .;
   IF (FB76 <= -1) THEN FB76 = .;
   IF (FB77A <= -1) THEN FB77A = .;
   IF (FB77B <= -1) THEN FB77B = .;
   IF (FB77C <= -1) THEN FB77C = .;
   IF (FB78 <= -1) THEN FB78 = .;
   IF (FB78A <= -1) THEN FB78A = .;
   IF (FB79 <= -1) THEN FB79 = .;
   IF (FB80 <= -1) THEN FB80 = .;
   IF (FB81A <= -1) THEN FB81A = .;
   IF (FB82A <= -1) THEN FB82A = .;
   IF (FB83A <= -1) THEN FB83A = .;
   IF (FB84A <= -1) THEN FB84A = .;
   IF (FB85A <= -1) THEN FB85A = .;
   IF (FB81B <= -1) THEN FB81B = .;
   IF (FB82B <= -1) THEN FB82B = .;
   IF (FB83B <= -1) THEN FB83B = .;
   IF (FB84B <= -1) THEN FB84B = .;
   IF (FB85B <= -1) THEN FB85B = .;
   IF (FB81C <= -1) THEN FB81C = .;
   IF (FB82C <= -1) THEN FB82C = .;
   IF (FB83C <= -1) THEN FB83C = .;
   IF (FB84C <= -1) THEN FB84C = .;
   IF (FB85C <= -1) THEN FB85C = .;
   IF (FB81D <= -1) THEN FB81D = .;
   IF (FB82D <= -1) THEN FB82D = .;
   IF (FB83D <= -1) THEN FB83D = .;
   IF (FB84D <= -1) THEN FB84D = .;
   IF (FB85D <= -1) THEN FB85D = .;
   IF (FB81E <= -1) THEN FB81E = .;
   IF (FB82E <= -1) THEN FB82E = .;
   IF (FB83E <= -1) THEN FB83E = .;
   IF (FB84E <= -1) THEN FB84E = .;
   IF (FB85E <= -1) THEN FB85E = .;
   IF (FB81F <= -1) THEN FB81F = .;
   IF (FB82F <= -1) THEN FB82F = .;
   IF (FB83F <= -1) THEN FB83F = .;
   IF (FB84F <= -1) THEN FB84F = .;
   IF (FB85F <= -1) THEN FB85F = .;
   IF (FB81G <= -1) THEN FB81G = .;
   IF (FB82G <= -1) THEN FB82G = .;
   IF (FB83G <= -1) THEN FB83G = .;
   IF (FB84G <= -1) THEN FB84G = .;
   IF (FB85G <= -1) THEN FB85G = .;
   IF (FB81H <= -1) THEN FB81H = .;
   IF (FB82H <= -1) THEN FB82H = .;
   IF (FB83H <= -1) THEN FB83H = .;
   IF (FB84H <= -1) THEN FB84H = .;
   IF (FB85H <= -1) THEN FB85H = .;
   IF (FB81I <= -1) THEN FB81I = .;
   IF (FB82I <= -1) THEN FB82I = .;
   IF (FB83I <= -1) THEN FB83I = .;
   IF (FB84I <= -1) THEN FB84I = .;
   IF (FB85I <= -1) THEN FB85I = .;
   IF (FB81J <= -1) THEN FB81J = .;
   IF (FB82J <= -1) THEN FB82J = .;
   IF (FB83J <= -1) THEN FB83J = .;
   IF (FB84J <= -1) THEN FB84J = .;
   IF (FB85J <= -1) THEN FB85J = .;
   IF (FB82K <= -1) THEN FB82K = .;
   IF (FB83K <= -1) THEN FB83K = .;
   IF (FB84K <= -1) THEN FB84K = .;
   IF (FB85K <= -1) THEN FB85K = .;
   IF (FB81L <= -1) THEN FB81L = .;
   IF (FB82L <= -1) THEN FB82L = .;
   IF (FB83L <= -1) THEN FB83L = .;
   IF (FB84L <= -1) THEN FB84L = .;
   IF (FB85L <= -1) THEN FB85L = .;
   IF (FB81M <= -1) THEN FB81M = .;
   IF (FB82M <= -1) THEN FB82M = .;
   IF (FB83M <= -1) THEN FB83M = .;
   IF (FB84M <= -1) THEN FB84M = .;
   IF (FB85M <= -1) THEN FB85M = .;
   IF (FB81N <= -1) THEN FB81N = .;
   IF (FB81NOTH <= -1) THEN FB81NOTH = .;
   IF (FB82N <= -1) THEN FB82N = .;
   IF (FB83N <= -1) THEN FB83N = .;
   IF (FB84N <= -1) THEN FB84N = .;
   IF (FB85N <= -1) THEN FB85N = .;
   IF (FB86 <= -1) THEN FB86 = .;
   IF (FB87 <= -1) THEN FB87 = .;
   IF (FB88 <= -1) THEN FB88 = .;
   IF (FB89 <= -1) THEN FB89 = .;
   IF (FB90 <= -1) THEN FB90 = .;
   IF (FB91 <= -1) THEN FB91 = .;
   IF (FB91U <= -1) THEN FB91U = .;
   IF (FB92 <= -1) THEN FB92 = .;
   IF (FB93 <= -1) THEN FB93 = .;
   IF (FB93U <= -1) THEN FB93U = .;
   IF (FB94 <= -1) THEN FB94 = .;
   IF (FB95 <= -1) THEN FB95 = .;
   IF (FB95A <= -1) THEN FB95A = .;
   IF (FC1 <= -1) THEN FC1 = .;
   IF (FC2 <= -1) THEN FC2 = .;
   IF (FC3 <= -1) THEN FC3 = .;
   IF (FC4 <= -1) THEN FC4 = .;
   IF (FC5 <= -1) THEN FC5 = .;
   IF (FC6 <= -1) THEN FC6 = .;
   IF (FC6A <= -1) THEN FC6A = .;
   IF (FC7A <= -1) THEN FC7A = .;
   IF (FC7B <= -1) THEN FC7B = .;
   IF (FC7C <= -1) THEN FC7C = .;
   IF (FC7D <= -1) THEN FC7D = .;
   IF (FC7E <= -1) THEN FC7E = .;
   IF (FC7F <= -1) THEN FC7F = .;
   IF (FC8 <= -1) THEN FC8 = .;
   IF (FC8A <= -1) THEN FC8A = .;
   IF (FC9 <= -1) THEN FC9 = .;
   IF (FC10 <= -1) THEN FC10 = .;
   IF (FC11 <= -1) THEN FC11 = .;
   IF (FC11U <= -1) THEN FC11U = .;
   IF (FC12 <= -1) THEN FC12 = .;
   IF (FC13A <= -1) THEN FC13A = .;
   IF (FC13AOTH <= -1) THEN FC13AOTH = .;
   IF (FC14 <= -1) THEN FC14 = .;
   IF (FC15 <= -1) THEN FC15 = .;
   IF (FC15U <= -1) THEN FC15U = .;
   IF (FC16A <= -1) THEN FC16A = .;
   IF (FC16AOTH <= -1) THEN FC16AOTH = .;
   IF (FC17 <= -1) THEN FC17 = .;
   IF (FC18 <= -1) THEN FC18 = .;
   IF (FC19 <= -1) THEN FC19 = .;
   IF (FC20 <= -1) THEN FC20 = .;
   IF (FC21 <= -1) THEN FC21 = .;
   IF (FC22 <= -1) THEN FC22 = .;
   IF (FC24A <= -1) THEN FC24A = .;
   IF (FC25A <= -1) THEN FC25A = .;
   IF (FC24B <= -1) THEN FC24B = .;
   IF (FC25B <= -1) THEN FC25B = .;
   IF (FC24C <= -1) THEN FC24C = .;
   IF (FC25C <= -1) THEN FC25C = .;
   IF (FC24D <= -1) THEN FC24D = .;
   IF (FC25D <= -1) THEN FC25D = .;
   IF (FC24E <= -1) THEN FC24E = .;
   IF (FC25E <= -1) THEN FC25E = .;
   IF (FC24F <= -1) THEN FC24F = .;
   IF (FC25F <= -1) THEN FC25F = .;
   IF (FC24G <= -1) THEN FC24G = .;
   IF (FC25G <= -1) THEN FC25G = .;
   IF (FC24H <= -1) THEN FC24H = .;
   IF (FC25H <= -1) THEN FC25H = .;
   IF (FC24I <= -1) THEN FC24I = .;
   IF (FC25I <= -1) THEN FC25I = .;
   IF (FC24J <= -1) THEN FC24J = .;
   IF (FC25J <= -1) THEN FC25J = .;
   IF (FC24K <= -1) THEN FC24K = .;
   IF (FC25K <= -1) THEN FC25K = .;
   IF (FC24L <= -1) THEN FC24L = .;
   IF (FC25L <= -1) THEN FC25L = .;
   IF (FC24M <= -1) THEN FC24M = .;
   IF (FC25M <= -1) THEN FC25M = .;
   IF (FC24N <= -1) THEN FC24N = .;
   IF (FC25N <= -1) THEN FC25N = .;
   IF (FC24O <= -1) THEN FC24O = .;
   IF (FC25O <= -1) THEN FC25O = .;
   IF (FC24P <= -1) THEN FC24P = .;
   IF (FC25P <= -1) THEN FC25P = .;
   IF (FC24Q <= -1) THEN FC24Q = .;
   IF (FC25Q <= -1) THEN FC25Q = .;
   IF (FC24R <= -1) THEN FC24R = .;
   IF (FC25R <= -1) THEN FC25R = .;
   IF (FC24S <= -1) THEN FC24S = .;
   IF (FC25S <= -1) THEN FC25S = .;
   IF (FC24T <= -1) THEN FC24T = .;
   IF (FC25T <= -1) THEN FC25T = .;
   IF (FC26 <= -1) THEN FC26 = .;
   IF (FC27 <= -1) THEN FC27 = .;
   IF (FC28 <= -1) THEN FC28 = .;
   IF (FC29A <= -1) THEN FC29A = .;
   IF (FC29B <= -1) THEN FC29B = .;
   IF (FC29C <= -1) THEN FC29C = .;
   IF (FC29D <= -1) THEN FC29D = .;
   IF (FC29E <= -1) THEN FC29E = .;
   IF (FC29F <= -1) THEN FC29F = .;
   IF (FC29G <= -1) THEN FC29G = .;
   IF (FC29H <= -1) THEN FC29H = .;
   IF (FC29I <= -1) THEN FC29I = .;
   IF (FC29J <= -1) THEN FC29J = .;
   IF (FC29K <= -1) THEN FC29K = .;
   IF (FC29L <= -1) THEN FC29L = .;
   IF (FC29M <= -1) THEN FC29M = .;
   IF (FC29N <= -1) THEN FC29N = .;
   IF (FC29O <= -1) THEN FC29O = .;
   IF (FC30A <= -1) THEN FC30A = .;
   IF (FC30B <= -1) THEN FC30B = .;
   IF (FC30C <= -1) THEN FC30C = .;
   IF (FC30D <= -1) THEN FC30D = .;
   IF (FC30E <= -1) THEN FC30E = .;
   IF (FC30EOTH <= -1) THEN FC30EOTH = .;
   IF (FC31A <= -1) THEN FC31A = .;
   IF (FC32A <= -1) THEN FC32A = .;
   IF (FC33A <= -1) THEN FC33A = .;
   IF (FC31B <= -1) THEN FC31B = .;
   IF (FC32B <= -1) THEN FC32B = .;
   IF (FC33B <= -1) THEN FC33B = .;
   IF (FC31C <= -1) THEN FC31C = .;
   IF (FC32C <= -1) THEN FC32C = .;
   IF (FC33C <= -1) THEN FC33C = .;
   IF (FC31D <= -1) THEN FC31D = .;
   IF (FC32D <= -1) THEN FC32D = .;
   IF (FC33D <= -1) THEN FC33D = .;
   IF (FC34 <= -1) THEN FC34 = .;
   IF (FC35 <= -1) THEN FC35 = .;
   IF (FC35OTH <= -1) THEN FC35OTH = .;
   IF (FC36 <= -1) THEN FC36 = .;
   IF (FC37 <= -1) THEN FC37 = .;
   IF (FC38 <= -1) THEN FC38 = .;
   IF (FC39 <= -1) THEN FC39 = .;
   IF (FC40 <= -1) THEN FC40 = .;
   IF (FC41 <= -1) THEN FC41 = .;
   IF (FC42 <= -1) THEN FC42 = .;
   IF (FC43 <= -1) THEN FC43 = .;
   IF (FC44 <= -1) THEN FC44 = .;
   IF (FC45 <= -1) THEN FC45 = .;
   IF (FC46 <= -1) THEN FC46 = .;
   IF (FC47 <= -1) THEN FC47 = .;
   IF (FC48 <= -1) THEN FC48 = .;
   IF (FC49 <= -1) THEN FC49 = .;
   IF (FC50 <= -1) THEN FC50 = .;
   IF (FC51 <= -1) THEN FC51 = .;
   IF (FC52 <= -1) THEN FC52 = .;
   IF (FC53 <= -1) THEN FC53 = .;
   IF (FC54 <= -1) THEN FC54 = .;
   IF (FC55 <= -1) THEN FC55 = .;
   IF (FC56 <= -1) THEN FC56 = .;
   IF (FC57 <= -1) THEN FC57 = .;
   IF (FC58 <= -1) THEN FC58 = .;
   IF (FC58U <= -1) THEN FC58U = .;
   IF (FC59 <= -1) THEN FC59 = .;
   IF (FC60A <= -1) THEN FC60A = .;
   IF (FC60B <= -1) THEN FC60B = .;
   IF (FC60C <= -1) THEN FC60C = .;
   IF (FC60D <= -1) THEN FC60D = .;
   IF (FC60E <= -1) THEN FC60E = .;
   IF (FC60F <= -1) THEN FC60F = .;
   IF (FC61A <= -1) THEN FC61A = .;
   IF (FC61B <= -1) THEN FC61B = .;
   IF (FC61C <= -1) THEN FC61C = .;
   IF (FC61D <= -1) THEN FC61D = .;
   IF (FC61E <= -1) THEN FC61E = .;
   IF (FC61F <= -1) THEN FC61F = .;
   IF (FC61G <= -1) THEN FC61G = .;
   IF (FC61H <= -1) THEN FC61H = .;
   IF (FC61I <= -1) THEN FC61I = .;
   IF (FC61J <= -1) THEN FC61J = .;
   IF (FC61JOTH <= -1) THEN FC61JOTH = .;
   IF (FC61MAIN <= -1) THEN FC61MAIN = .;
   IF (FC62A <= -1) THEN FC62A = .;
   IF (FC62B <= -1) THEN FC62B = .;
   IF (FC62C <= -1) THEN FC62C = .;
   IF (FC62D <= -1) THEN FC62D = .;
   IF (FC62E <= -1) THEN FC62E = .;
   IF (FC62F <= -1) THEN FC62F = .;
   IF (FC62G <= -1) THEN FC62G = .;
   IF (FC62H <= -1) THEN FC62H = .;
   IF (FC62I <= -1) THEN FC62I = .;
   IF (FC62J <= -1) THEN FC62J = .;
   IF (FC62K <= -1) THEN FC62K = .;
   IF (FC62L <= -1) THEN FC62L = .;
   IF (FD1A <= -1) THEN FD1A = .;
   IF (FD2A <= -1) THEN FD2A = .;
   IF (FD3A <= -1) THEN FD3A = .;
   IF (FD4A <= -1) THEN FD4A = .;
   IF (FD1B <= -1) THEN FD1B = .;
   IF (FD2B <= -1) THEN FD2B = .;
   IF (FD3B <= -1) THEN FD3B = .;
   IF (FD4B <= -1) THEN FD4B = .;
   IF (FD1C <= -1) THEN FD1C = .;
   IF (FD2C <= -1) THEN FD2C = .;
   IF (FD3C <= -1) THEN FD3C = .;
   IF (FD4C <= -1) THEN FD4C = .;
   IF (FD1D <= -1) THEN FD1D = .;
   IF (FD2D <= -1) THEN FD2D = .;
   IF (FD3D <= -1) THEN FD3D = .;
   IF (FD4D <= -1) THEN FD4D = .;
   IF (FD1E <= -1) THEN FD1E = .;
   IF (FD2E <= -1) THEN FD2E = .;
   IF (FD3E <= -1) THEN FD3E = .;
   IF (FD4E <= -1) THEN FD4E = .;
   IF (FD1F <= -1) THEN FD1F = .;
   IF (FD2F <= -1) THEN FD2F = .;
   IF (FD3F <= -1) THEN FD3F = .;
   IF (FD4F <= -1) THEN FD4F = .;
   IF (FD1G <= -1) THEN FD1G = .;
   IF (FD2G <= -1) THEN FD2G = .;
   IF (FD3G <= -1) THEN FD3G = .;
   IF (FD4G <= -1) THEN FD4G = .;
   IF (FD1H <= -1) THEN FD1H = .;
   IF (FD2H <= -1) THEN FD2H = .;
   IF (FD3H <= -1) THEN FD3H = .;
   IF (FD4H <= -1) THEN FD4H = .;
   IF (FD1I <= -1) THEN FD1I = .;
   IF (FD2I <= -1) THEN FD2I = .;
   IF (FD3I <= -1) THEN FD3I = .;
   IF (FD4I <= -1) THEN FD4I = .;
   IF (FD1J <= -1) THEN FD1J = .;
   IF (FD2J <= -1) THEN FD2J = .;
   IF (FD3J <= -1) THEN FD3J = .;
   IF (FD4J <= -1) THEN FD4J = .;
   IF (FD1K <= -1) THEN FD1K = .;
   IF (FD2K <= -1) THEN FD2K = .;
   IF (FD3K <= -1) THEN FD3K = .;
   IF (FD4K <= -1) THEN FD4K = .;
   IF (FD1L <= -1) THEN FD1L = .;
   IF (FD2L <= -1) THEN FD2L = .;
   IF (FD3L <= -1) THEN FD3L = .;
   IF (FD4L <= -1) THEN FD4L = .;
   IF (FD1M <= -1) THEN FD1M = .;
   IF (FD1MOTH1 <= -1) THEN FD1MOTH1 = .;
   IF (FD2MOTH1 <= -1) THEN FD2MOTH1 = .;
   IF (FD3MOTH1 <= -1) THEN FD3MOTH1 = .;
   IF (FD4MOTH1 <= -1) THEN FD4MOTH1 = .;
   IF (FD1MOTH2 <= -1) THEN FD1MOTH2 = .;
   IF (FD2MOTH2 <= -1) THEN FD2MOTH2 = .;
   IF (FD3MOTH2 <= -1) THEN FD3MOTH2 = .;
   IF (FD4MOTH2 <= -1) THEN FD4MOTH2 = .;
   IF (FD1MOTH3 <= -1) THEN FD1MOTH3 = .;
   IF (FD2MOTH3 <= -1) THEN FD2MOTH3 = .;
   IF (FD3MOTH3 <= -1) THEN FD3MOTH3 = .;
   IF (FD4MOTH3 <= -1) THEN FD4MOTH3 = .;
   IF (FD5 <= -1) THEN FD5 = .;
   IF (FD6 <= -1) THEN FD6 = .;
   IF (FD7 <= -1) THEN FD7 = .;
   IF (FD8 <= -1) THEN FD8 = .;
   IF (FD9 <= -1) THEN FD9 = .;
   IF (FD10 <= -1) THEN FD10 = .;
   IF (FD11 <= -1) THEN FD11 = .;
   IF (FD12A <= -1) THEN FD12A = .;
   IF (FD13A <= -1) THEN FD13A = .;
   IF (FD12B <= -1) THEN FD12B = .;
   IF (FD13B <= -1) THEN FD13B = .;
   IF (FD12C <= -1) THEN FD12C = .;
   IF (FD13C <= -1) THEN FD13C = .;
   IF (FD14 <= -1) THEN FD14 = .;
   IF (FD15 <= -1) THEN FD15 = .;
   IF (FD16 <= -1) THEN FD16 = .;
   IF (FD17 <= -1) THEN FD17 = .;
   IF (FD18 <= -1) THEN FD18 = .;
   IF (FD19 <= -1) THEN FD19 = .;
   IF (FD20 <= -1) THEN FD20 = .;
   IF (FD21 <= -1) THEN FD21 = .;
   IF (FD23A <= -1) THEN FD23A = .;
   IF (FD23B <= -1) THEN FD23B = .;
   IF (FD23C <= -1) THEN FD23C = .;
   IF (FD23D <= -1) THEN FD23D = .;
   IF (FD23E <= -1) THEN FD23E = .;
   IF (FD23F <= -1) THEN FD23F = .;
   IF (FD23G <= -1) THEN FD23G = .;
   IF (FD24 <= -1) THEN FD24 = .;
   IF (FD25 <= -1) THEN FD25 = .;
   IF (FD26 <= -1) THEN FD26 = .;
   IF (FD27 <= -1) THEN FD27 = .;
   IF (FD28A <= -1) THEN FD28A = .;
   IF (FD28AOTH <= -1) THEN FD28AOTH = .;
   IF (FD29 <= -1) THEN FD29 = .;
   IF (FD30 <= -1) THEN FD30 = .;
   IF (FD31A <= -1) THEN FD31A = .;
   IF (FD31AOTH <= -1) THEN FD31AOTH = .;
   IF (FD32A <= -1) THEN FD32A = .;
   IF (FD32B <= -1) THEN FD32B = .;
   IF (FD32C <= -1) THEN FD32C = .;
   IF (FD32D <= -1) THEN FD32D = .;
   IF (FD32E <= -1) THEN FD32E = .;
   IF (FD32F <= -1) THEN FD32F = .;
   IF (FD32G <= -1) THEN FD32G = .;
   IF (FD32H <= -1) THEN FD32H = .;
   IF (FD32I <= -1) THEN FD32I = .;
   IF (FD32J <= -1) THEN FD32J = .;
   IF (FD32K <= -1) THEN FD32K = .;
   IF (FD32L <= -1) THEN FD32L = .;
   IF (FD33A <= -1) THEN FD33A = .;
   IF (FD33B <= -1) THEN FD33B = .;
   IF (FD33C <= -1) THEN FD33C = .;
   IF (FD33D <= -1) THEN FD33D = .;
   IF (FD33E <= -1) THEN FD33E = .;
   IF (FD33F <= -1) THEN FD33F = .;
   IF (FD34A <= -1) THEN FD34A = .;
   IF (FD34B <= -1) THEN FD34B = .;
   IF (FD34C <= -1) THEN FD34C = .;
   IF (FD34D <= -1) THEN FD34D = .;
   IF (FD34E <= -1) THEN FD34E = .;
   IF (FD35 <= -1) THEN FD35 = .;
   IF (FD37A <= -1) THEN FD37A = .;
   IF (FD38A <= -1) THEN FD38A = .;
   IF (FD37B <= -1) THEN FD37B = .;
   IF (FD38B <= -1) THEN FD38B = .;
   IF (FD37C <= -1) THEN FD37C = .;
   IF (FD38C <= -1) THEN FD38C = .;
   IF (FD37D <= -1) THEN FD37D = .;
   IF (FD38D <= -1) THEN FD38D = .;
   IF (FD37E <= -1) THEN FD37E = .;
   IF (FD38E <= -1) THEN FD38E = .;
   IF (FD37F <= -1) THEN FD37F = .;
   IF (FD38F <= -1) THEN FD38F = .;
   IF (FD37G <= -1) THEN FD37G = .;
   IF (FD38G <= -1) THEN FD38G = .;
   IF (FD37H <= -1) THEN FD37H = .;
   IF (FD38H <= -1) THEN FD38H = .;
   IF (FD39A <= -1) THEN FD39A = .;
   IF (FD40A <= -1) THEN FD40A = .;
   IF (FD41A <= -1) THEN FD41A = .;
   IF (FD39B <= -1) THEN FD39B = .;
   IF (FD40B <= -1) THEN FD40B = .;
   IF (FD41B <= -1) THEN FD41B = .;
   IF (FD39C <= -1) THEN FD39C = .;
   IF (FD40C <= -1) THEN FD40C = .;
   IF (FD41C <= -1) THEN FD41C = .;
   IF (FD39D <= -1) THEN FD39D = .;
   IF (FD40D <= -1) THEN FD40D = .;
   IF (FD41D <= -1) THEN FD41D = .;
   IF (FD42 <= -1) THEN FD42 = .;
   IF (FD42A <= -1) THEN FD42A = .;
   IF (FD42B <= -1) THEN FD42B = .;
   IF (FD42C <= -1) THEN FD42C = .;
   IF (FD42D <= -1) THEN FD42D = .;
   IF (FD42E <= -1) THEN FD42E = .;
   IF (FD42F <= -1) THEN FD42F = .;
   IF (FD42G <= -1) THEN FD42G = .;
   IF (FD42H <= -1) THEN FD42H = .;
   IF (FD42I <= -1) THEN FD42I = .;
   IF (FD43 <= -1) THEN FD43 = .;
   IF (FD44 <= -1) THEN FD44 = .;
   IF (FD45 <= -1) THEN FD45 = .;
   IF (FD46 <= -1) THEN FD46 = .;
   IF (FD47 <= -1) THEN FD47 = .;
   IF (FD48 <= -1) THEN FD48 = .;
   IF (FD49A <= -1) THEN FD49A = .;
   IF (FD49B <= -1) THEN FD49B = .;
   IF (FD49C <= -1) THEN FD49C = .;
   IF (FD49D <= -1) THEN FD49D = .;
   IF (FD49E <= -1) THEN FD49E = .;
   IF (FD49F <= -1) THEN FD49F = .;
   IF (FD49G <= -1) THEN FD49G = .;
   IF (FD49H <= -1) THEN FD49H = .;
   IF (FD49I <= -1) THEN FD49I = .;
   IF (FD49J <= -1) THEN FD49J = .;
   IF (FD49K <= -1) THEN FD49K = .;
   IF (FD49L <= -1) THEN FD49L = .;
   IF (FD49M <= -1) THEN FD49M = .;
   IF (FD50 <= -1) THEN FD50 = .;
   IF (FD51 <= -1) THEN FD51 = .;
   IF (FD54 <= -1) THEN FD54 = .;
   IF (FD55 <= -1) THEN FD55 = .;
   IF (FD56 <= -1) THEN FD56 = .;
   IF (FD57 <= -1) THEN FD57 = .;
   IF (FD58 <= -1) THEN FD58 = .;
   IF (FD59 <= -1) THEN FD59 = .;
   IF (FD60 <= -1) THEN FD60 = .;
   IF (FD61A <= -1) THEN FD61A = .;
   IF (FD61B <= -1) THEN FD61B = .;
   IF (FD61C <= -1) THEN FD61C = .;
   IF (FD62 <= -1) THEN FD62 = .;
   IF (FD63 <= -1) THEN FD63 = .;
   IF (FD64 <= -1) THEN FD64 = .;
   IF (FD65 <= -1) THEN FD65 = .;
   IF (FD66 <= -1) THEN FD66 = .;
   IF (FD67 <= -1) THEN FD67 = .;
   IF (FD68A <= -1) THEN FD68A = .;
   IF (FD69A <= -1) THEN FD69A = .;
   IF (FD68B <= -1) THEN FD68B = .;
   IF (FD69B <= -1) THEN FD69B = .;
   IF (FD68C <= -1) THEN FD68C = .;
   IF (FD69C <= -1) THEN FD69C = .;
   IF (FD68D <= -1) THEN FD68D = .;
   IF (FD69D <= -1) THEN FD69D = .;
   IF (FD68E <= -1) THEN FD68E = .;
   IF (FD69E <= -1) THEN FD69E = .;
   IF (FD68F <= -1) THEN FD68F = .;
   IF (FD69F <= -1) THEN FD69F = .;
   IF (FD68G <= -1) THEN FD68G = .;
   IF (FD69G <= -1) THEN FD69G = .;
   IF (FD68H <= -1) THEN FD68H = .;
   IF (FD69H <= -1) THEN FD69H = .;
   IF (FD68I <= -1) THEN FD68I = .;
   IF (FD69I <= -1) THEN FD69I = .;
   IF (FD68J <= -1) THEN FD68J = .;
   IF (FD69J <= -1) THEN FD69J = .;
   IF (FD68K <= -1) THEN FD68K = .;
   IF (FD69K <= -1) THEN FD69K = .;
   IF (FD68L <= -1) THEN FD68L = .;
   IF (FD69L <= -1) THEN FD69L = .;
   IF (FD68M <= -1) THEN FD68M = .;
   IF (FD69M <= -1) THEN FD69M = .;
   IF (FD68N <= -1) THEN FD68N = .;
   IF (FD68NOTH <= -1) THEN FD68NOTH = .;
   IF (FD69N <= -1) THEN FD69N = .;
   IF (FD70 <= -1) THEN FD70 = .;
   IF (FD71 <= -1) THEN FD71 = .;
   IF (FD72 <= -1) THEN FD72 = .;
   IF (FD73 <= -1) THEN FD73 = .;
   IF (FD74 <= -1) THEN FD74 = .;
   IF (FD75 <= -1) THEN FD75 = .;
   IF (FD75U <= -1) THEN FD75U = .;
   IF (FD76 <= -1) THEN FD76 = .;
   IF (FD77 <= -1) THEN FD77 = .;
   IF (FD78 <= -1) THEN FD78 = .;
   IF (FD79 <= -1) THEN FD79 = .;
   IF (FD80 <= -1) THEN FD80 = .;
   IF (FD81A <= -1) THEN FD81A = .;
   IF (FD82A <= -1) THEN FD82A = .;
   IF (FD83A <= -1) THEN FD83A = .;
   IF (FD81B <= -1) THEN FD81B = .;
   IF (FD82B <= -1) THEN FD82B = .;
   IF (FD83B <= -1) THEN FD83B = .;
   IF (FD81C <= -1) THEN FD81C = .;
   IF (FD82C <= -1) THEN FD82C = .;
   IF (FD83C <= -1) THEN FD83C = .;
   IF (FD81D <= -1) THEN FD81D = .;
   IF (FD82D <= -1) THEN FD82D = .;
   IF (FD83D <= -1) THEN FD83D = .;
   IF (FD81E <= -1) THEN FD81E = .;
   IF (FD82E <= -1) THEN FD82E = .;
   IF (FD83E <= -1) THEN FD83E = .;
   IF (FD81F <= -1) THEN FD81F = .;
   IF (FD82F <= -1) THEN FD82F = .;
   IF (FD83F <= -1) THEN FD83F = .;
   IF (FD81G <= -1) THEN FD81G = .;
   IF (FD82G <= -1) THEN FD82G = .;
   IF (FD83G <= -1) THEN FD83G = .;
   IF (FD81H <= -1) THEN FD81H = .;
   IF (FD82H <= -1) THEN FD82H = .;
   IF (FD83H <= -1) THEN FD83H = .;
   IF (FD81I <= -1) THEN FD81I = .;
   IF (FD82I <= -1) THEN FD82I = .;
   IF (FD83I <= -1) THEN FD83I = .;
   IF (FD84A <= -1) THEN FD84A = .;
   IF (FD84B <= -1) THEN FD84B = .;
   IF (FD84C <= -1) THEN FD84C = .;
   IF (FD84D <= -1) THEN FD84D = .;
   IF (FD84E <= -1) THEN FD84E = .;
   IF (FD84F <= -1) THEN FD84F = .;
   IF (FD84G <= -1) THEN FD84G = .;
   IF (FB2CFLG <= -1) THEN FB2CFLG = .;
   IF (FB2FFLG <= -1) THEN FB2FFLG = .;
   IF (FB2KFLG <= -1) THEN FB2KFLG = .;
   IF (FB82AFLG <= -1) THEN FB82AFLG = .;
   IF (FB82BFLG <= -1) THEN FB82BFLG = .;
   IF (FB82CFLG <= -1) THEN FB82CFLG = .;
   IF (FB82DFLG <= -1) THEN FB82DFLG = .;
   IF (FB82EFLG <= -1) THEN FB82EFLG = .;
   IF (FB82FFLG <= -1) THEN FB82FFLG = .;
   IF (FB82GFLG <= -1) THEN FB82GFLG = .;
   IF (FB82HFLG <= -1) THEN FB82HFLG = .;
   IF (FB82IFLG <= -1) THEN FB82IFLG = .;
   IF (FB82JFLG <= -1) THEN FB82JFLG = .;
   IF (FB82KFLG <= -1) THEN FB82KFLG = .;
   IF (FB82LFLG <= -1) THEN FB82LFLG = .;
   IF (FB82MFLG <= -1) THEN FB82MFLG = .;
   IF (FB82NFLG <= -1) THEN FB82NFLG = .;
   IF (FB88AFLG <= -1) THEN FB88AFLG = .;
   IF (FD36FLG <= -1) THEN FD36FLG = .;
   IF (FD3BFLG <= -1) THEN FD3BFLG = .;
   IF (FD3CFLG <= -1) THEN FD3CFLG = .;
   IF (FD3DFLG <= -1) THEN FD3DFLG = .;
   IF (FD3EFLG <= -1) THEN FD3EFLG = .;
   IF (FD3FFLG <= -1) THEN FD3FFLG = .;
   IF (FD3GFLG <= -1) THEN FD3GFLG = .;
   IF (FD3IFLG <= -1) THEN FD3IFLG = .;
   IF (FD38BFLG <= -1) THEN FD38BFLG = .;
   IF (FD38CFLG <= -1) THEN FD38CFLG = .;
   IF (FD38DFLG <= -1) THEN FD38DFLG = .;
   IF (FD38FFLG <= -1) THEN FD38FFLG = .;
   IF (FD38GFLG <= -1) THEN FD38GFLG = .;
   IF (FD38HFLG <= -1) THEN FD38HFLG = .;
   IF (FD5FLG <= -1) THEN FD5FLG = .;
   IF (FD26FLG <= -1) THEN FD26FLG = .;
   IF (FD30FLG <= -1) THEN FD30FLG = .;
   IF (FD40AFLG <= -1) THEN FD40AFLG = .;
   IF (FD40BFLG <= -1) THEN FD40BFLG = .;
   IF (FD40CFLG <= -1) THEN FD40CFLG = .;
   IF (FD40DFLG <= -1) THEN FD40DFLG = .;
   IF (FB64MOTH <= -1) THEN FB64MOTH = .;
   IF (FC7FOTH1 <= -1) THEN FC7FOTH1 = .;
   IF (FC7FOTH2 <= -1) THEN FC7FOTH2 = .;
   IF (FC7FOTH3 <= -1) THEN FC7FOTH3 = .;
   IF (FD49MOTH <= -1) THEN FD49MOTH = .;
   IF (FD81IOTH <= -1) THEN FD81IOTH = .;
   IF (FC23 <= -1) THEN FC23 = .;
   IF (FC29OOTH <= -1) THEN FC29OOTH = .;
   IF (FDAYSDCG <= -1) THEN FDAYSDCG = .;
   IF (F_NEXTTX <= -1) THEN F_NEXTTX = .;
   IF (F_AGEINT <= -1) THEN F_AGEINT = .;
   IF (A73 <= -1) THEN A73 = .;
   IF (FACID <= -1) THEN FACID = .;
   IF (AGE_CALC <= -1) THEN AGE_CALC = .;
   IF (LOS <= -1) THEN LOS = .;
   IF (TRT_DUR <= -1) THEN TRT_DUR = .;
   IF (ALCOHOL <= -1) THEN ALCOHOL = .;
   IF (DRUG <= -1) THEN DRUG = .;
   IF (DRUG_ALC <= -1) THEN DRUG_ALC = .;
   IF (TXCARE <= -1) THEN TXCARE = .;
   IF (ABSSMPTY <= -1) THEN ABSSMPTY = .;
   IF (QFSTRAT <= -1) THEN QFSTRAT = .;
   IF (GROUP <= -1) THEN GROUP = .;
   IF (FIELDPSU <= -1) THEN FIELDPSU = .;
   IF (U_MRJ_SM <= -1) THEN U_MRJ_SM = .;
   IF (U_PCP_SM <= -1) THEN U_PCP_SM = .;
   IF (U_AMP_SM <= -1) THEN U_AMP_SM = .;
   IF (U_BEN_SM <= -1) THEN U_BEN_SM = .;
   IF (U_COC_SM <= -1) THEN U_COC_SM = .;
   IF (U_MET_SM <= -1) THEN U_MET_SM = .;
   IF (U_OPI_SM <= -1) THEN U_OPI_SM = .;
   IF (U_ALCF1 <= -1) THEN U_ALCF1 = .;
   IF (U_MRJF1 <= -1) THEN U_MRJF1 = .;
   IF (U_PCPF1 <= -1) THEN U_PCPF1 = .;
   IF (U_AMPF1 <= -1) THEN U_AMPF1 = .;
   IF (U_AMPF2 <= -1) THEN U_AMPF2 = .;
   IF (U_BENF1 <= -1) THEN U_BENF1 = .;
   IF (U_BENF2 <= -1) THEN U_BENF2 = .;
   IF (U_BENF3 <= -1) THEN U_BENF3 = .;
   IF (U_BENF4 <= -1) THEN U_BENF4 = .;
   IF (U_BENF5 <= -1) THEN U_BENF5 = .;
   IF (U_BENF6 <= -1) THEN U_BENF6 = .;
   IF (U_BENF7 <= -1) THEN U_BENF7 = .;
   IF (U_BENF8 <= -1) THEN U_BENF8 = .;
   IF (U_COCF1 <= -1) THEN U_COCF1 = .;
   IF (U_METF1 <= -1) THEN U_METF1 = .;
   IF (U_OPIF1 <= -1) THEN U_OPIF1 = .;
   IF (U_OPIF2 <= -1) THEN U_OPIF2 = .;
   IF (U_OPIF3 <= -1) THEN U_OPIF3 = .;
   IF (U_OPIF4 <= -1) THEN U_OPIF4 = .;
   IF (U_AMLID <= -1) THEN U_AMLID = .;
   IF (U_CREATN <= -1) THEN U_CREATN = .;
   IF (U_PH <= -1) THEN U_PH = .;
   IF (U_MRJV1 <= -1) THEN U_MRJV1 = .;
   IF (U_PCPV1 <= -1) THEN U_PCPV1 = .;
   IF (U_AMPV1 <= -1) THEN U_AMPV1 = .;
   IF (U_AMPV2 <= -1) THEN U_AMPV2 = .;
   IF (U_BENV1 <= -1) THEN U_BENV1 = .;
   IF (U_BENV2 <= -1) THEN U_BENV2 = .;
   IF (U_BENV3 <= -1) THEN U_BENV3 = .;
   IF (U_BENV4 <= -1) THEN U_BENV4 = .;
   IF (U_BENV5 <= -1) THEN U_BENV5 = .;
   IF (U_BENV6 <= -1) THEN U_BENV6 = .;
   IF (U_BENV7 <= -1) THEN U_BENV7 = .;
   IF (U_BENV8 <= -1) THEN U_BENV8 = .;
   IF (U_COCV1 <= -1) THEN U_COCV1 = .;
   IF (U_METV1 <= -1) THEN U_METV1 = .;
   IF (U_OPIV1 <= -1) THEN U_OPIV1 = .;
   IF (U_OPIV2 <= -1) THEN U_OPIV2 = .;
   IF (U_OPIV3 <= -1) THEN U_OPIV3 = .;
   IF (U_OPIV4 <= -1) THEN U_OPIV4 = .;
   IF (U_ALCV1 <= -1.00) THEN U_ALCV1 = .;
   IF (U_NITRIT <= -1) THEN U_NITRIT = .;
   IF (U_ANYPOS <= -1) THEN U_ANYPOS = .;
   IF (U_ANYDRG <= -1) THEN U_ANYDRG = .;
   IF (U_NUMDRG <= -1) THEN U_NUMDRG = .;
   IF (U_DTDIFF <= -1) THEN U_DTDIFF = .;
   IF (U_RESULT <= -1) THEN U_RESULT = .;
   IF (FB33 <= -1.00) THEN FB33 = .;
   IF (FB38 <= -1.00) THEN FB38 = .;
   IF (FC13 <= -1.00) THEN FC13 = .;
   IF (FC16 <= -1.00) THEN FC16 = .;
   IF (FD31 <= -1.00) THEN FD31 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT FOUTCOME foutcome. F_CT f_ct. FA1 fa1fffff.
         FA3 fa3fffff. FA4 fa4fffff. FA5 fa5fffff.
         FA6 fa6fffff. FA7 fa7fffff. FA8 fa8fffff.
         FA9 fa9fffff. FA10 fa10ffff. FA11 fa11ffff.
         FA12 fa12ffff. FA12A fa12a. FA13 fa13ffff.
         FA14 fa14ffff. FA15 fa15ffff. FA16 fa16ffff.
         FA17 fa17ffff. FA18 fa18ffff. F_LANG f_lang.
         FB1A fb1a. FB2A fb2a. FB3A fb3a.
         FB4A fb4a. FB1B fb1b. FB2B fb2b.
         FB3B fb3b. FB4B fb4b. FB1C fb1c.
         FB2C fb2c. FB3C fb3c. FB4C fb4c.
         FB1D fb1d. FB2D fb2d. FB3D fb3d.
         FB4D fb4d. FB1E fb1e. FB2E fb2e.
         FB3E fb3e. FB4E fb4e. FB1F fb1f.
         FB2F fb2f. FB3F fb3f. FB4F fb4f.
         FB1G fb1g. FB2G fb2g. FB3G fb3g.
         FB4G fb4g. FB1H fb1h. FB2H fb2h.
         FB3H fb3h. FB4H fb4h. FB1I fb1i.
         FB2I fb2i. FB3I fb3i. FB4I fb4i.
         FB1J fb1j. FB2J fb2j. FB3J fb3j.
         FB4J fb4j. FB1K fb1k. FB2K fb2k.
         FB3K fb3k. FB4K fb4k. FB1L fb1l.
         FB2L fb2l. FB3L fb3l. FB4L fb4l.
         FB1M fb1m. FB1MOTH fb1moth. FB2M fb2m.
         FB3M fb3m. FB4M fb4m. FB5 fb5fffff.
         FB6 fb6fffff. FB7 fb7fffff. FB8 fb8fffff.
         FB9 fb9fffff. FB9A fb9a. FB10 fb10ffff.
         FB11 fb11ffff. FB12A fb12a. FB13A fb13a.
         FB12B fb12b. FB13B fb13b. FB12C fb12c.
         FB13C fb13c. FB14 fb14ffff. FB15 fb15ffff.
         FB16 fb16ffff. FB17 fb17ffff. FB18 fb18ffff.
         FB19 fb19ffff. FB20 fb20ffff. FB21 fb21ffff.
         FB22 fb22ffff. FB23 fb23ffff. FB24 fb24ffff.
         FB25 fb25ffff. FB26 fb26ffff. FB27A fb27a.
         FB27B fb27b. FB27C fb27c. FB27D fb27d.
         FB27E fb27e. FB27F fb27f. FB27G fb27g.
         FB28 fb28ffff. FB29 fb29ffff. FB30 fb30ffff.
         FB31 fb31ffff. FB32 fb32ffff. FB33A fb33a.
         FB33AOTH fb33aoth. FB34 fb34ffff. FB34A fb34a.
         FB35 fb35ffff. FB36 fb36ffff. FB37 fb37ffff.
         FB38A fb38a. FB38AOTH fb38aoth. FB39 fb39ffff.
         FB40 fb40ffff. FB41 fb41ffff. FB42A fb42a.
         FB42B fb42b. FB42C fb42c. FB42D fb42d.
         FB42E fb42e. FB42F fb42f. FB42G fb42g.
         FB42H fb42h. FB42I fb42i. FB42J fb42j.
         FB42K fb42k. FB42L fb42l. FB43 fb43ffff.
         FB44 fb44ffff. FB44A fb44a. FB44B fb44b.
         FB45 fb45ffff. FB46A fb46a. FB47A fb47a.
         FB46B fb46b. FB47B fb47b. FB46C fb46c.
         FB47C fb47c. FB46D fb46d. FB47D fb47d.
         FB46E fb46e. FB47E fb47e. FB46F fb46f.
         FB47F fb47f. FB46G fb46g. FB47G fb47g.
         FB46H fb46h. FB47H fb47h. FB48A fb48a.
         FB49A fb49a. FB48B fb48b. FB49B fb49b.
         FB48C fb48c. FB49C fb49c. FB48D fb48d.
         FB49D fb49d. FB48E fb48e. FB49E fb49e.
         FB48F fb48f. FB49F fb49f. FB48G fb48g.
         FB49G fb49g. FB48H fb48h. FB49H fb49h.
         FB50A fb50a. FB50B fb50b. FB50C fb50c.
         FB50D fb50d. FB51A fb51a. FB52A fb52a.
         FB53A fb53a. FB51B fb51b. FB52B fb52b.
         FB53B fb53b. FB51C fb51c. FB52C fb52c.
         FB53C fb53c. FB51D fb51d. FB52D fb52d.
         FB53D fb53d. FB54 fb54ffff. FB55 fb55ffff.
         FB56 fb56ffff. FB57 fb57ffff. FB58 fb58ffff.
         FB59 fb59ffff. FB60 fb60ffff. FB61 fb61ffff.
         FB62 fb62ffff. FB63 fb63ffff. FB64A fb64a.
         FB65A fb65a. FB64B fb64b. FB65B fb65b.
         FB64C fb64c. FB65C fb65c. FB64D fb64d.
         FB65D fb65d. FB64E fb64e. FB65E fb65e.
         FB64F fb64f. FB65F fb65f. FB64G fb64g.
         FB65G fb65g. FB64H fb64h. FB65H fb65h.
         FB64I fb64i. FB65I fb65i. FB64J fb64j.
         FB65J fb65j. FB64K fb64k. FB65K fb65k.
         FB64L fb64l. FB65L fb65l. FB64M fb64m.
         FB65M fb65m. FB66 fb66ffff. FB67 fb67ffff.
         FB68 fb68ffff. FB69 fb69ffff. FB70 fb70ffff.
         FB71 fb71ffff. FB72 fb72ffff. FB73 fb73ffff.
         FB74 fb74ffff. FB75 fb75ffff. FB76 fb76ffff.
         FB77A fb77a. FB77B fb77b. FB77C fb77c.
         FB78 fb78ffff. FB78A fb78a. FB79 fb79ffff.
         FB80 fb80ffff. FB81A fb81a. FB82A fb82a.
         FB83A fb83a. FB84A fb84a. FB85A fb85a.
         FB81B fb81b. FB82B fb82b. FB83B fb83b.
         FB84B fb84b. FB85B fb85b. FB81C fb81c.
         FB82C fb82c. FB83C fb83c. FB84C fb84c.
         FB85C fb85c. FB81D fb81d. FB82D fb82d.
         FB83D fb83d. FB84D fb84d. FB85D fb85d.
         FB81E fb81e. FB82E fb82e. FB83E fb83e.
         FB84E fb84e. FB85E fb85e. FB81F fb81f.
         FB82F fb82f. FB83F fb83f. FB84F fb84f.
         FB85F fb85f. FB81G fb81g. FB82G fb82g.
         FB83G fb83g. FB84G fb84g. FB85G fb85g.
         FB81H fb81h. FB82H fb82h. FB83H fb83h.
         FB84H fb84h. FB85H fb85h. FB81I fb81i.
         FB82I fb82i. FB83I fb83i. FB84I fb84i.
         FB85I fb85i. FB81J fb81j. FB82J fb82j.
         FB83J fb83j. FB84J fb84j. FB85J fb85j.
         FB82K fb82k. FB83K fb83k. FB84K fb84k.
         FB85K fb85k. FB81L fb81l. FB82L fb82l.
         FB83L fb83l. FB84L fb84l. FB85L fb85l.
         FB81M fb81m. FB82M fb82m. FB83M fb83m.
         FB84M fb84m. FB85M fb85m. FB81N fb81n.
         FB81NOTH fb81noth. FB82N fb82n. FB83N fb83n.
         FB84N fb84n. FB85N fb85n. FB86 fb86ffff.
         FB87 fb87ffff. FB88 fb88ffff. FB89 fb89ffff.
         FB90 fb90ffff. FB91 fb91ffff. FB91U fb91u.
         FB92 fb92ffff. FB93 fb93ffff. FB93U fb93u.
         FB94 fb94ffff. FB95 fb95ffff. FB95A fb95a.
         FC1 fc1fffff. FC2 fc2fffff. FC3 fc3fffff.
         FC4 fc4fffff. FC5 fc5fffff. FC6 fc6fffff.
         FC6A fc6a. FC7A fc7a. FC7B fc7b.
         FC7C fc7c. FC7D fc7d. FC7E fc7e.
         FC7F fc7f. FC8 fc8fffff. FC8A fc8a.
         FC9 fc9fffff. FC10 fc10ffff. FC11 fc11ffff.
         FC11U fc11u. FC12 fc12ffff. FC13A fc13a.
         FC13AOTH fc13aoth. FC14 fc14ffff. FC15 fc15ffff.
         FC15U fc15u. FC16A fc16a. FC16AOTH fc16aoth.
         FC17 fc17ffff. FC18 fc18ffff. FC19 fc19ffff.
         FC20 fc20ffff. FC21 fc21ffff. FC22 fc22ffff.
         FC24A fc24a. FC25A fc25a. FC24B fc24b.
         FC25B fc25b. FC24C fc24c. FC25C fc25c.
         FC24D fc24d. FC25D fc25d. FC24E fc24e.
         FC25E fc25e. FC24F fc24f. FC25F fc25f.
         FC24G fc24g. FC25G fc25g. FC24H fc24h.
         FC25H fc25h. FC24I fc24i. FC25I fc25i.
         FC24J fc24j. FC25J fc25j. FC24K fc24k.
         FC25K fc25k. FC24L fc24l. FC25L fc25l.
         FC24M fc24m. FC25M fc25m. FC24N fc24n.
         FC25N fc25n. FC24O fc24o. FC25O fc25o.
         FC24P fc24p. FC25P fc25p. FC24Q fc24q.
         FC25Q fc25q. FC24R fc24r. FC25R fc25r.
         FC24S fc24s. FC25S fc25s. FC24T fc24t.
         FC25T fc25t. FC26 fc26ffff. FC27 fc27ffff.
         FC28 fc28ffff. FC29A fc29a. FC29B fc29b.
         FC29C fc29c. FC29D fc29d. FC29E fc29e.
         FC29F fc29f. FC29G fc29g. FC29H fc29h.
         FC29I fc29i. FC29J fc29j. FC29K fc29k.
         FC29L fc29l. FC29M fc29m. FC29N fc29n.
         FC29O fc29o. FC30A fc30a. FC30B fc30b.
         FC30C fc30c. FC30D fc30d. FC30E fc30e.
         FC30EOTH fc30eoth. FC31A fc31a. FC32A fc32a.
         FC33A fc33a. FC31B fc31b. FC32B fc32b.
         FC33B fc33b. FC31C fc31c. FC32C fc32c.
         FC33C fc33c. FC31D fc31d. FC32D fc32d.
         FC33D fc33d. FC34 fc34ffff. FC35 fc35ffff.
         FC35OTH fc35oth. FC36 fc36ffff. FC37 fc37ffff.
         FC38 fc38ffff. FC39 fc39ffff. FC40 fc40ffff.
         FC41 fc41ffff. FC42 fc42ffff. FC43 fc43ffff.
         FC44 fc44ffff. FC45 fc45ffff. FC46 fc46ffff.
         FC47 fc47ffff. FC48 fc48ffff. FC49 fc49ffff.
         FC50 fc50ffff. FC51 fc51ffff. FC52 fc52ffff.
         FC53 fc53ffff. FC54 fc54ffff. FC55 fc55ffff.
         FC56 fc56ffff. FC57 fc57ffff. FC58 fc58ffff.
         FC58U fc58u. FC59 fc59ffff. FC60A fc60a.
         FC60B fc60b. FC60C fc60c. FC60D fc60d.
         FC60E fc60e. FC60F fc60f. FC61A fc61a.
         FC61B fc61b. FC61C fc61c. FC61D fc61d.
         FC61E fc61e. FC61F fc61f. FC61G fc61g.
         FC61H fc61h. FC61I fc61i. FC61J fc61j.
         FC61JOTH fc61joth. FC61MAIN fc61main. FC62A fc62a.
         FC62B fc62b. FC62C fc62c. FC62D fc62d.
         FC62E fc62e. FC62F fc62f. FC62G fc62g.
         FC62H fc62h. FC62I fc62i. FC62J fc62j.
         FC62K fc62k. FC62L fc62l. FD1A fd1a.
         FD2A fd2a. FD3A fd3a. FD4A fd4a.
         FD1B fd1b. FD2B fd2b. FD3B fd3b.
         FD4B fd4b. FD1C fd1c. FD2C fd2c.
         FD3C fd3c. FD4C fd4c. FD1D fd1d.
         FD2D fd2d. FD3D fd3d. FD4D fd4d.
         FD1E fd1e. FD2E fd2e. FD3E fd3e.
         FD4E fd4e. FD1F fd1f. FD2F fd2f.
         FD3F fd3f. FD4F fd4f. FD1G fd1g.
         FD2G fd2g. FD3G fd3g. FD4G fd4g.
         FD1H fd1h. FD2H fd2h. FD3H fd3h.
         FD4H fd4h. FD1I fd1i. FD2I fd2i.
         FD3I fd3i. FD4I fd4i. FD1J fd1j.
         FD2J fd2j. FD3J fd3j. FD4J fd4j.
         FD1K fd1k. FD2K fd2k. FD3K fd3k.
         FD4K fd4k. FD1L fd1l. FD2L fd2l.
         FD3L fd3l. FD4L fd4l. FD1M fd1m.
         FD1MOTH1 fd1mothf. FD2MOTH1 fd2mothf. FD3MOTH1 fd3mothf.
         FD4MOTH1 fd4mothf. FD1MOTH2 fd1mot0f. FD2MOTH2 fd2mot0f.
         FD3MOTH2 fd3mot0f. FD4MOTH2 fd4mot0f. FD1MOTH3 fd1mot1f.
         FD2MOTH3 fd2mot1f. FD3MOTH3 fd3mot1f. FD4MOTH3 fd4mot1f.
         FD5 fd5fffff. FD6 fd6fffff. FD7 fd7fffff.
         FD8 fd8fffff. FD9 fd9fffff. FD10 fd10ffff.
         FD11 fd11ffff. FD12A fd12a. FD13A fd13a.
         FD12B fd12b. FD13B fd13b. FD12C fd12c.
         FD13C fd13c. FD14 fd14ffff. FD15 fd15ffff.
         FD16 fd16ffff. FD17 fd17ffff. FD18 fd18ffff.
         FD19 fd19ffff. FD20 fd20ffff. FD21 fd21ffff.
         FD23A fd23a. FD23B fd23b. FD23C fd23c.
         FD23D fd23d. FD23E fd23e. FD23F fd23f.
         FD23G fd23g. FD24 fd24ffff. FD25 fd25ffff.
         FD26 fd26ffff. FD27 fd27ffff. FD28A fd28a.
         FD28AOTH fd28aoth. FD29 fd29ffff. FD30 fd30ffff.
         FD31A fd31a. FD31AOTH fd31aoth. FD32A fd32a.
         FD32B fd32b. FD32C fd32c. FD32D fd32d.
         FD32E fd32e. FD32F fd32f. FD32G fd32g.
         FD32H fd32h. FD32I fd32i. FD32J fd32j.
         FD32K fd32k. FD32L fd32l. FD33A fd33a.
         FD33B fd33b. FD33C fd33c. FD33D fd33d.
         FD33E fd33e. FD33F fd33f. FD34A fd34a.
         FD34B fd34b. FD34C fd34c. FD34D fd34d.
         FD34E fd34e. FD35 fd35ffff. FD37A fd37a.
         FD38A fd38a. FD37B fd37b. FD38B fd38b.
         FD37C fd37c. FD38C fd38c. FD37D fd37d.
         FD38D fd38d. FD37E fd37e. FD38E fd38e.
         FD37F fd37f. FD38F fd38f. FD37G fd37g.
         FD38G fd38g. FD37H fd37h. FD38H fd38h.
         FD39A fd39a. FD40A fd40a. FD41A fd41a.
         FD39B fd39b. FD40B fd40b. FD41B fd41b.
         FD39C fd39c. FD40C fd40c. FD41C fd41c.
         FD39D fd39d. FD40D fd40d. FD41D fd41d.
         FD42 fd42ffff. FD42A fd42a. FD42B fd42b.
         FD42C fd42c. FD42D fd42d. FD42E fd42e.
         FD42F fd42f. FD42G fd42g. FD42H fd42h.
         FD42I fd42i. FD43 fd43ffff. FD44 fd44ffff.
         FD45 fd45ffff. FD46 fd46ffff. FD47 fd47ffff.
         FD48 fd48ffff. FD49A fd49a. FD49B fd49b.
         FD49C fd49c. FD49D fd49d. FD49E fd49e.
         FD49F fd49f. FD49G fd49g. FD49H fd49h.
         FD49I fd49i. FD49J fd49j. FD49K fd49k.
         FD49L fd49l. FD49M fd49m. FD50 fd50ffff.
         FD51 fd51ffff. FD54 fd54ffff. FD55 fd55ffff.
         FD56 fd56ffff. FD57 fd57ffff. FD58 fd58ffff.
         FD59 fd59ffff. FD60 fd60ffff. FD61A fd61a.
         FD61B fd61b. FD61C fd61c. FD62 fd62ffff.
         FD63 fd63ffff. FD64 fd64ffff. FD65 fd65ffff.
         FD66 fd66ffff. FD67 fd67ffff. FD68A fd68a.
         FD69A fd69a. FD68B fd68b. FD69B fd69b.
         FD68C fd68c. FD69C fd69c. FD68D fd68d.
         FD69D fd69d. FD68E fd68e. FD69E fd69e.
         FD68F fd68f. FD69F fd69f. FD68G fd68g.
         FD69G fd69g. FD68H fd68h. FD69H fd69h.
         FD68I fd68i. FD69I fd69i. FD68J fd68j.
         FD69J fd69j. FD68K fd68k. FD69K fd69k.
         FD68L fd68l. FD69L fd69l. FD68M fd68m.
         FD69M fd69m. FD68N fd68n. FD68NOTH fd68noth.
         FD69N fd69n. FD70 fd70ffff. FD71 fd71ffff.
         FD72 fd72ffff. FD73 fd73ffff. FD74 fd74ffff.
         FD75 fd75ffff. FD75U fd75u. FD76 fd76ffff.
         FD77 fd77ffff. FD78 fd78ffff. FD79 fd79ffff.
         FD80 fd80ffff. FD81A fd81a. FD82A fd82a.
         FD83A fd83a. FD81B fd81b. FD82B fd82b.
         FD83B fd83b. FD81C fd81c. FD82C fd82c.
         FD83C fd83c. FD81D fd81d. FD82D fd82d.
         FD83D fd83d. FD81E fd81e. FD82E fd82e.
         FD83E fd83e. FD81F fd81f. FD82F fd82f.
         FD83F fd83f. FD81G fd81g. FD82G fd82g.
         FD83G fd83g. FD81H fd81h. FD82H fd82h.
         FD83H fd83h. FD81I fd81i. FD82I fd82i.
         FD83I fd83i. FD84A fd84a. FD84B fd84b.
         FD84C fd84c. FD84D fd84d. FD84E fd84e.
         FD84F fd84f. FD84G fd84g. FB2CFLG fb2cflg.
         FB2FFLG fb2fflg. FB2KFLG fb2kflg. FB82AFLG fb82aflg.
         FB82BFLG fb82bflg. FB82CFLG fb82cflg. FB82DFLG fb82dflg.
         FB82EFLG fb82eflg. FB82FFLG fb82fflg. FB82GFLG fb82gflg.
         FB82HFLG fb82hflg. FB82IFLG fb82iflg. FB82JFLG fb82jflg.
         FB82KFLG fb82kflg. FB82LFLG fb82lflg. FB82MFLG fb82mflg.
         FB82NFLG fb82nflg. FB88AFLG fb88aflg. FD36FLG fd36flg.
         FD3BFLG fd3bflg. FD3CFLG fd3cflg. FD3DFLG fd3dflg.
         FD3EFLG fd3eflg. FD3FFLG fd3fflg. FD3GFLG fd3gflg.
         FD3IFLG fd3iflg. FD38BFLG fd38bflg. FD38CFLG fd38cflg.
         FD38DFLG fd38dflg. FD38FFLG fd38fflg. FD38GFLG fd38gflg.
         FD38HFLG fd38hflg. FD5FLG fd5flg. FD26FLG fd26flg.
         FD30FLG fd30flg. FD40AFLG fd40aflg. FD40BFLG fd40bflg.
         FD40CFLG fd40cflg. FD40DFLG fd40dflg. FB64MOTH fb64moth.
         FC7FOTH1 fc7fothf. FC7FOTH2 fc7fot0f. FC7FOTH3 fc7fot1f.
         FD49MOTH fd49moth. FD81IOTH fd81ioth. FC23 fc23ffff.
         FC29OOTH fc29ooth. FDAYSDCG fdaysdcg. F_NEXTTX f_nexttx.
         F_AGEINT f_ageint. A73 a73fffff. AGE_CALC age_calc.
         LOS los. TRT_DUR trt_dur. ALCOHOL alcohol.
         DRUG drug. DRUG_ALC drug_alc. TXCARE txcare.
         ABSSMPTY abssmpty. QFSTRAT qfstrat. GROUP group.
         U_MRJ_SM u_mrj_sm. U_PCP_SM u_pcp_sm. U_AMP_SM u_amp_sm.
         U_BEN_SM u_ben_sm. U_COC_SM u_coc_sm. U_MET_SM u_met_sm.
         U_OPI_SM u_opi_sm. U_ALCF1 u_alcf1f. U_MRJF1 u_mrjf1f.
         U_PCPF1 u_pcpf1f. U_AMPF1 u_ampf1f. U_AMPF2 u_ampf2f.
         U_BENF1 u_benf1f. U_BENF2 u_benf2f. U_BENF3 u_benf3f.
         U_BENF4 u_benf4f. U_BENF5 u_benf5f. U_BENF6 u_benf6f.
         U_BENF7 u_benf7f. U_BENF8 u_benf8f. U_COCF1 u_cocf1f.
         U_METF1 u_metf1f. U_OPIF1 u_opif1f. U_OPIF2 u_opif2f.
         U_OPIF3 u_opif3f. U_OPIF4 u_opif4f. U_AMLID u_amlid.
         U_CREATN u_creatn. U_PH u_ph. U_MRJV1 u_mrjv1f.
         U_PCPV1 u_pcpv1f. U_AMPV1 u_ampv1f. U_AMPV2 u_ampv2f.
         U_BENV1 u_benv1f. U_BENV2 u_benv2f. U_BENV3 u_benv3f.
         U_BENV4 u_benv4f. U_BENV5 u_benv5f. U_BENV6 u_benv6f.
         U_BENV7 u_benv7f. U_BENV8 u_benv8f. U_COCV1 u_cocv1f.
         U_METV1 u_metv1f. U_OPIV1 u_opiv1f. U_OPIV2 u_opiv2f.
         U_OPIV3 u_opiv3f. U_OPIV4 u_opiv4f. U_ALCV1 u_alcv1f.
         U_NITRIT u_nitrit. U_ANYPOS u_anypos. U_ANYDRG u_anydrg.
         U_NUMDRG u_numdrg. U_DTDIFF u_dtdiff. U_RESULT u_result.
         FB33 fb33ffff. FB38 fb38ffff. FC13 fc13ffff.
         FC16 fc16ffff. FD31 fd31ffff.  ;
*/

RUN ;
